@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  channel_mode.h: The ircd channel mode header.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,25 +17,43 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: channel_mode.h 1956 2013-05-06 18:59:00Z michael $
  */
 
+/*! \file channel_mode.h
+ * \brief Includes channel mode related definitions and structures.
+ * \version $Id: channel_mode.h 3043 2014-02-25 21:10:08Z michael $
+ */
 
 #ifndef INCLUDED_channel_mode_h
 #define INCLUDED_channel_mode_h
 
-#include "ircd_defs.h"        /* buffer sizes */
-
 #define MODEBUFLEN    200
 
 /* Maximum mode changes allowed per client, per server is different */
 #define MAXMODEPARAMS 4
 
+enum
+{
+  MODE_QUERY =  0,
+  MODE_ADD   =  1,
+  MODE_DEL   = -1
+};
+
+enum
+{
+  CHACCESS_NOTONCHAN = -1,
+  CHACCESS_PEON      =  0,
+  CHACCESS_HALFOP    =  1,
+  CHACCESS_CHANOP    =  2
+};
+
 /* can_send results */
-#define CAN_SEND_NO	0
-#define CAN_SEND_NONOP  -1
-#define CAN_SEND_OPV	-2
+enum
+{
+  CAN_SEND_NO    =  0,
+  CAN_SEND_NONOP = -1,
+  CAN_SEND_OPV   = -2
+};
 
 
 /* Channel related flags */
@@ -66,18 +83,9 @@
 #define CHFL_BAN_CHECKED  0x0080
 #define CHFL_BAN_SILENCED 0x0100
 
-#define MODE_QUERY  0
-#define MODE_ADD    1
-#define MODE_DEL   -1
-
-#define CHACCESS_NOTONCHAN  -1
-#define CHACCESS_PEON       0
-#define CHACCESS_HALFOP     1
-#define CHACCESS_CHANOP     2
-
 /* name invisible */
 #define SecretChannel(x)        (((x)->mode.mode & MODE_SECRET))
-#define PubChannel(x)           (!SecretChannel(x))
+#define PubChannel(x)           (((x)->mode.mode & (MODE_PRIVATE | MODE_SECRET)) == 0)
 /* knock is forbidden, halfops can't kick/deop other halfops.
  * +pi means paranoid and will generate notices on each invite */
 #define PrivateChannel(x)       (((x)->mode.mode & MODE_PRIVATE))
@@ -108,9 +116,10 @@ struct mode_letter
 };
 
 extern const struct mode_letter chan_modes[];
-extern int add_id(struct Client *, struct Channel *, char *, int);
+
+extern int add_id(struct Client *, struct Channel *, char *, unsigned int);
 extern void set_channel_mode(struct Client *, struct Client *, struct Channel *,
-                             struct Membership *, int, char **, char *);
+                             struct Membership *, int, char **);
 extern void clear_ban_cache(struct Channel *);
 extern void clear_ban_cache_client(struct Client *);
 extern void init_chcap_usage_counts(void);
