@@ -1,7 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 2590 2013-11-21 13:51:37Z michael $
+ * \version $Id: client.h 3310 2014-04-15 11:41:24Z michael $
  */
 
 
@@ -36,6 +36,8 @@
 #include "channel.h"
 #include "s_auth.h"
 
+struct MaskItem;
+
 /*
  * status macros.
  */
@@ -51,9 +53,9 @@
 #define REG_NEED_CAP  0x4
 #define REG_INIT (REG_NEED_USER|REG_NEED_NICK)
 
-#define HasID(x)		((x)->id[0] != '\0')
-#define ID(x)			(HasID(x) ? (x)->id : (x)->name)
-#define ID_or_name(x,client_p)	((IsCapable(client_p->from, CAP_TS6) && HasID(x)) ? (x)->id : (x)->name)
+#define HasID(x)                ((x)->id[0] != '\0')
+#define ID(x)                   (HasID(x) ? (x)->id : (x)->name)
+#define ID_or_name(x,client_p)  ((IsCapable(client_p->from, CAP_TS6) && HasID(x)) ? (x)->id : (x)->name)
 
 #define IsRegistered(x)         ((x)->status  > STAT_UNKNOWN)
 #define IsConnecting(x)         ((x)->status == STAT_CONNECTING)
@@ -64,23 +66,23 @@
 #define IsClient(x)             ((x)->status == STAT_CLIENT)
 
 #define SetConnecting(x)        {(x)->status = STAT_CONNECTING; \
-				 (x)->handler = UNREGISTERED_HANDLER; }
+                                 (x)->handler = UNREGISTERED_HANDLER; }
 
 #define SetHandshake(x)         {(x)->status = STAT_HANDSHAKE; \
-				 (x)->handler = UNREGISTERED_HANDLER; }
+                                 (x)->handler = UNREGISTERED_HANDLER; }
 
 #define SetMe(x)                {(x)->status = STAT_ME; \
-				 (x)->handler = UNREGISTERED_HANDLER; }
+                                 (x)->handler = UNREGISTERED_HANDLER; }
 
 #define SetUnknown(x)           {(x)->status = STAT_UNKNOWN; \
-				 (x)->handler = UNREGISTERED_HANDLER; }
+                                 (x)->handler = UNREGISTERED_HANDLER; }
 
 #define SetServer(x)            {(x)->status = STAT_SERVER; \
-				 (x)->handler = SERVER_HANDLER; }
+                                 (x)->handler = SERVER_HANDLER; }
 
 #define SetClient(x)            {(x)->status = STAT_CLIENT; \
-				 (x)->handler = HasUMode(x, UMODE_OPER) ? \
-					OPER_HANDLER : CLIENT_HANDLER; }
+                                 (x)->handler = HasUMode(x, UMODE_OPER) ? \
+                                 OPER_HANDLER : CLIENT_HANDLER; }
 
 #define MyConnect(x)            ((x)->localClient != NULL)
 #define MyClient(x)             (MyConnect(x) && IsClient(x))
@@ -97,9 +99,11 @@
 
 #define CAP_MULTI_PREFIX  0x00000001
 #define CAP_AWAY_NOTIFY   0x00000002
+#define CAP_UHNAMES       0x00000004
 
 #define HasCap(x, y) ((x)->localClient->cap_active & (y))
 
+
 /* housekeeping flags */
 #define FLAGS_PINGSENT       0x00000001 /**< Unreplied ping sent */
 #define FLAGS_DEADSOCKET     0x00000002 /**< Local socket is dead--Exiting soon */
@@ -185,7 +189,7 @@
 #define OPER_FLAG_UNKLINE        0x00000004 /**< Oper can use unkline        */
 #define OPER_FLAG_GLINE          0x00000008 /**< Oper can use gline          */
 #define OPER_FLAG_K              0x00000010 /**< Oper can kill/kline         */
-#define OPER_FLAG_X              0x00000020 /**< Oper can xline              */
+#define OPER_FLAG_XLINE          0x00000020 /**< Oper can xline              */
 #define OPER_FLAG_DIE            0x00000040 /**< Oper can die                */
 #define OPER_FLAG_REHASH         0x00000080 /**< Oper can rehash             */
 #define OPER_FLAG_ADMIN          0x00000100 /**< Oper can set umode +a       */
@@ -203,6 +207,8 @@
 #define OPER_FLAG_CONNECT_REMOTE 0x00100000 /**< Oper can do global CONNECT */
 #define OPER_FLAG_WALLOPS        0x00200000 /**< Oper can do WALLOPS */
 #define OPER_FLAG_LOCOPS         0x00400000 /**< Oper can do LOCOPS */
+#define OPER_FLAG_UNXLINE        0x00800000 /**< Oper can unxline            */
+
 
 #define HasOFlag(x, y) (MyConnect(x) ? (x)->localClient->operflags & (y) : 0)
 #define AddOFlag(x, y) ((x)->localClient->operflags |=  (y))
@@ -215,25 +221,24 @@
 #define IsAuthFinished(x)       ((x)->flags & FLAGS_FINISHED_AUTH)
 #define IsDead(x)               ((x)->flags & FLAGS_DEADSOCKET)
 #define SetDead(x)              ((x)->flags |= FLAGS_DEADSOCKET)
-#define IsClosing(x)		((x)->flags & FLAGS_CLOSING)
-#define SetClosing(x)		((x)->flags |= FLAGS_CLOSING)
-#define SetCanFlood(x)		((x)->flags |= FLAGS_CANFLOOD)
-#define IsCanFlood(x)		((x)->flags & FLAGS_CANFLOOD)
-#define IsDefunct(x)            ((x)->flags & (FLAGS_DEADSOCKET|FLAGS_CLOSING| \
-					       FLAGS_KILLED))
+#define IsClosing(x)            ((x)->flags & FLAGS_CLOSING)
+#define SetClosing(x)           ((x)->flags |= FLAGS_CLOSING)
+#define SetCanFlood(x)          ((x)->flags |= FLAGS_CANFLOOD)
+#define IsCanFlood(x)           ((x)->flags & FLAGS_CANFLOOD)
+#define IsDefunct(x)            ((x)->flags & (FLAGS_DEADSOCKET|FLAGS_CLOSING|FLAGS_KILLED))
 
 /* oper flags */
 #define MyOper(x)               (MyConnect(x) && HasUMode(x, UMODE_OPER))
 
 #define SetOper(x)              {(x)->umodes |= UMODE_OPER; \
-				 if (!IsServer((x))) (x)->handler = OPER_HANDLER;}
+                                 if (!IsServer((x))) (x)->handler = OPER_HANDLER;}
 
 #define ClearOper(x)            {(x)->umodes &= ~(UMODE_OPER|UMODE_ADMIN); \
-				 if (!HasUMode(x, UMODE_OPER) && !IsServer((x))) \
-				  (x)->handler = CLIENT_HANDLER; }
+                                 if (!HasUMode(x, UMODE_OPER) && !IsServer((x))) \
+                                  (x)->handler = CLIENT_HANDLER; }
 
-#define SetSendQExceeded(x)	((x)->flags |= FLAGS_SENDQEX)
-#define IsSendQExceeded(x)	((x)->flags &  FLAGS_SENDQEX)
+#define SetSendQExceeded(x)     ((x)->flags |= FLAGS_SENDQEX)
+#define IsSendQExceeded(x)      ((x)->flags &  FLAGS_SENDQEX)
 
 #define SetIpHash(x)            ((x)->flags |= FLAGS_IPHASH)
 #define ClearIpHash(x)          ((x)->flags &= ~FLAGS_IPHASH)
@@ -243,9 +248,9 @@
 #define ClearUserHost(x)        ((x)->flags &= ~FLAGS_USERHOST)
 #define IsUserHostIp(x)         ((x)->flags & FLAGS_USERHOST)
 
-#define SetPingSent(x)		((x)->flags |= FLAGS_PINGSENT)
-#define IsPingSent(x)		((x)->flags & FLAGS_PINGSENT)
-#define ClearPingSent(x)	((x)->flags &= ~FLAGS_PINGSENT)
+#define SetPingSent(x)          ((x)->flags |= FLAGS_PINGSENT)
+#define IsPingSent(x)           ((x)->flags & FLAGS_PINGSENT)
+#define ClearPingSent(x)        ((x)->flags &= ~FLAGS_PINGSENT)
 
 #define SetNeedId(x)            ((x)->flags |= FLAGS_NEEDID)
 #define IsNeedId(x)             ((x)->flags & FLAGS_NEEDID)
@@ -272,10 +277,6 @@
 #define IsHidden(x)             ((x)->flags &  FLAGS_HIDDEN)
 #define SetHidden(x)            ((x)->flags |= FLAGS_HIDDEN)
 
-#define IsSendqBlocked(x)       ((x)->flags &  FLAGS_BLOCKED)
-#define SetSendqBlocked(x)      ((x)->flags |= FLAGS_BLOCKED)
-#define ClearSendqBlocked(x)    ((x)->flags &= ~FLAGS_BLOCKED)
-
 
 /*! \brief addr_mask_type enumeration */
 enum addr_mask_type
@@ -408,10 +409,9 @@ struct Client
 
   char away[AWAYLEN + 1]; /**< Client's AWAY message. Can be set/unset via AWAY command */
   char name[HOSTLEN + 1]; /**< unique name for a client nick or host */
-  char svid[HOSTLEN + 1]; /**< Services ID. XXX: Going with HOSTLEN for now. NICKLEN might be too small
-                                if dealing with timestamps */
+  char svid[SVIDLEN + 1]; /**< Services ID. */
   char id[IDLEN + 1];       /**< client ID, unique ID per client */
-  /* 
+  /*
    * client->username is the username from ident or the USER message,
    * If the client is idented the USER message is ignored, otherwise
    * the username part of the USER message is put here prefixed with a
@@ -461,6 +461,7 @@ extern struct split_nuh_item *find_accept(const char *, const char *,
 extern void del_accept(struct split_nuh_item *, struct Client *);
 extern void del_all_accepts(struct Client *);
 extern void exit_client(struct Client *, struct Client *, const char *);
+extern void conf_try_ban(struct Client *, struct MaskItem *);
 extern void check_conf_klines(void);
 extern void client_init(void);
 extern void dead_link_on_write(struct Client *, int);
@@ -468,7 +469,7 @@ extern void dead_link_on_read(struct Client *, int);
 extern void exit_aborted_clients(void);
 extern void free_exited_clients(void);
 extern struct Client *make_client(struct Client *);
-extern struct Client *find_chasing(struct Client *, const char *, int *const);
+extern struct Client *find_chasing(struct Client *, const char *);
 extern struct Client *find_person(const struct Client *const, const char *);
 extern const char *get_client_name(const struct Client *, enum addr_mask_type);
 
