@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  conf.h: A header for the configuration functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2005 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: conf.h 2523 2013-11-01 20:44:22Z michael $
+ */
+
+/*! \file conf.h
+ * \brief A header for the configuration functions.
+ * \version $Id: conf.h 3094 2014-03-01 19:45:10Z michael $
  */
 
 #ifndef INCLUDED_s_conf_h
@@ -40,33 +42,29 @@
 
 /* MaskItem->flags */
 #define CONF_FLAGS_DO_IDENTD            0x00000001
-#define CONF_FLAGS_LIMIT_IP             0x00000002
 #define CONF_FLAGS_NO_TILDE             0x00000004
 #define CONF_FLAGS_NEED_IDENTD          0x00000008
-#define CONF_FLAGS_NOMATCH_IP           0x00000010
-#define CONF_FLAGS_EXEMPTKLINE          0x00000020
-#define CONF_FLAGS_NOLIMIT              0x00000040
-#define CONF_FLAGS_SPOOF_IP             0x00000080
-#define CONF_FLAGS_SPOOF_NOTICE         0x00000100
-#define CONF_FLAGS_REDIR                0x00000200
-#define CONF_FLAGS_EXEMPTGLINE          0x00000400
-#define CONF_FLAGS_CAN_FLOOD            0x00000800
-#define CONF_FLAGS_NEED_PASSWORD        0x00001000
-#define CONF_FLAGS_ALLOW_AUTO_CONN      0x00002000
-#define CONF_FLAGS_ENCRYPTED            0x00004000
-#define CONF_FLAGS_IN_DATABASE          0x00008000
-#define CONF_FLAGS_EXEMPTRESV           0x00010000
-#define CONF_FLAGS_SSL                  0x00020000
-#define CONF_FLAGS_WEBIRC               0x00040000
+#define CONF_FLAGS_EXEMPTKLINE          0x00000010
+#define CONF_FLAGS_NOLIMIT              0x00000020
+#define CONF_FLAGS_SPOOF_IP             0x00000040
+#define CONF_FLAGS_SPOOF_NOTICE         0x00000080
+#define CONF_FLAGS_REDIR                0x00000100
+#define CONF_FLAGS_EXEMPTGLINE          0x00000200
+#define CONF_FLAGS_CAN_FLOOD            0x00000400
+#define CONF_FLAGS_NEED_PASSWORD        0x00000800
+#define CONF_FLAGS_ALLOW_AUTO_CONN      0x00001000
+#define CONF_FLAGS_ENCRYPTED            0x00002000
+#define CONF_FLAGS_IN_DATABASE          0x00004000
+#define CONF_FLAGS_EXEMPTRESV           0x00008000
+#define CONF_FLAGS_SSL                  0x00010000
+#define CONF_FLAGS_WEBIRC               0x00020000
 
 /* Macros for struct MaskItem */
 #define IsConfWebIRC(x)         ((x)->flags & CONF_FLAGS_WEBIRC)
-#define IsLimitIp(x)            ((x)->flags & CONF_FLAGS_LIMIT_IP)
 #define IsNoTilde(x)            ((x)->flags & CONF_FLAGS_NO_TILDE)
 #define IsConfCanFlood(x)       ((x)->flags & CONF_FLAGS_CAN_FLOOD)
 #define IsNeedPassword(x)       ((x)->flags & CONF_FLAGS_NEED_PASSWORD)
 #define IsNeedIdentd(x)         ((x)->flags & CONF_FLAGS_NEED_IDENTD)
-#define IsNoMatchIp(x)          ((x)->flags & CONF_FLAGS_NOMATCH_IP)
 #define IsConfExemptKline(x)    ((x)->flags & CONF_FLAGS_EXEMPTKLINE)
 #define IsConfExemptLimits(x)   ((x)->flags & CONF_FLAGS_NOLIMIT)
 #define IsConfExemptGline(x)    ((x)->flags & CONF_FLAGS_EXEMPTGLINE)
@@ -88,7 +86,7 @@
 #define SetConfDatabase(x)     ((x)->flags |= CONF_FLAGS_IN_DATABASE)
 
 
-/* shared/cluster server entry types 
+/* shared/cluster server entry types
  * These defines are used for both shared and cluster.
  */
 #define SHARED_KLINE            0x0001
@@ -108,20 +106,28 @@
 
 enum maskitem_type
 {
-  CONF_RESERVED = 1 <<  0, /* XXX */
-  CONF_CLIENT   = 1 <<  1,
-  CONF_SERVER   = 1 <<  2,
-  CONF_KLINE    = 1 <<  3,
-  CONF_DLINE    = 1 <<  4,
-  CONF_EXEMPT   = 1 <<  5,
-  CONF_CLUSTER  = 1 <<  6,
-  CONF_XLINE    = 1 <<  7,
-  CONF_ULINE    = 1 <<  8,
-  CONF_GLINE    = 1 <<  9,
-  CONF_CRESV    = 1 << 10,
-  CONF_NRESV    = 1 << 11,
-  CONF_SERVICE  = 1 << 12,
-  CONF_OPER     = 1 << 13,
+  CONF_CLIENT   = 1 <<  0,
+  CONF_SERVER   = 1 <<  1,
+  CONF_KLINE    = 1 <<  2,
+  CONF_DLINE    = 1 <<  3,
+  CONF_EXEMPT   = 1 <<  4,
+  CONF_CLUSTER  = 1 <<  5,
+  CONF_XLINE    = 1 <<  6,
+  CONF_ULINE    = 1 <<  7,
+  CONF_GLINE    = 1 <<  8,
+  CONF_CRESV    = 1 <<  9,
+  CONF_NRESV    = 1 << 10,
+  CONF_SERVICE  = 1 << 11,
+  CONF_OPER     = 1 << 12,
+};
+
+enum
+{
+  NOT_AUTHORIZED = -1,
+  I_LINE_FULL    = -2,
+  TOO_MANY       = -3,
+  BANNED_CLIENT  = -4,
+  TOO_FAST       = -5
 };
 
 struct conf_parser_context
@@ -376,9 +382,9 @@ extern void conf_add_class_to_conf(struct MaskItem *, const char *);
 extern const char *get_oper_name(const struct Client *);
 
 /* XXX should the parse_aline stuff go into another file ?? */
-#define AWILD 0x1		/* check wild cards */
+#define AWILD 0x1  /* check wild cards */
 extern int parse_aline(const char *, struct Client *, int, char **,
-		       int, char **, char **, time_t *, char **, char **);
+                       int, char **, char **, time_t *, char **, char **);
 extern int valid_comment(struct Client *, char *, int);
 
 
@@ -387,14 +393,7 @@ extern int valid_comment(struct Client *, char *, int);
 extern time_t valid_tkline(const char *, const int);
 extern int match_conf_password(const char *, const struct MaskItem *);
 
-#define NOT_AUTHORIZED    (-1)
-#define I_LINE_FULL       (-2)
-#define TOO_MANY          (-3)
-#define BANNED_CLIENT     (-4)
-#define TOO_FAST          (-5)
-
 #define CLEANUP_TKLINES_TIME 60
 
-extern void cluster_a_line(struct Client *,
-			   const char *, int, int, const char *,...);
+extern void cluster_a_line(struct Client *, const char *, int, int, const char *,...);
 #endif /* INCLUDED_s_conf_h */
