@@ -1,7 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,17 +21,19 @@
 
 /*! \file
  * \brief Configuration managment for class{} blocks
- * \version $Id: conf_class.h 1785 2013-01-26 22:40:55Z michael $
+ * \version $Id: conf_class.h 3088 2014-03-01 18:47:05Z michael $
  */
 
 
 #ifndef INCLUDED_conf_class_h
 #define INCLUDED_conf_class_h
 
-#define CLASS_FLAGS_FAKE_IDLE            0x01
-#define CLASS_FLAGS_RANDOM_IDLE          0x02
-#define CLASS_FLAGS_HIDE_IDLE_FROM_OPERS 0x04
-
+enum
+{
+  CLASS_FLAGS_FAKE_IDLE            = 1 << 0,
+  CLASS_FLAGS_RANDOM_IDLE          = 1 << 1,
+  CLASS_FLAGS_HIDE_IDLE_FROM_OPERS = 1 << 2
+};
 
 struct ClassItem
 {
