@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  hostmask.h: A header for the hostmask code.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2005 by the past and present ircd coders, and others.
+ *  Copyright (c) 2001-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,12 +17,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: hostmask.h 1644 2012-11-06 22:20:16Z michael $
+ */
+
+/*! \file hostmask.h
+ * \brief A header for the hostmask code.
+ * \version $Id: hostmask.h 2866 2014-01-19 14:35:59Z michael $
  */
 
 #ifndef INCLUDE_hostmask_h
-#define INCLUDE_hostmask_h 1
+#define INCLUDE_hostmask_h
 
 #define ATABLE_SIZE 0x1000
 
@@ -72,7 +74,7 @@ extern int match_ipv4(const struct irc_ssaddr *, const struct irc_ssaddr *, int)
 
 extern void mask_addr(struct irc_ssaddr *, int);
 extern void init_host_hash(void);
-extern void add_conf_by_address(const unsigned int, struct MaskItem *);
+extern struct AddressRec *add_conf_by_address(const unsigned int, struct MaskItem *);
 extern void delete_one_address_conf(const char *, struct MaskItem *);
 extern void clear_out_address_conf(void);
 extern void hostmask_expire_temporary(void);
