@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  ircd_getopt.h: A header for the getopt() command line option calls.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 2001-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,14 +17,18 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: ircd_getopt.h 1357 2012-04-21 20:47:01Z michael $
+ */
+
+/*! \file ircd_getopt.h
+ * \brief A header for the getopt() command line option calls.
+ * \version $Id: ircd_getopt.h 2866 2014-01-19 14:35:59Z michael $
  */
 
 #ifndef __GETOPT_H_INCLUDED__
 #define __GETOPT_H_INCLUDED__
 
-struct lgetopt {
+struct lgetopt
+{
   const char *opt; /* name of the argument */
   void *argloc; /* where we store the argument to it (-option argument) */
   enum { INTEGER, YESNO, STRING, USAGE, ENDEBUG } argtype;
