@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2007-2012, The Tor Project, Inc.
+ * Copyright (c) 2012-2014 ircd-hybrid development team
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -32,7 +33,7 @@
 
 /*! \file mempool.h
  * \brief Pooling allocator
- * \version $Id: mempool.h 1662 2012-11-17 20:11:33Z michael $
+ * \version $Id: mempool.h 2918 2014-01-25 21:16:58Z michael $
  */
 
 #ifndef TOR_MEMPOOL_H
@@ -55,7 +56,8 @@ extern void mp_pool_garbage_collect(void *);
 
 #define MEMPOOL_STATS
 
-struct mp_pool_t {
+struct mp_pool_t
+{
   /** Next pool. A pool is usually linked into the mp_allocated_pools list. */
   mp_pool_t *next;
 
