@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  modules.h: A header for the modules functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 2000-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,18 +17,21 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: modules.h 1737 2013-01-14 17:37:55Z michael $
+ */
+
+/*! \file modules.h
+ * \brief A header for the modules functions.
+ * \version $Id: modules.h 3090 2014-03-01 18:50:32Z michael $
  */
 
 #ifndef INCLUDED_modules_h
 #define INCLUDED_modules_h
 
-#include "config.h"
-
-
-#define MODULE_FLAG_CORE     0x1
-#define MODULE_FLAG_NOUNLOAD 0x2
+enum
+{
+  MODULE_FLAG_CORE     = 1 << 0,
+  MODULE_FLAG_NOUNLOAD = 1 << 1
+};
 
 struct module
 {
@@ -48,8 +50,8 @@ struct module_path
   char path[HYB_PATH_MAX + 1];
 };
 
-extern dlink_list modules_list;
 
+extern dlink_list *modules_get_list(void);
 /* add a path */
 extern void mod_add_path(const char *);
 extern void mod_clear_paths(void);
