@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  s_gline.h: A header for the gline functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: s_gline.h 1798 2013-03-31 17:09:50Z michael $
+ */
+
+/*! \file s_gline.h
+ * \brief A header for the gline functions.
+ * \version $Id: s_gline.h 2866 2014-01-19 14:35:59Z michael $
  */
 
 #ifndef INCLUDED_s_gline_h
@@ -41,7 +43,8 @@ struct gline_pending
 {
   dlink_node node;
 
-  struct {
+  struct
+  {
     char oper_nick[NICKLEN + 1];
     char oper_user[USERLEN + 1];
     char oper_host[HOSTLEN + 1];
