@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  s_user.h: A header for the user functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: s_user.h 2136 2013-05-29 19:36:51Z michael $
+ */
+
+/*! \file s_user.h
+ * \brief A header for the user functions.
+ * \version $Id: s_user.h 2956 2014-01-28 16:41:18Z michael $
  */
 
 #ifndef INCLUDED_s_user_h
@@ -45,7 +47,7 @@ extern void oper_up(struct Client *);
 extern void register_local_user(struct Client *);
 extern void register_remote_user(struct Client *,
                                  const char *, const char *,
-                                 const char *, const char *);
+                                 const char *);
 extern void init_uid(void);
 extern int valid_sid(const char *);
 extern int valid_hostname(const char *);
@@ -56,5 +58,4 @@ extern void delete_isupport(const char *);
 extern void init_isupport(void);
 extern void rebuild_isupport_message_line(void);
 extern void user_set_hostmask(struct Client *, const char *, const int);
-
 #endif
