@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  send.h: A header for the message sending functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: send.h 2564 2013-11-17 18:20:52Z michael $
+ */
+
+/*! \file send.h
+ * \brief A header for the message sending functions.
+ * \version $Id: send.h 3077 2014-02-28 20:33:31Z michael $
  */
 
 #ifndef INCLUDED_send_h
@@ -27,27 +29,37 @@
 
 #include "fdlist.h"
 
-#define ALL_MEMBERS  0
-#define NON_CHANOPS  1
-#define ONLY_CHANOPS_VOICED  2
-#define ONLY_CHANOPS 3
-#define ONLY_SERVERS 4 /* for channel_mode.c */
+enum { NOCAPS = 0 };
 
-#define L_ALL   0
-#define L_OPER  1
-#define L_ADMIN 2
+enum
+{
+  ALL_MEMBERS         = 0,
+  NON_CHANOPS         = 1,
+  ONLY_CHANOPS_VOICED = 2,
+  ONLY_CHANOPS        = 3,
+  ONLY_SERVERS        = 4
+};
 
-#define SEND_NOTICE 1
-#define SEND_GLOBAL 2
-#define SEND_LOCOPS 3
+enum
+{
+  L_ALL   = 0,
+  L_OPER  = 1,
+  L_ADMIN = 2
+};
 
-#define NOCAPS          0               /* no caps */
-#define NOFLAGS         0               /* no flags */
+enum
+{
+  SEND_NOTICE = 1,
+  SEND_GLOBAL = 2,
+  SEND_LOCOPS = 3
+};
 
 /* used when sending to #mask or $mask */
-#define MATCH_SERVER  1
-#define MATCH_HOST    2
-
+enum
+{
+  MATCH_SERVER = 1,
+  MATCH_HOST   = 2
+};
 
 /*
  * struct decls
@@ -69,13 +81,10 @@ extern void sendto_channel_local(unsigned int, int, struct Channel *,
                                  const char *, ...) AFP(4,5);
 extern void sendto_channel_local_butone(struct Client *, unsigned int, unsigned int, struct Channel *,
                                         const char *, ...) AFP(5,6);
-extern void sendto_channel_remote(struct Client *, struct Client *, unsigned int,
-                                  const unsigned int, const unsigned int,
-                                  struct Channel *, const char *, ...) AFP(7,8);
 extern void sendto_server(struct Client *,
                           const unsigned int,
                           const unsigned int, const char *, ...) AFP(4,5);
-extern void sendto_match_butone(struct Client *, struct Client *, 
+extern void sendto_match_butone(struct Client *, struct Client *,
                                 char *, int, const char *, ...) AFP(5,6);
 extern void sendto_match_servs(struct Client *, const char *, unsigned int,
                                const char *, ...) AFP(4,5);
@@ -83,10 +92,11 @@ extern void sendto_realops_flags(unsigned int, int, int,
                                  const char *, ...) AFP(4,5);
 extern void sendto_wallops_flags(unsigned int, struct Client *,
                                  const char *, ...) AFP(3,4);
-extern void ts_warn(const char *, ...) AFP(1,2);
+extern void sendto_realops_flags_ratelimited(const char *, ...) AFP(1,2);
 
-extern void sendto_anywhere(struct Client *, struct Client *, 
-                            const char *, ...) AFP(3,4);
+extern void sendto_anywhere(struct Client *, struct Client *,
+                            const char *,
+                            const char *, ...) AFP(4,5);
 extern void kill_client(struct Client *, struct Client *,
                         const char *, ... ) AFP(3,4);
 extern void kill_client_serv_butone(struct Client *, struct Client *,
