@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_die.c: Kills off this server.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_die.c 1834 2013-04-19 19:50:27Z michael $
+ */
+
+/*! \file m_die.c
+ * \brief Includes required functions for processing the DIE command.
+ * \version $Id: m_die.c 2821 2014-01-15 23:12:35Z michael $
  */
 
 #include "stdinc.h"
@@ -37,7 +39,7 @@
 /*
  * mo_die - DIE command handler
  */
-static void
+static int
 mo_die(struct Client *client_p, struct Client *source_p,
        int parc, char *parv[])
 {
@@ -47,31 +49,33 @@ mo_die(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOPRIVS),
                me.name, source_p->name, "die");
-    return;
+    return 0;
   }
 
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one(source_p, ":%s NOTICE %s :Need server name /die %s",
                me.name, source_p->name, me.name);
-    return;
+    return 0;
   }
 
   if (irccmp(parv[1], me.name))
   {
     sendto_one(source_p, ":%s NOTICE %s :Mismatch on /die %s",
                me.name, source_p->name, me.name);
-    return;
+    return 0;
   }
 
   snprintf(buf, sizeof(buf), "received DIE command from %s",
            get_oper_name(source_p));
   server_die(buf, 0);
+  return 0;
 }
 
-static struct Message die_msgtab = {
+static struct Message die_msgtab =
+{
   "DIE", 0, 0, 1, MAXPARA, MFLG_SLOW, 0,
-  {m_unregistered, m_not_oper, m_ignore, m_ignore, mo_die, m_ignore}
+  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_die, m_ignore }
 };
 
 static void
@@ -86,10 +90,11 @@ module_exit(void)
   mod_del_cmd(&die_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 1834 $",
+  .version = "$Revision: 2821 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
