@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_kick.c: Kicks a user from a channel.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_kick.c 2476 2013-10-13 18:50:07Z michael $
+ */
+
+/*! \file m_kick.c
+ * \brief Includes required functions for processing the KICK command.
+ * \version $Id: m_kick.c 3293 2014-04-10 17:23:37Z michael $
  */
 
 #include "stdinc.h"
@@ -44,20 +46,16 @@
  *  parv[2] = client to kick
  *  parv[3] = kick comment
  */
-static void 
+static int
 m_kick(struct Client *client_p, struct Client *source_p,
        int parc, char *parv[])
 {
-  struct Client *who;
-  struct Channel *chptr;
-  int chasing = 0;
-  char *comment;
-  char *name;
-  char *p = NULL;
-  char *user;
+  struct Client *target_p = NULL;
+  struct Channel *chptr = NULL;
+  char *comment = NULL;
   const char *from, *to;
-  struct Membership *ms = NULL;
-  struct Membership *ms_target;
+  struct Membership *ms_source = NULL;
+  struct Membership *ms_target = NULL;
 
   if (!MyConnect(source_p) && IsCapable(source_p->from, CAP_TS6) && HasID(source_p))
   {
@@ -74,58 +72,48 @@ m_kick(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                from, to, "KICK");
-    return;
+    return 0;
   }
 
   if (MyClient(source_p) && !IsFloodDone(source_p))
     flood_endgrace(source_p);
 
-  comment = (EmptyString(parv[3])) ? source_p->name : parv[3];
-  if (strlen(comment) > (size_t)KICKLEN)
-    comment[KICKLEN] = '\0';
-
-  name = parv[1];
-  if ((p = strchr(name,',')) != NULL)
-    *p = '\0';
-  if (*name == '\0')
-    return;
-
-  if ((chptr = hash_find_channel(name)) == NULL)
+  if ((chptr = hash_find_channel(parv[1])) == NULL)
   {
     sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
-               from, to, name);
-    return;
+               from, to, parv[1]);
+    return 0;
   }
 
   if (!IsServer(source_p) && !HasFlag(source_p, FLAGS_SERVICE))
   {
-    if ((ms = find_channel_link(source_p, chptr)) == NULL)
+    if ((ms_source = find_channel_link(source_p, chptr)) == NULL)
     {
       if (MyConnect(source_p))
       {
         sendto_one(source_p, form_str(ERR_NOTONCHANNEL),
-                   me.name, source_p->name, name);
-        return;
+                   me.name, source_p->name, chptr->chname);
+        return 0;
       }
     }
 
-    if (!has_member_flags(ms, CHFL_CHANOP|CHFL_HALFOP))
+    if (!has_member_flags(ms_source, CHFL_CHANOP|CHFL_HALFOP))
     {
       /* was a user, not a server, and user isn't seen as a chanop here */
       if (MyConnect(source_p))
       {
         /* user on _my_ server, with no chanops.. so go away */
         sendto_one(source_p, form_str(ERR_CHANOPRIVSNEEDED),
-                   me.name, source_p->name, name);
-        return;
+                   me.name, source_p->name, chptr->chname);
+        return 0;
       }
 
       if (chptr->channelts == 0)
       {
-        /* If its a TS 0 channel, do it the old way */         
+        /* If its a TS 0 channel, do it the old way */
         sendto_one(source_p, form_str(ERR_CHANOPRIVSNEEDED),
-                   from, to, name);
-        return;
+                   from, to, chptr->chname);
+        return 0;
       }
 
       /* Its a user doing a kick, but is not showing as chanop locally
@@ -133,12 +121,12 @@ m_kick(struct Client *client_p, struct Client *source_p,
        * There are two cases we can get to this point then...
        *
        *     1) connect burst is happening, and for some reason a legit
-       *        op has sent a KICK, but the SJOIN hasn't happened yet or 
+       *        op has sent a KICK, but the SJOIN hasn't happened yet or
        *        been seen. (who knows.. due to lag...)
        *
        *     2) The channel is desynced. That can STILL happen with TS
-       *        
-       *     Now, the old code roger wrote, would allow the KICK to 
+       *
+       *     Now, the old code roger wrote, would allow the KICK to
        *     go through. Thats quite legit, but lets weird things like
        *     KICKS by users who appear not to be chanopped happen,
        *     or even neater, they appear not to be on the channel.
@@ -151,32 +139,29 @@ m_kick(struct Client *client_p, struct Client *source_p,
     }
   }
 
-  user = parv[2];
-  if ((p = strchr(user, ',')) != NULL)
-    *p = '\0';
+  if ((target_p = find_chasing(source_p, parv[2])) == NULL)
+    return 0;
 
-  if (*user == '\0')
-    return;
-
-  if ((who = find_chasing(source_p, user, &chasing)) == NULL)
-    return;
-
-  if ((ms_target = find_channel_link(who, chptr)) != NULL)
+  if ((ms_target = find_channel_link(target_p, chptr)) != NULL)
   {
 #ifdef HALFOPS
     /* half ops cannot kick other halfops on private channels */
-    if (has_member_flags(ms, CHFL_HALFOP) && !has_member_flags(ms, CHFL_CHANOP))
+    if (has_member_flags(ms_source, CHFL_HALFOP) && !has_member_flags(ms_source, CHFL_CHANOP))
     {
       if (((chptr->mode.mode & MODE_PRIVATE) && has_member_flags(ms_target,
         CHFL_CHANOP|CHFL_HALFOP)) || has_member_flags(ms_target, CHFL_CHANOP))
       {
         sendto_one(source_p, form_str(ERR_CHANOPRIVSNEEDED),
-                   me.name, source_p->name, name);
-        return;
+                   me.name, source_p->name, chptr->chname);
+        return 0;
       }
     }
 #endif
 
+  comment = (EmptyString(parv[3])) ? source_p->name : parv[3];
+  if (strlen(comment) > (size_t)KICKLEN)
+    comment[KICKLEN] = '\0';
+
     /* jdc
      * - In the case of a server kicking a user (i.e. CLEARCHAN),
      *   the kick should show up as coming from the server which did
@@ -186,29 +171,31 @@ m_kick(struct Client *client_p, struct Client *source_p,
      */
     if (IsServer(source_p))
       sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s KICK %s %s :%s",
-                           source_p->name, name, who->name, comment);
+                           source_p->name, chptr->chname, target_p->name, comment);
     else
       sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s KICK %s %s :%s",
                            source_p->name, source_p->username,
-                           source_p->host, name, who->name, comment);
+                           source_p->host, chptr->chname, target_p->name, comment);
 
     sendto_server(client_p, CAP_TS6, NOCAPS,
                   ":%s KICK %s %s :%s",
-                  ID(source_p), chptr->chname, ID(who), comment);
+                  ID(source_p), chptr->chname, ID(target_p), comment);
     sendto_server(client_p, NOCAPS, CAP_TS6,
                   ":%s KICK %s %s :%s", source_p->name, chptr->chname,
-                  who->name, comment);
+                  target_p->name, comment);
 
     remove_user_from_channel(ms_target);
   }
   else
     sendto_one(source_p, form_str(ERR_USERNOTINCHANNEL),
-               from, to, user, name);
+               from, to, target_p->name, chptr->chname);
+  return 0;
 }
 
-static struct Message kick_msgtab = {
+static struct Message kick_msgtab =
+{
   "KICK", 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  {m_unregistered, m_kick, m_kick, m_ignore, m_kick, m_ignore}
+  { m_unregistered, m_kick, m_kick, m_ignore, m_kick, m_ignore }
 };
 
 static void
@@ -223,10 +210,11 @@ module_exit(void)
   mod_del_cmd(&kick_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2476 $",
+  .version = "$Revision: 3293 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
