@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_mode.c: Sets a user or channel mode.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_mode.c 2643 2013-12-10 19:19:08Z michael $
+ */
+
+/*! \file m_mode.c
+ * \brief Includes required functions for processing the MODE/TMODE/BMASK command.
+ * \version $Id: m_mode.c 3043 2014-02-25 21:10:08Z michael $
  */
 
 #include "stdinc.h"
@@ -45,7 +47,7 @@
  * parv[0] - sender
  * parv[1] - channel
  */
-static void
+static int
 m_mode(struct Client *client_p, struct Client *source_p,
        int parc, char *parv[])
 {
@@ -58,7 +60,7 @@ m_mode(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "MODE");
-    return;
+    return 0;
   }
 
   /* Now, try to find the channel in question */
@@ -66,16 +68,16 @@ m_mode(struct Client *client_p, struct Client *source_p,
   {
     /* if here, it has to be a non-channel name */
     set_user_mode(client_p, source_p, parc, parv);
-    return;
+    return 0;
   }
 
   if ((chptr = hash_find_channel(parv[1])) == NULL)
   {
     sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
-	       ID_or_name(&me, source_p->from),
-	       ID_or_name(source_p, source_p->from),
-	       parv[1]);
-    return;
+               ID_or_name(&me, source_p),
+               ID_or_name(source_p, source_p),
+               parv[1]);
+    return 0;
   }
 
   /* Now known the channel exists */
@@ -86,7 +88,7 @@ m_mode(struct Client *client_p, struct Client *source_p,
                me.name, source_p->name, chptr->chname, modebuf, parabuf);
     sendto_one(source_p, form_str(RPL_CREATIONTIME),
                me.name, source_p->name, chptr->chname, chptr->channelts);
-    return;
+    return 0;
   }
 
   /*
@@ -95,8 +97,7 @@ m_mode(struct Client *client_p, struct Client *source_p,
    * including telnet servers *g* - Dianora
    */
   if (IsServer(source_p) || HasFlag(source_p, FLAGS_SERVICE))
-    set_channel_mode(client_p, source_p, chptr, NULL, parc - 2, parv + 2,
-                     chptr->chname);
+    set_channel_mode(client_p, source_p, chptr, NULL, parc - 2, parv + 2);
   else
   {
     member = find_channel_link(source_p, chptr);
@@ -108,10 +109,11 @@ m_mode(struct Client *client_p, struct Client *source_p,
         if (!((parc == 3) && (parv[2][0] == 'b') && (parv[2][1] == '\0')))
           flood_endgrace(source_p);
 
-      set_channel_mode(client_p, source_p, chptr, member, parc - 2, parv + 2,
-                       chptr->chname);
+      set_channel_mode(client_p, source_p, chptr, member, parc - 2, parv + 2);
     }
   }
+
+  return 0;
 }
 
 /*
@@ -122,7 +124,7 @@ m_mode(struct Client *client_p, struct Client *source_p,
  *		  parv[2] = channel name
  *		  parv[3] = modestring
  */
-static void
+static int
 ms_tmode(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
@@ -132,24 +134,26 @@ ms_tmode(struct Client *client_p, struct Client *source_p, int parc, char *parv[
   {
     sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
                ID_or_name(&me, client_p), ID_or_name(source_p, client_p), parv[2]);
-    return;
+    return 0;
   }
 
   if (atol(parv[1]) > chptr->channelts)
-    return;
+    return 0;
 
   if (IsServer(source_p) || HasFlag(source_p, FLAGS_SERVICE))
-    set_channel_mode(client_p, source_p, chptr, NULL, parc - 3, parv + 3, chptr->chname);
+    set_channel_mode(client_p, source_p, chptr, NULL, parc - 3, parv + 3);
   else
   {
     member = find_channel_link(source_p, chptr);
 
     /* XXX are we sure we just want to bail here? */
     if (has_member_flags(member, CHFL_DEOPPED))
-      return;
+      return 0;
 
-    set_channel_mode(client_p, source_p, chptr, member, parc - 3, parv + 3, chptr->chname);
+    set_channel_mode(client_p, source_p, chptr, member, parc - 3, parv + 3);
   }
+
+  return 0;
 }
 
 /*
@@ -165,25 +169,24 @@ ms_tmode(struct Client *client_p, struct Client *source_p, int parc, char *parv[
  *		  sends plain modes to the others.  nothing is sent
  *		  to the server the issuing server is connected through
  */
-static void
+static int
 ms_bmask(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
 {
-  static char modebuf[IRCD_BUFSIZE];
-  static char parabuf[IRCD_BUFSIZE];
-  static char banbuf[IRCD_BUFSIZE];
+  char modebuf[IRCD_BUFSIZE];
+  char parabuf[IRCD_BUFSIZE];
+  char banbuf[IRCD_BUFSIZE];
   struct Channel *chptr;
   char *s, *t, *mbuf, *pbuf;
-  long mode_type;
+  unsigned int mode_type = 0;
   int mlen, tlen;
   int modecount = 0;
-  int needcap = NOCAPS;
 
   if ((chptr = hash_find_channel(parv[2])) == NULL)
-    return;
+    return 0;
 
   /* TS is higher, drop it. */
   if (atol(parv[1]) > chptr->channelts)
-    return;
+    return 0;
 
   switch (*parv[3])
   {
@@ -193,17 +196,15 @@ ms_bmask(struct Client *client_p, struct Client *source_p, int parc, char *parv[
 
     case 'e':
       mode_type = CHFL_EXCEPTION;
-      needcap = CAP_EX;
       break;
 
     case 'I':
       mode_type = CHFL_INVEX;
-      needcap = CAP_IE;
       break;
 
     /* maybe we should just blindly propagate this? */
     default:
-      return; 
+      return 0;
   }
 
   parabuf[0] = '\0';
@@ -217,12 +218,13 @@ ms_bmask(struct Client *client_p, struct Client *source_p, int parc, char *parv[
   mbuf = modebuf + mlen;
   pbuf = parabuf;
 
-  do {
-    if ((t = strchr(s, ' ')) != NULL)
+  do
+  {
+    if ((t = strchr(s, ' ')))
       *t++ = '\0';
     tlen = strlen(s);
 
-    /* I dont even want to begin parsing this.. */
+    /* I don't even want to begin parsing this.. */
     if (tlen > MODEBUFLEN)
       break;
 
@@ -237,7 +239,7 @@ ms_bmask(struct Client *client_p, struct Client *source_p, int parc, char *parv[
 
         sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s",
                              modebuf, parabuf);
-        sendto_server(client_p, needcap, CAP_TS6,
+        sendto_server(client_p, NOCAPS, CAP_TS6,
                       "%s %s", modebuf, parabuf);
 
         mbuf = modebuf + mlen;
@@ -257,30 +259,33 @@ ms_bmask(struct Client *client_p, struct Client *source_p, int parc, char *parv[
   {
     *mbuf = *(pbuf - 1) = '\0';
     sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", modebuf, parabuf);
-    sendto_server(client_p, needcap, CAP_TS6,
+    sendto_server(client_p, NOCAPS, CAP_TS6,
                   "%s %s", modebuf, parabuf);
   }
 
   /* assumption here is that since the server sent BMASK, they are TS6, so they have an ID */
-  sendto_server(client_p, CAP_TS6|needcap, NOCAPS,
-                ":%s BMASK %lu %s %s :%s",
+  sendto_server(client_p, CAP_TS6, NOCAPS, ":%s BMASK %lu %s %s :%s",
                 source_p->id, (unsigned long)chptr->channelts, chptr->chname,
                 parv[3], parv[4]);
+  return 0;
 }
 
-static struct Message mode_msgtab = {
+static struct Message mode_msgtab =
+{
   "MODE", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  {m_unregistered, m_mode, m_mode, m_ignore, m_mode, m_ignore}
+  { m_unregistered, m_mode, m_mode, m_ignore, m_mode, m_ignore }
 };
 
-static struct Message tmode_msgtab = {
+static struct Message tmode_msgtab =
+{
   "TMODE", 0, 0, 4, MAXPARA, MFLG_SLOW, 0,
-  {m_ignore, m_ignore, ms_tmode, m_ignore, m_ignore, m_ignore}
+  { m_ignore, m_ignore, ms_tmode, m_ignore, m_ignore, m_ignore }
 };
 
-static struct Message bmask_msgtab = {
+static struct Message bmask_msgtab =
+{
   "BMASK", 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  {m_ignore, m_ignore, ms_bmask, m_ignore, m_ignore, m_ignore}
+  { m_ignore, m_ignore, ms_bmask, m_ignore, m_ignore, m_ignore }
 };
 
 static void
@@ -299,10 +304,11 @@ module_exit(void)
   mod_del_cmd(&bmask_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2643 $",
+  .version = "$Revision: 3043 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
