@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_part.c: Parts a user from a channel.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_part.c 2006 2013-05-12 12:37:49Z michael $
+ */
+
+/*! \file m_part.c
+ * \brief Includes required functions for processing the PART command.
+ * \version $Id: m_part.c 3223 2014-03-28 17:16:24Z michael $
  */
 
 #include "stdinc.h"
@@ -45,7 +47,7 @@
  * 		- pointer to source client to remove
  *		- char pointer of name of channel to remove from
  * output	- none
- * side effects	- remove ONE client given the channel name 
+ * side effects	- remove ONE client given the channel name
  */
 static void
 part_one_client(struct Client *source_p, const char *name, const char *reason)
@@ -62,8 +64,8 @@ part_one_client(struct Client *source_p, const char *name, const char *reason)
 
   if ((ms = find_channel_link(source_p, chptr)) == NULL)
   {
-    sendto_one(source_p, form_str(ERR_NOTONCHANNEL),
-               me.name, source_p->name, name);
+    sendto_one(source_p, form_str(ERR_NOTONCHANNEL), me.name,
+               source_p->name, chptr->chname);
     return;
   }
 
@@ -79,22 +81,20 @@ part_one_client(struct Client *source_p, const char *name, const char *reason)
        (source_p->localClient->firsttime + ConfigFileEntry.anti_spam_exit_message_time)
         < CurrentTime))))
   {
-    sendto_server(source_p->from, CAP_TS6, NOCAPS,
-                  ":%s PART %s :%s", ID(source_p), chptr->chname,
-                  reason);
-    sendto_server(source_p->from, NOCAPS, CAP_TS6,
-                  ":%s PART %s :%s", source_p->name, chptr->chname,
-                  reason);
+    sendto_server(source_p->from, CAP_TS6, NOCAPS, ":%s PART %s :%s",
+                  ID(source_p), chptr->chname, reason);
+    sendto_server(source_p->from, NOCAPS, CAP_TS6, ":%s PART %s :%s",
+                  source_p->name, chptr->chname, reason);
     sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s PART %s :%s",
                          source_p->name, source_p->username,
                          source_p->host, chptr->chname, reason);
   }
   else
   {
-    sendto_server(source_p->from, CAP_TS6, NOCAPS,
-                  ":%s PART %s", ID(source_p), chptr->chname);
-    sendto_server(source_p->from, NOCAPS, CAP_TS6,
-                  ":%s PART %s", source_p->name, chptr->chname);
+    sendto_server(source_p->from, CAP_TS6, NOCAPS, ":%s PART %s",
+                  ID(source_p), chptr->chname);
+    sendto_server(source_p->from, NOCAPS, CAP_TS6, ":%s PART %s",
+                  source_p->name, chptr->chname);
     sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s PART %s",
                          source_p->name, source_p->username,
                          source_p->host, chptr->chname);
@@ -109,21 +109,18 @@ part_one_client(struct Client *source_p, const char *name, const char *reason)
 **      parv[1] = channel
 **      parv[2] = reason
 */
-static void
+static int
 m_part(struct Client *client_p, struct Client *source_p,
        int parc, char *parv[])
 {
   char *p = NULL, *name = NULL;
   char reason[KICKLEN + 1] = { '\0' };
 
-  if (IsServer(source_p))
-    return;
-
   if (EmptyString(parv[1]))
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "PART");
-    return;
+    return 0;
   }
 
   if (parc > 2 && !EmptyString(parv[2]))
@@ -136,9 +133,11 @@ m_part(struct Client *client_p, struct Client *source_p,
   for (name = strtoken(&p, parv[1], ","); name;
        name = strtoken(&p,    NULL, ","))
     part_one_client(source_p, name, reason);
+  return 0;
 }
 
-static struct Message part_msgtab = {
+static struct Message part_msgtab =
+{
   "PART", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_part, m_part, m_ignore, m_part, m_ignore }
 };
@@ -155,10 +154,11 @@ module_exit(void)
   mod_del_cmd(&part_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2006 $",
+  .version = "$Revision: 3223 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
