@@ -1,7 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_admin.c
  * \brief Includes required functions for processing the ADMIN command.
- * \version $Id: m_admin.c 2342 2013-07-03 13:59:41Z michael $
+ * \version $Id: m_admin.c 2992 2014-02-18 12:10:13Z michael $
  */
 
 #include "stdinc.h"
@@ -44,8 +44,8 @@
 static void
 do_admin(struct Client *source_p)
 {
-  const char *me_name = ID_or_name(&me, source_p->from);
-  const char *nick = ID_or_name(source_p, source_p->from);
+  const char *me_name = ID_or_name(&me, source_p);
+  const char *nick = ID_or_name(source_p, source_p);
 
   sendto_realops_flags(UMODE_SPY, L_ALL, SEND_NOTICE,
                        "ADMIN requested by %s (%s@%s) [%s]",
@@ -66,7 +66,7 @@ do_admin(struct Client *source_p)
                me_name, nick, AdminInfo.email);
 }
 
-/*! \brief NICK command handler (called by already registered,
+/*! \brief ADMIN command handler (called by already registered,
  *         locally connected clients)
  *
  * \param client_p Pointer to allocated Client struct with physical connection
@@ -80,7 +80,7 @@ do_admin(struct Client *source_p)
  *      - parv[0] = sender prefix
  *      - parv[1] = nickname/servername
  */
-static void
+static int
 m_admin(struct Client *client_p, struct Client *source_p,
         int parc, char *parv[])
 {
@@ -90,7 +90,7 @@ m_admin(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p,form_str(RPL_LOAD2HI),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   last_used = CurrentTime;
@@ -98,9 +98,10 @@ m_admin(struct Client *client_p, struct Client *source_p,
   if (!ConfigServerHide.disable_remote_commands)
     if (hunt_server(client_p, source_p, ":%s ADMIN :%s", 1,
                     parc, parv) != HUNTED_ISME)
-      return;
+      return 0;
 
   do_admin(source_p);
+  return 0;
 }
 
 /*! \brief ADMIN command handler (called by operators and
@@ -117,18 +118,20 @@ m_admin(struct Client *client_p, struct Client *source_p,
  *      - parv[0] = sender prefix
  *      - parv[1] = nickname/servername
  */
-static void
+static int
 ms_admin(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
   if (hunt_server(client_p, source_p, ":%s ADMIN :%s", 1,
                   parc, parv) != HUNTED_ISME)
-    return;
+    return 0;
 
   do_admin(source_p);
+  return 0;
 }
 
-static struct Message admin_msgtab = {
+static struct Message admin_msgtab =
+{
   "ADMIN", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_admin, ms_admin, m_ignore, ms_admin, m_ignore }
 };
@@ -145,10 +148,11 @@ module_exit(void)
   mod_del_cmd(&admin_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry = 
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2342 $",
+  .version = "$Revision: 2992 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
