@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_capab.c: Negotiates capabilities with a remote server.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1998-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_capab.c 2526 2013-11-02 17:07:55Z michael $
+ */
+
+/*! \file m_capab.c
+ * \brief Includes required functions for processing the CAPAB command.
+ * \version $Id: m_capab.c 3309 2014-04-14 20:16:55Z michael $
  */
 
 #include "stdinc.h"
@@ -37,31 +39,32 @@
  *      parv[1] = space-separated list of capabilities
  *
  */
-static void
+static int
 mr_capab(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
-  int i = 0;
   unsigned int cap = 0;
   char *p = NULL;
   char *s = NULL;
 
-  if (client_p->localClient->caps && !(IsCapable(client_p, CAP_TS6)))
+  if (client_p->localClient->caps && !IsCapable(client_p, CAP_TS6))
   {
     exit_client(client_p, client_p, "CAPAB received twice");
-    return;
+    return 0;
   }
 
   SetCapable(client_p, CAP_CAP);
 
-  for (i = 1; i < parc; ++i)
-    for (s = strtoken(&p, parv[i], " "); s;
-         s = strtoken(&p,    NULL, " "))
-      if ((cap = find_capability(s)))
-        SetCapable(client_p, cap);
+  for (s = strtoken(&p, parv[1], " "); s;
+       s = strtoken(&p,    NULL, " "))
+    if ((cap = find_capability(s)))
+      SetCapable(client_p, cap);
+
+  return 0;
 }
 
-static struct Message capab_msgtab = {
+static struct Message capab_msgtab =
+{
   "CAPAB", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
   { mr_capab, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore }
 };
@@ -78,10 +81,11 @@ module_exit(void)
   mod_del_cmd(&capab_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2526 $",
+  .version = "$Revision: 3309 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
