@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_connect.c: Connects to a remote IRC server.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_connect.c 2343 2013-07-03 18:13:17Z michael $
+ */
+
+/*! \file m_connect.c
+ * \brief Includes required functions for processing the CONNECT command.
+ * \version $Id: m_connect.c 2821 2014-01-15 23:12:35Z michael $
  */
 
 #include "stdinc.h"
@@ -49,7 +51,7 @@
  *      parv[2] = port number
  *      parv[3] = remote server
  */
-static void
+static int
 mo_connect(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -62,27 +64,27 @@ mo_connect(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "CONNECT");
-    return;
+    return 0;
   }
 
   if (parc > 3)
   {
     if (!HasOFlag(source_p, OPER_FLAG_CONNECT_REMOTE))
     {
-      sendto_one(source_p, form_str(ERR_NOPRIVS),
-                 me.name, source_p->name, "connect");
-      return;
+      sendto_one(source_p, form_str(ERR_NOPRIVS), me.name,
+                 source_p->name, "connect:remote");
+      return 0;
     }
 
     if (hunt_server(client_p, source_p, ":%s CONNECT %s %s :%s", 3,
                     parc, parv) != HUNTED_ISME)
-      return;
+      return 0;
   }
   else if (!HasOFlag(source_p, OPER_FLAG_CONNECT))
   {
     sendto_one(source_p, form_str(ERR_NOPRIVS),
                me.name, source_p->name, "connect");
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(parv[1])))
@@ -90,11 +92,11 @@ mo_connect(struct Client *client_p, struct Client *source_p,
     sendto_one(source_p,
                ":%s NOTICE %s :Connect: Server %s already exists from %s.",
                me.name, source_p->name, parv[1], target_p->from->name);
-    return;
+    return 0;
   }
 
   /*
-   * try to find the name, then host, if both fail notify ops and bail
+   * Try to find the name, then host, if both fail notify ops and bail
    */
   if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)))
   {
@@ -103,7 +105,7 @@ mo_connect(struct Client *client_p, struct Client *source_p,
       sendto_one(source_p,
                  ":%s NOTICE %s :Connect: Host %s not listed in ircd.conf",
                  me.name, source_p->name, parv[1]);
-      return;
+      return 0;
     }
   }
 
@@ -120,21 +122,21 @@ mo_connect(struct Client *client_p, struct Client *source_p,
     {
       sendto_one(source_p, ":%s NOTICE %s :Connect: Illegal port number",
                  me.name, source_p->name);
-      return;
+      return 0;
     }
   }
   else if (port <= 0 && (port = PORTNUM) <= 0)
   {
     sendto_one(source_p, ":%s NOTICE %s :Connect: missing port number",
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if (find_servconn_in_progress(conf->name))
   {
     sendto_one(source_p, ":%s NOTICE %s :Connect: a connection to %s "
                "is already in progress.", me.name, source_p->name, conf->name);
-    return;
+    return 0;
   }
 
   /*
@@ -146,7 +148,7 @@ mo_connect(struct Client *client_p, struct Client *source_p,
   conf->port = port;
 
   /*
-   * at this point we should be calling connect_server with a valid
+   * At this point we should be calling connect_server with a valid
    * C:line and a valid port in the C:line
    */
   if (serv_connect(conf, source_p))
@@ -170,6 +172,7 @@ mo_connect(struct Client *client_p, struct Client *source_p,
    * destroyed
    */
   conf->port = tmpport;
+  return 0;
 }
 
 /*
@@ -183,7 +186,7 @@ mo_connect(struct Client *client_p, struct Client *source_p,
  *      parv[2] = port number
  *      parv[3] = remote server
  */
-static void
+static int
 ms_connect(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -194,13 +197,13 @@ ms_connect(struct Client *client_p, struct Client *source_p,
 
   if (hunt_server(client_p, source_p, ":%s CONNECT %s %s :%s",
                   3, parc, parv) != HUNTED_ISME)
-    return;
+    return 0;
 
   if (EmptyString(parv[1]))
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "CONNECT");
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(parv[1])))
@@ -208,11 +211,11 @@ ms_connect(struct Client *client_p, struct Client *source_p,
     sendto_one(source_p,
                ":%s NOTICE %s :Connect: Server %s already exists from %s.",
                me.name, source_p->name, parv[1], target_p->from->name);
-    return;
+    return 0;
   }
 
   /*
-   * try to find the name, then host, if both fail notify ops and bail
+   * Try to find the name, then host, if both fail notify ops and bail
    */
   if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)))
   { 
@@ -221,7 +224,7 @@ ms_connect(struct Client *client_p, struct Client *source_p,
       sendto_one(source_p,
                  ":%s NOTICE %s :Connect: Host %s not listed in ircd.conf",
                  me.name, source_p->name, parv[1]);
-      return;
+      return 0;
     }
   }
 
@@ -237,7 +240,7 @@ ms_connect(struct Client *client_p, struct Client *source_p,
     port = atoi(parv[2]);
 
     /*
-     * if someone sends port 0, and we have a config port.. use it
+     * If someone sends port 0, and we have a config port.. use it
      */
     if (port == 0 && conf->port)
       port = conf->port;
@@ -245,21 +248,21 @@ ms_connect(struct Client *client_p, struct Client *source_p,
     {
       sendto_one(source_p, ":%s NOTICE %s :Connect: Illegal port number",
                  me.name, source_p->name);
-      return;
+      return 0;
     }
   }
   else if (port <= 0 && (port = PORTNUM) <= 0)
   {
     sendto_one(source_p, ":%s NOTICE %s :Connect: missing port number",
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if (find_servconn_in_progress(conf->name))
   {
     sendto_one(source_p, ":%s NOTICE %s :Connect: a connection to %s "
                "is already in progress.", me.name, source_p->name, conf->name);
-    return;
+    return 0;
   }
 
   /*
@@ -294,9 +297,11 @@ ms_connect(struct Client *client_p, struct Client *source_p,
    * destroyed
    */
   conf->port = tmpport;
+  return 0;
 }
 
-static struct Message connect_msgtab = {
+static struct Message connect_msgtab =
+{
   "CONNECT", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_not_oper, ms_connect, m_ignore, mo_connect, m_ignore }
 };
@@ -313,10 +318,11 @@ module_exit(void)
   mod_del_cmd(&connect_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2343 $",
+  .version = "$Revision: 2821 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
