@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_dline.c: Bans a user.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_dline.c 2476 2013-10-13 18:50:07Z michael $
+ */
+
+/*! \file m_dline.c
+ * \brief Includes required functions for processing the DLINE/UNDLINE command.
+ * \version $Id: m_dline.c 3193 2014-03-23 19:49:55Z michael $
  */
 
 #include "stdinc.h"
@@ -62,7 +64,7 @@ apply_dline(struct Client *source_p, struct MaskItem *conf,
                          get_oper_name(source_p), tkline_time/60,
                          conf->host, conf->reason);
     sendto_one(source_p, ":%s NOTICE %s :Added temporary %d min. D-Line [%s]",
-               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p->from),
+               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p),
                source_p->name, tkline_time/60, conf->host);
     ilog(LOG_TYPE_DLINE, "%s added temporary %d min. D-Line for [%s] [%s]",
          get_oper_name(source_p), tkline_time/60, conf->host, conf->reason);
@@ -73,7 +75,7 @@ apply_dline(struct Client *source_p, struct MaskItem *conf,
                          "%s added D-Line for [%s] [%s]",
                          get_oper_name(source_p), conf->host, conf->reason);
     sendto_one(source_p, ":%s NOTICE %s :Added D-Line [%s]",
-               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p->from),
+               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p),
                source_p->name, conf->host);
     ilog(LOG_TYPE_DLINE, "%s added D-Line for [%s] [%s]",
          get_oper_name(source_p), conf->host, conf->reason);
@@ -112,7 +114,7 @@ remove_dline_match(const char *host)
   else
     piphost = NULL;
 
-  if ((conf = find_conf_by_address(host, piphost, CONF_DLINE | 1, aftype, NULL, NULL, 0)))
+  if ((conf = find_conf_by_address(host, piphost, CONF_DLINE, aftype, NULL, NULL, 0)))
   {
     if (IsConfDatabase(conf))
     {
@@ -134,7 +136,7 @@ remove_dline_match(const char *host)
  * side effects - D line is added
  *
  */
-static void
+static int
 mo_dline(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
@@ -154,37 +156,24 @@ mo_dline(struct Client *client_p, struct Client *source_p,
 
   if (!HasOFlag(source_p, OPER_FLAG_DLINE))
   {
-    sendto_one(source_p, form_str(ERR_NOPRIVS),
-               me.name, source_p->name, "dline");
-    return;
+    sendto_one(source_p, form_str(ERR_NOPRIVS), me.name,
+               source_p->name, "dline");
+    return 0;
   }
 
   if (parse_aline("DLINE", source_p,  parc, parv, AWILD, &dlhost,
                   NULL, &tkline_time, &target_server, &reason) < 0)
-    return;
+    return 0;
 
   if (target_server != NULL)
   {
-    if (HasID(source_p))
-    {
-      sendto_server(NULL, CAP_DLN|CAP_TS6, NOCAPS,
-                    ":%s DLINE %s %lu %s :%s",
-                    source_p->id, target_server, (unsigned long)tkline_time,
-                    dlhost, reason);
-      sendto_server(NULL, CAP_DLN, CAP_TS6,
-                    ":%s DLINE %s %lu %s :%s",
-                    source_p->name, target_server, (unsigned long)tkline_time,
-                    dlhost, reason);
-    }
-    else
-      sendto_server(NULL, CAP_DLN, NOCAPS,
-                    ":%s DLINE %s %lu %s :%s",
-                    source_p->name, target_server, (unsigned long)tkline_time,
-                    dlhost, reason);
+    sendto_match_servs(source_p, target_server, CAP_DLN, "DLINE %s %lu %s :%s",
+                       target_server, (unsigned long)tkline_time,
+                       dlhost, reason);
 
     /* Allow ON to apply local kline as well if it matches */
     if (match(target_server, me.name))
-      return;
+      return 0;
   }
   else
     cluster_a_line(source_p, "DLINE", CAP_DLN, SHARED_DLINE,
@@ -192,23 +181,22 @@ mo_dline(struct Client *client_p, struct Client *source_p,
 
   if ((t = parse_netmask(dlhost, NULL, &bits)) == HM_HOST)
   {
-    if ((target_p = find_chasing(source_p, dlhost, NULL)) == NULL)
-      return;
+    if ((target_p = find_chasing(source_p, dlhost)) == NULL)
+      return 0;
 
     if (!MyConnect(target_p))
     {
       sendto_one(source_p,
                  ":%s NOTICE %s :Can't DLINE nick on another server",
                  me.name, source_p->name);
-      return;
+      return 0;
     }
 
     if (IsExemptKline(target_p))
     {
-      sendto_one(source_p,
-                 ":%s NOTICE %s :%s is E-lined", me.name,
-                 source_p->name, target_p->name);
-      return;
+      sendto_one(source_p, ":%s NOTICE %s :%s is E-lined",
+                 me.name, source_p->name, target_p->name);
+      return 0;
     }
 
     getnameinfo((struct sockaddr *)&target_p->localClient->ip,
@@ -224,7 +212,7 @@ mo_dline(struct Client *client_p, struct Client *source_p,
     sendto_one(source_p,
                ":%s NOTICE %s :For safety, bitmasks less than 8 require conf access.",
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
 #ifdef IPV6
@@ -239,22 +227,21 @@ mo_dline(struct Client *client_p, struct Client *source_p,
   if ((conf = find_dline_conf(&daddr, aftype)) != NULL)
   {
     creason = conf->reason ? conf->reason : def_reason;
+
     if (IsConfExemptKline(conf))
-      sendto_one(source_p,
-		 ":%s NOTICE %s :[%s] is (E)d-lined by [%s] - %s",
-		 me.name, source_p->name, dlhost, conf->host, creason);
+      sendto_one(source_p, ":%s NOTICE %s :[%s] is (E)d-lined by [%s] - %s",
+                 me.name, source_p->name, dlhost, conf->host, creason);
     else
-      sendto_one(source_p,
-		 ":%s NOTICE %s :[%s] already D-lined by [%s] - %s",
-		 me.name, source_p->name, dlhost, conf->host, creason);
-    return;
+      sendto_one(source_p, ":%s NOTICE %s :[%s] already D-lined by [%s] - %s",
+                 me.name, source_p->name, dlhost, conf->host, creason);
+    return 0;
   }
 
   cur_time = CurrentTime;
   current_date = smalldate(cur_time);
 
   if (!valid_comment(source_p, reason, 1))
-    return;
+    return 0;
 
   conf = conf_make(CONF_DLINE);
   conf->host = xstrdup(dlhost);
@@ -268,9 +255,10 @@ mo_dline(struct Client *client_p, struct Client *source_p,
   conf->reason = xstrdup(buffer);
   apply_dline(source_p, conf, tkline_time);
   rehashed_klines = 1;
+  return 0;
 }
 
-static void
+static int
 ms_dline(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
@@ -288,7 +276,7 @@ ms_dline(struct Client *client_p, struct Client *source_p,
   char buffer[IRCD_BUFSIZE];
 
   if (parc != 5 || EmptyString(parv[4]))
-    return;
+    return 0;
 
   /* parv[0]  parv[1]        parv[2]      parv[3]  parv[4] */
   /* oper     target_server  tkline_time  host     reason  */
@@ -297,29 +285,31 @@ ms_dline(struct Client *client_p, struct Client *source_p,
                      parv[1], parv[2], parv[3], parv[4]);
 
   if (match(parv[1], me.name))
-    return;
+    return 0;
 
   tkline_time = valid_tkline(parv[2], TK_SECONDS);
   dlhost = parv[3];
   reason = parv[4];
 
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+  if (HasFlag(source_p, FLAGS_SERVICE) ||
+      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
                               source_p->username, source_p->host,
                               SHARED_DLINE))
   {
     if (!IsClient(source_p))
-      return;
+      return 0;
+
     if ((t = parse_netmask(dlhost, NULL, &bits)) == HM_HOST)
     {
-      if ((target_p = find_chasing(source_p, dlhost, NULL)) == NULL)
-        return;
+      if ((target_p = find_chasing(source_p, dlhost)) == NULL)
+        return 0;
 
       if (!MyConnect(target_p))
       {
         sendto_one(source_p,
                    ":%s NOTICE %s :Can't DLINE nick on another server",
                    me.name, source_p->name);
-        return;
+        return 0;
       }
 
       if (IsExemptKline(target_p))
@@ -327,7 +317,7 @@ ms_dline(struct Client *client_p, struct Client *source_p,
         sendto_one(source_p,
                    ":%s NOTICE %s :%s is E-lined", me.name,
                    source_p->name, target_p->name);
-        return;
+        return 0;
       }
 
       getnameinfo((struct sockaddr *)&target_p->localClient->ip,
@@ -343,7 +333,7 @@ ms_dline(struct Client *client_p, struct Client *source_p,
       sendto_one(source_p,
                  ":%s NOTICE %s :For safety, bitmasks less than 8 require conf access.",
                  me.name, source_p->name);
-      return;
+      return 0;
     }
 
 #ifdef IPV6
@@ -366,14 +356,14 @@ ms_dline(struct Client *client_p, struct Client *source_p,
         sendto_one(source_p,
                    ":%s NOTICE %s :[%s] already D-lined by [%s] - %s",
                    me.name, source_p->name, dlhost, conf->host, creason);
-      return;
+      return 0;
     }
 
     cur_time = CurrentTime;
     current_date = smalldate(cur_time);
 
     if (!valid_comment(source_p, reason, 1))
-      return;
+      return 0;
 
     conf = conf_make(CONF_DLINE);
     conf->host = xstrdup(dlhost);
@@ -388,6 +378,8 @@ ms_dline(struct Client *client_p, struct Client *source_p,
     apply_dline(source_p, conf, tkline_time);
     rehashed_klines = 1;
   }
+
+  return 0;
 }
 
 /*
@@ -399,7 +391,7 @@ ms_dline(struct Client *client_p, struct Client *source_p,
 **      parv[0] = sender nick
 **      parv[1] = dline to remove
 */
-static void
+static int
 mo_undline(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -408,21 +400,21 @@ mo_undline(struct Client *client_p, struct Client *source_p,
 
   if (!HasOFlag(source_p, OPER_FLAG_UNDLINE))
   {
-    sendto_one(source_p, form_str(ERR_NOPRIVS),
-               me.name, source_p->name, "undline");
-    return;
+    sendto_one(source_p, form_str(ERR_NOPRIVS), me.name,
+               source_p->name, "undline");
+    return 0;
   }
 
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "UNDLINE");
-    return;
+    return 0;
   }
 
   if (parse_aline("UNDLINE", source_p, parc, parv, 0, &user,
                   &addr, NULL, &target_server, NULL) < 0)
-    return;
+    return 0;
 
   if (target_server != NULL)
   {
@@ -431,7 +423,7 @@ mo_undline(struct Client *client_p, struct Client *source_p,
 
     /* Allow ON to apply local unkline as well if it matches */
     if (match(target_server, me.name))
-      return;
+      return 0;
   }
   else
     cluster_a_line(source_p, "UNDLINE", CAP_UNDLN, SHARED_UNDLINE,
@@ -439,8 +431,7 @@ mo_undline(struct Client *client_p, struct Client *source_p,
 
   if (remove_dline_match(addr))
   {
-    sendto_one(source_p,
-               ":%s NOTICE %s :D-Line for [%s] is removed",
+    sendto_one(source_p, ":%s NOTICE %s :D-Line for [%s] is removed",
                me.name, source_p->name, addr);
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                          "%s has removed the D-Line for: [%s]",
@@ -451,31 +442,33 @@ mo_undline(struct Client *client_p, struct Client *source_p,
   else
     sendto_one(source_p, ":%s NOTICE %s :No D-Line for [%s] found",
                me.name, source_p->name, addr);
+  return 0;
 }
 
-static void
-me_undline(struct Client *client_p, struct Client *source_p,
+static int
+ms_undline(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
-  const char *addr = NULL;
+  const char *addr = parv[1];
 
   if (parc != 3 || EmptyString(parv[2]))
-    return;
+    return 0;
 
-  addr = parv[2];
+  sendto_match_servs(source_p, parv[1], CAP_UNDLN,
+                     "UNDLINE %s %s",
+                     parv[1], parv[2]);
 
   if (!IsClient(source_p) || match(parv[1], me.name))
-    return;
+    return 0;
 
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_ULINE,
-                                   source_p->servptr->name,
-                                   source_p->username, source_p->host,
-                                   SHARED_UNDLINE))
+  if (HasFlag(source_p, FLAGS_SERVICE) ||
+      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+                              source_p->username, source_p->host,
+                              SHARED_UNDLINE))
   {
     if (remove_dline_match(addr))
     {
-      sendto_one(source_p,
-                 ":%s NOTICE %s :D-Line for [%s] is removed",
+      sendto_one(source_p, ":%s NOTICE %s :D-Line for [%s] is removed",
                  me.name, source_p->name, addr);
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                            "%s has removed the D-Line for: [%s]",
@@ -487,30 +480,20 @@ me_undline(struct Client *client_p, struct Client *source_p,
       sendto_one(source_p, ":%s NOTICE %s :No D-Line for [%s] found",
                  me.name, source_p->name, addr);
   }
+
+  return 0;
 }
 
-static void
-ms_undline(struct Client *client_p, struct Client *source_p,
-           int parc, char *parv[])
+static struct Message dline_msgtab =
 {
-  if (parc != 3 || EmptyString(parv[2]))
-    return;
-
-  sendto_match_servs(source_p, parv[1], CAP_UNDLN,
-                     "UNDLINE %s %s",
-                     parv[1], parv[2]);
-
-  me_undline(client_p, source_p, parc, parv);
-}
-
-static struct Message dline_msgtab = {
   "DLINE", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-   {m_unregistered, m_not_oper, ms_dline, m_ignore, mo_dline, m_ignore}
+  { m_unregistered, m_not_oper, ms_dline, m_ignore, mo_dline, m_ignore }
 };
 
-static struct Message undline_msgtab = {
+static struct Message undline_msgtab =
+{
   "UNDLINE", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-   {m_unregistered, m_not_oper, ms_undline, m_ignore, mo_undline, m_ignore}
+  { m_unregistered, m_not_oper, ms_undline, m_ignore, mo_undline, m_ignore }
 };
 
 static void
@@ -531,10 +514,11 @@ module_exit(void)
   delete_capability("DLN");
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2476 $",
+  .version = "$Revision: 3193 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
