@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_encap.c: encapsulated command propagation and parsing
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2003 by the past and present ircd coders, and others.
+ *  Copyright (c) 2003-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_encap.c 1793 2013-03-31 14:06:08Z michael $
+ */
+
+/*! \file m_encap.c
+ * \brief Includes required functions for processing the ENCAP command.
+ * \version $Id: m_encap.c 3038 2014-02-25 19:41:54Z michael $
  */
 
 #include "stdinc.h"
@@ -38,7 +40,7 @@
  * output	- none
  * side effects	- propagates subcommand to locally connected servers
  */
-static void
+static int
 ms_encap(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
@@ -55,37 +57,27 @@ ms_encap(struct Client *client_p, struct Client *source_p,
     len = strlen(parv[i]) + 1;
 
     if ((cur_len + len) >= sizeof(buffer))
-      return;
+      return 0;
 
     snprintf(ptr, sizeof(buffer) - cur_len, "%s ", parv[i]);
     cur_len += len;
     ptr += len;
   }
 
-  len = strlen(parv[i]);
-
-  /*
-   * if the final parameter crosses our buffer size, should we bail, 
-   * like the rest, or should we truncate?  ratbox seems to think truncate,
-   * so i'll do that for now until i can talk to lee.  -bill
-   */
-
+  /* If it's a command without parameters, don't prepend a ':' */
   if (parc == 3)
     snprintf(ptr, sizeof(buffer) - cur_len, "%s", parv[2]);
   else
     snprintf(ptr, sizeof(buffer) - cur_len, ":%s", parv[parc - 1]);
 
-  if ((cur_len + len) >= sizeof(buffer))
-    buffer[sizeof(buffer) - 1] = '\0';
-
   sendto_match_servs(source_p, parv[1], CAP_ENCAP,
                      "ENCAP %s", buffer);
 
   if (match(parv[1], me.name))
-    return;
+    return 0;
 
   if ((mptr = find_command(parv[2])) == NULL)
-    return;
+    return 0;
 
 #ifdef NOT_USED_YET
   paramcount = mptr->parameters;
@@ -94,9 +86,12 @@ ms_encap(struct Client *client_p, struct Client *source_p,
   mptr->bytes += strlen(buffer);
 
   /*
-   * yes this is an ugly hack, but it is quicker than copying the entire array again
-   * note: this hack wouldnt be needed if parv[0] were set to the command name, rather
-   * than being derived from the prefix, as it should have been from the beginning.
+   * Yes this is an ugly hack, but it is quicker than copying the
+   * entire array again.
+   *
+   * Note: this hack wouldn't be needed if parv[0] were set to the
+   * command name, rather than being derived from the prefix, as
+   * it should have been from the beginning.
    */
   ptr = parv[0];
   parv += 2;
@@ -105,11 +100,13 @@ ms_encap(struct Client *client_p, struct Client *source_p,
 
   if ((handler = mptr->handlers[ENCAP_HANDLER]))
     (*handler)(client_p, source_p, parc, parv);
+  return 0;
 }
 
-static struct Message encap_msgtab = {
+static struct Message encap_msgtab =
+{
   "ENCAP", 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  {m_ignore, m_ignore, ms_encap, m_ignore, m_ignore, m_ignore}
+  { m_ignore, m_ignore, ms_encap, m_ignore, m_ignore, m_ignore }
 };
 
 static void
@@ -126,10 +123,11 @@ module_exit(void)
   delete_capability("ENCAP");
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 1793 $",
+  .version = "$Revision: 3038 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
