@@ -1,7 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
  */
 
 /*! \file m_gline.c
- * \brief Includes required functions for processing the GLINE command.
- * \version $Id: m_gline.c 2339 2013-07-03 13:24:43Z michael $
+ * \brief Includes required functions for processing the GLINE/GUNGLINE command.
+ * \version $Id: m_gline.c 2862 2014-01-18 20:17:59Z michael $
  */
 
 #include "stdinc.h"
@@ -50,6 +50,41 @@
 #define GLINE_PLACED         1
 
 
+static void
+check_gline(struct AddressRec *arec)
+{
+  dlink_node *ptr = NULL, *ptr_next = NULL;
+
+  DLINK_FOREACH_SAFE(ptr, ptr_next, local_client_list.head)
+  {
+    struct Client *client_p = ptr->data;
+
+    if (IsDead(client_p))
+      continue;
+
+    if (match(arec->username, client_p->username))
+      continue;
+
+    switch (arec->masktype)
+    {
+      case HM_IPV4:
+        if (client_p->localClient->aftype == AF_INET)
+          if (match_ipv4(&client_p->localClient->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
+            conf_try_ban(client_p, arec->conf);
+        break;
+      case HM_IPV6:
+        if (client_p->localClient->aftype == AF_INET6)
+          if (match_ipv6(&client_p->localClient->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
+            conf_try_ban(client_p, arec->conf);
+        break;
+      default:  /* HM_HOST */
+        if (!match(arec->Mask.hostname, client_p->host))
+          conf_try_ban(client_p, arec->conf);
+        break;
+    }
+  }
+}
+
 /*! \brief Adds a GLINE to the configuration subsystem.
  *
  * \param source_p Operator requesting gline
@@ -80,8 +115,7 @@ set_local_gline(const struct Client *source_p, const char *user,
   ilog(LOG_TYPE_GLINE, "%s added G-Line for [%s@%s] [%s]",
        get_oper_name(source_p), conf->user, conf->host, conf->reason);
 
-  add_conf_by_address(CONF_GLINE, conf);
-  rehashed_klines = 1;
+  check_gline(add_conf_by_address(CONF_GLINE, conf));
 }
 
 /*! \brief Removes a GLINE from the configuration subsystem.
@@ -247,18 +281,32 @@ check_majority(const struct Client *source_p, const char *user,
   return GLINE_NOT_PLACED;
 }
 
-static void
-do_sgline(struct Client *source_p, int parc, char *parv[], int prop)
+/* ms_gline()
+ *
+ * inputs       - The usual for a m_ function
+ * output       -
+ * side effects -
+ *
+ * Place a G line if 3 opers agree on the identical user@host
+ *
+ * Allow this server to pass along GLINE if received and
+ * GLINES is not defined.
+ *
+ */
+static int
+ms_gline(struct Client *client_p, struct Client *source_p,
+         int parc, char *parv[])
 {
   const char *reason = NULL;      /* reason for "victims" demise       */
   const char *user = NULL;
   const char *host = NULL;        /* user and host of GLINE "victim"   */
+  const char *p = NULL;
 
   if (!IsClient(source_p))
-    return;
+    return 0;
 
   if (parc != 4 || EmptyString(parv[3]))
-    return;
+    return 0;
 
   assert(source_p->servptr != NULL);
 
@@ -273,50 +321,45 @@ do_sgline(struct Client *source_p, int parc, char *parv[], int prop)
                 ":%s GLINE %s %s :%s",
                 source_p->name, user, host, reason);
 
-  if (ConfigFileEntry.glines)
+  if (!ConfigFileEntry.glines)
+    return 0;
+
+  if (!valid_wild_card(source_p, 1, 2, user, host))
+    return 0;
+
+  if ((p = strchr(host, '/')))
   {
-    if (!valid_wild_card(source_p, 1, 2, user, host))
-      return;
-
-    if (IsClient(source_p))
-    {
-      const char *p = NULL;
-
-      if ((p = strchr(host, '/')))
-      {
-        int bitlen = strtol(++p, NULL, 10);
-        int min_bitlen = strchr(host, ':') ? ConfigFileEntry.gline_min_cidr6 :
+    int bitlen = strtol(++p, NULL, 10);
+    int min_bitlen = strchr(host, ':') ? ConfigFileEntry.gline_min_cidr6 :
                                              ConfigFileEntry.gline_min_cidr;
 
-        if (bitlen < min_bitlen)
-        {
-          sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                               "%s is requesting a GLINE with a CIDR mask < %d for [%s@%s] [%s]",
-                               get_oper_name(source_p), min_bitlen,
-                               user, host, reason);
-          return;
-        }
-      }
+    if (bitlen < min_bitlen)
+    {
+      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+                           "%s is requesting a GLINE with a CIDR mask < %d for [%s@%s] [%s]",
+                           get_oper_name(source_p), min_bitlen,
+                           user, host, reason);
+      return 0;
     }
-
-     /* If at least 3 opers agree this user should be G lined then do it */
-     if (check_majority(source_p, user, host, reason, GLINE_PENDING_ADD_TYPE) ==
-         GLINE_ALREADY_VOTED)
-     {
-       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                            "oper or server has already voted");
-       return;
-     }
-
-     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                          "%s requesting G-Line for [%s@%s] [%s]",
-                          get_oper_name(source_p),
-                          user, host, reason);
-     ilog(LOG_TYPE_GLINE, "G-Line for [%s@%s] [%s] requested by %s",
-          user, host, reason, get_oper_name(source_p));
   }
-}
 
+  /* If at least 3 opers agree this user should be G lined then do it */
+  if (check_majority(source_p, user, host, reason, GLINE_PENDING_ADD_TYPE) ==
+      GLINE_ALREADY_VOTED)
+  {
+    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+                         "oper or server has already voted");
+    return 0;
+  }
+
+  sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+                        "%s requesting G-Line for [%s@%s] [%s]",
+                        get_oper_name(source_p),
+                        user, host, reason);
+  ilog(LOG_TYPE_GLINE, "G-Line for [%s@%s] [%s] requested by %s",
+       user, host, reason, get_oper_name(source_p));
+  return 0;
+}
 
 /*! \brief GLINE command handler (called by operators)
  *
@@ -332,7 +375,7 @@ do_sgline(struct Client *source_p, int parc, char *parv[], int prop)
  *      - parv[1] = user\@host mask
  *      - parv[2] = reason
  */
-static void
+static int
 mo_gline(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
@@ -345,19 +388,19 @@ mo_gline(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOPRIVS),
                me.name, source_p->name, "gline");
-    return;
+    return 0;
   }
 
   if (!ConfigFileEntry.glines)
   {
     sendto_one(source_p, ":%s NOTICE %s :GLINE disabled",
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if (parse_aline("GLINE", source_p, parc, parv, AWILD,
                   &user, &host, NULL, NULL, &reason) < 0)
-    return;
+    return 0;
 
   if ((p = strchr(host, '/')) != NULL)
   {
@@ -368,7 +411,7 @@ mo_gline(struct Client *client_p, struct Client *source_p,
     {
       sendto_one(source_p, ":%s NOTICE %s :Cannot set G-Lines with CIDR length < %d",
                  me.name, source_p->name, min_bitlen);
-      return;
+      return 0;
     }
   }
   
@@ -379,7 +422,7 @@ mo_gline(struct Client *client_p, struct Client *source_p,
     sendto_one(source_p,
                ":%s NOTICE %s :This server or oper has already voted",
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   /*
@@ -400,36 +443,7 @@ mo_gline(struct Client *client_p, struct Client *source_p,
   sendto_server(NULL, CAP_GLN, CAP_TS6,
 		":%s GLINE %s %s :%s",
 		source_p->name, user, host, reason);
-}
-
-/* ms_gline()
- * me_gline()
- * do_sgline()
- *
- * inputs       - The usual for a m_ function
- * output       -
- * side effects -
- *
- * Place a G line if 3 opers agree on the identical user@host
- * 
- * Allow this server to pass along GLINE if received and
- * GLINES is not defined.
- *
- * ENCAP'd GLINES are propagated by encap code.
- */
-
-static void
-ms_gline(struct Client *client_p, struct Client *source_p,
-         int parc, char *parv[])
-{
-  do_sgline(source_p, parc, parv, 1);
-}
-
-static void
-me_gline(struct Client *client_p, struct Client *source_p,
-         int parc, char *parv[])
-{
-  do_sgline(source_p, parc, parv, 0);
+  return 0;
 }
 
 static void
@@ -477,12 +491,13 @@ do_sungline(struct Client *source_p, const char *user,
  *      - parv[2] = hostname
  *      - parv[3] = reason
  */
-static void
+static int
 me_gungline(struct Client *client_p, struct Client *source_p,
             int parc, char *parv[])
 {
   if (ConfigFileEntry.glines)
     do_sungline(source_p, parv[1], parv[2], parv[3], 0);
+  return 0;
 }
 
 /*! \brief GUNGLINE command handler (called by operators)
@@ -499,7 +514,7 @@ me_gungline(struct Client *client_p, struct Client *source_p,
  *      - parv[1] = user\@host mask
  *      - parv[2] = reason
  */
-static void
+static int
 mo_gungline(struct Client *client_p, struct Client *source_p,
             int parc, char *parv[])
 {
@@ -511,21 +526,22 @@ mo_gungline(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOPRIVS),
                me.name, source_p->name, "gline");
-    return;
+    return 0;
   }
 
   if (!ConfigFileEntry.glines)
   {
     sendto_one(source_p, ":%s NOTICE %s :GUNGLINE disabled",
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if (parse_aline("GUNGLINE", source_p, parc, parv, 0, &user,
                   &host, NULL, NULL, &reason) < 0)
-    return;
+    return 0;
 
   do_sungline(source_p, user, host, reason, 1);
+  return 0;
 }
 
 /*
@@ -533,12 +549,14 @@ mo_gungline(struct Client *client_p, struct Client *source_p,
  * a gline is not valid with "No reason"
  * -db
  */
-static struct Message gline_msgtab = {
+static struct Message gline_msgtab =
+{
   "GLINE", 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, ms_gline, me_gline, mo_gline, m_ignore }
+  { m_unregistered, m_not_oper, ms_gline, m_ignore, mo_gline, m_ignore }
 };
 
-static struct Message ungline_msgtab = {
+static struct Message ungline_msgtab =
+{
   "GUNGLINE", 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_not_oper, m_ignore, me_gungline, mo_gungline, m_ignore }
 };
@@ -559,10 +577,11 @@ module_exit(void)
   delete_capability("GLN");
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2339 $",
+  .version = "$Revision: 2862 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
