@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_help.c: Provides help information to a user/operator.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1999-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_help.c 2656 2013-12-12 19:04:40Z michael $
+ */
+
+/*! \file m_help.c
+ * \brief Includes required functions for processing the HELP command.
+ * \version $Id: m_help.c 3027 2014-02-25 00:07:20Z michael $
  */
 
 #include "stdinc.h"
@@ -74,7 +76,7 @@ sendhelpfile(struct Client *source_p, const char *path, const char *topic)
 }
 
 static void
-dohelp(struct Client *source_p, char *topic)
+do_help(struct Client *source_p, char *topic)
 {
   char *p = topic;
   char h_index[] = "index";
@@ -124,7 +126,7 @@ dohelp(struct Client *source_p, char *topic)
  * m_help - HELP message handler
  *      parv[0] = sender prefix
  */
-static void
+static int
 m_help(struct Client *client_p, struct Client *source_p,
        int parc, char *parv[])
 {
@@ -134,30 +136,33 @@ m_help(struct Client *client_p, struct Client *source_p,
   if ((last_used + ConfigFileEntry.pace_wait_simple) > CurrentTime)
   {
     /* safe enough to give this on a local connect only */
-    sendto_one(source_p,form_str(RPL_LOAD2HI),
+    sendto_one(source_p, form_str(RPL_LOAD2HI),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   last_used = CurrentTime;
 
-  dohelp(source_p, parv[1]);
+  do_help(source_p, parv[1]);
+  return 0;
 }
 
 /*
  * mo_help - HELP message handler
  *      parv[0] = sender prefix
  */
-static void
+static int
 mo_help(struct Client *client_p, struct Client *source_p,
         int parc, char *parv[])
 {
-  dohelp(source_p, parv[1]);
+  do_help(source_p, parv[1]);
+  return 0;
 }
 
-static struct Message help_msgtab = {
+static struct Message help_msgtab =
+{
   "HELP", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  {m_unregistered, m_help, m_ignore, m_ignore, mo_help, m_ignore}
+  { m_unregistered, m_help, m_ignore, m_ignore, mo_help, m_ignore }
 };
 
 static void
@@ -172,10 +177,11 @@ module_exit(void)
   mod_del_cmd(&help_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2656 $",
+  .version = "$Revision: 3027 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
