@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_info.c: Sends information about the server.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2005 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_info.c 2342 2013-07-03 13:59:41Z michael $
+ */
+
+/*! \file m_info.c
+ * \brief Includes required functions for processing the INFO command.
+ * \version $Id: m_info.c 3080 2014-03-01 17:22:54Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +31,7 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
+#include "s_misc.h"
 #include "s_serv.h"
 #include "s_user.h"
 #include "send.h"
@@ -649,7 +652,7 @@ send_conf_options(struct Client *source_p)
  * output       - NONE
  * side effects - info text is sent to client
  */
-static void
+static int
 send_info_text(struct Client *source_p)
 {
   const char **text = infotext;
@@ -684,6 +687,7 @@ send_info_text(struct Client *source_p)
 
   sendto_one(source_p, form_str(RPL_ENDOFINFO),
              me.name, source_p->name);
+  return 0;
 }
 
 /*
@@ -691,7 +695,7 @@ send_info_text(struct Client *source_p)
 **  parv[0] = sender prefix
 **  parv[1] = servername
 */
-static void
+static int
 m_info(struct Client *client_p, struct Client *source_p,
        int parc, char *parv[])
 {
@@ -702,17 +706,17 @@ m_info(struct Client *client_p, struct Client *source_p,
     /* safe enough to give this on a local connect only */
     sendto_one(source_p, form_str(RPL_LOAD2HI),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   last_used = CurrentTime;
 
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(client_p,source_p, ":%s INFO :%s", 1,
+    if (hunt_server(client_p, source_p, ":%s INFO :%s", 1,
                     parc, parv) != HUNTED_ISME)
-      return;
+      return 0;
 
-  send_info_text(source_p);
+  return send_info_text(source_p);
 }
 
 /*
@@ -720,18 +724,19 @@ m_info(struct Client *client_p, struct Client *source_p,
 **  parv[0] = sender prefix
 **  parv[1] = servername
 */
-static void
+static int
 ms_info(struct Client *client_p, struct Client *source_p,
         int parc, char *parv[])
 {
   if (hunt_server(client_p, source_p, ":%s INFO :%s", 1,
                   parc, parv) != HUNTED_ISME)
-    return;
+    return 0;
 
-  send_info_text(source_p);
+  return send_info_text(source_p);
 }
 
-static struct Message info_msgtab = {
+static struct Message info_msgtab =
+{
   "INFO", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_info, ms_info, m_ignore, ms_info, m_ignore }
 };
@@ -748,10 +753,11 @@ module_exit(void)
   mod_del_cmd(&info_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2342 $",
+  .version = "$Revision: 3080 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
