@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_kline.c: Bans a user.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_kline.c 2339 2013-07-03 13:24:43Z michael $
+ */
+
+/*! \file m_kline.c
+ * \brief Includes required functions for processing the KLINE/UNKLINE command.
+ * \version $Id: m_kline.c 3080 2014-03-01 17:22:54Z michael $
  */
 
 #include "stdinc.h"
@@ -44,162 +46,47 @@
 #include "conf_db.h"
 #include "memory.h"
 
-static int already_placed_kline(struct Client *, const char *, const char *, int);
-static void m_kline_add_kline(struct Client *, struct MaskItem *, time_t);
 
-static char buffer[IRCD_BUFSIZE];
-static int remove_kline_match(const char *, const char *);
-
-
-/* mo_kline()
- *
- * inputs	- pointer to server
- *		- pointer to client
- *		- parameter count
- *		- parameter list
- * output	-
- * side effects - k line is added
- */
 static void
-mo_kline(struct Client *client_p, struct Client *source_p,
-         int parc, char *parv[])
+check_kline(struct AddressRec *arec)
 {
-  char *reason = NULL;
-  char *user = NULL;
-  char *host = NULL;
-  const char *current_date;
-  char *target_server = NULL;
-  struct MaskItem *conf;
-  time_t tkline_time = 0;
-  time_t cur_time;
+  dlink_node *ptr = NULL, *ptr_next = NULL;
 
-  if (!HasOFlag(source_p, OPER_FLAG_K))
+  DLINK_FOREACH_SAFE(ptr, ptr_next, local_client_list.head)
   {
-    sendto_one(source_p, form_str(ERR_NOPRIVS),
-               me.name, source_p->name, "kline");
-    return;
-  }
+    struct Client *client_p = ptr->data;
 
-  if (parse_aline("KLINE", source_p, parc, parv,
-		  AWILD, &user, &host, &tkline_time, &target_server, &reason) < 0)
-    return;
+    if (IsDead(client_p))
+      continue;
 
-  if (target_server != NULL)
-  {
-    if (HasID(source_p))
+    if (match(arec->username, client_p->username))
+      continue;
+
+    switch (arec->masktype)
     {
-      sendto_server(NULL, CAP_KLN|CAP_TS6, NOCAPS,
-                    ":%s KLINE %s %lu %s %s :%s",
-                    source_p->id, target_server, (unsigned long)tkline_time,
-                    user, host, reason);
-      sendto_server(NULL, CAP_KLN, CAP_TS6,
-                    ":%s KLINE %s %lu %s %s :%s",
-                    source_p->name, target_server, (unsigned long)tkline_time,
-                    user, host, reason);
+      case HM_IPV4:
+        if (client_p->localClient->aftype == AF_INET)
+          if (match_ipv4(&client_p->localClient->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
+            conf_try_ban(client_p, arec->conf);
+        break;
+      case HM_IPV6:
+        if (client_p->localClient->aftype == AF_INET6)
+          if (match_ipv6(&client_p->localClient->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
+            conf_try_ban(client_p, arec->conf);
+        break;
+      default:  /* HM_HOST */
+        if (!match(arec->Mask.hostname, client_p->host))
+          conf_try_ban(client_p, arec->conf);
+        break;
     }
-    else
-      sendto_server(NULL, CAP_KLN, NOCAPS,
-                    ":%s KLINE %s %lu %s %s :%s",
-                    source_p->name, target_server, (unsigned long)tkline_time,
-                    user, host, reason);
-
-    /* Allow ON to apply local kline as well if it matches */
-    if (match(target_server, me.name))
-      return;
   }
-  else
-    cluster_a_line(source_p, "KLINE", CAP_KLN, SHARED_KLINE,
-                   "%d %s %s :%s", tkline_time, user, host, reason);
-
-  if (already_placed_kline(source_p, user, host, 1))
-    return;
-
-  cur_time = CurrentTime;
-  current_date = smalldate(cur_time);
-  conf = conf_make(CONF_KLINE);
-
-  conf->host = xstrdup(host);
-  conf->user = xstrdup(user);
-
-  if (tkline_time != 0)
-    snprintf(buffer, sizeof(buffer), "Temporary K-line %d min. - %s (%s)",
-             (int)(tkline_time/60), reason, current_date);
-  else
-    snprintf(buffer, sizeof(buffer), "%s (%s)", reason, current_date);
-
-  conf->reason = xstrdup(buffer);
-  m_kline_add_kline(source_p, conf, tkline_time);
-}
-
-/* me_kline - handle remote kline. no propagation */
-static void
-me_kline(struct Client *client_p, struct Client *source_p,
-         int parc, char *parv[])
-{
-  struct MaskItem *conf = NULL;
-  int tkline_time = 0;
-  const char* current_date;
-  time_t cur_time;
-  char *kuser, *khost, *kreason;
-
-  if (parc != 6 || EmptyString(parv[5]))
-    return;
-
-  if (match(parv[1], me.name))
-    return;
-
-  tkline_time = valid_tkline(parv[2], TK_SECONDS);
-  kuser = parv[3];
-  khost = parv[4];
-  kreason = parv[5];
-
-  cur_time = CurrentTime;
-  current_date = smalldate(cur_time);
-
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_KLINE))
-  {
-    if (!IsClient(source_p) ||
-        already_placed_kline(source_p, kuser, khost, 1))
-      return;
-
-    conf = conf_make(CONF_KLINE);
-    conf->host = xstrdup(khost);
-    conf->user = xstrdup(kuser);
-
-    if (tkline_time != 0)
-      snprintf(buffer, sizeof(buffer), "Temporary K-line %d min. - %s (%s)",
-               (int)(tkline_time/60), kreason, current_date);
-    else
-      snprintf(buffer, sizeof(buffer), "%s (%s)", kreason, current_date);
-
-    conf->reason = xstrdup(buffer);
-    m_kline_add_kline(source_p, conf, tkline_time);
-  }
-}
-
-static void
-ms_kline(struct Client *client_p, struct Client *source_p,
-         int parc, char *parv[])
-{
-  if (parc != 6 || EmptyString(parv[5]))
-    return;
-
-  /* parv[0]  parv[1]        parv[2]      parv[3]  parv[4]  parv[5] */
-  /* oper     target_server  tkline_time  user     host     reason */
-  sendto_match_servs(source_p, parv[1], CAP_KLN,
-                     "KLINE %s %s %s %s :%s",
-                     parv[1], parv[2], parv[3], parv[4], parv[5]);
-
-  me_kline(client_p, source_p, parc, parv);
 }
 
 /* apply_tkline()
  *
- * inputs	-
- * output	- NONE
- * side effects	- tkline as given is placed
+ * inputs       -
+ * output       - NONE
+ * side effects - tkline as given is placed
  */
 static void
 m_kline_add_kline(struct Client *source_p, struct MaskItem *conf,
@@ -214,7 +101,7 @@ m_kline_add_kline(struct Client *source_p, struct MaskItem *conf,
                          conf->user, conf->host,
                          conf->reason);
     sendto_one(source_p, ":%s NOTICE %s :Added temporary %d min. K-Line [%s@%s]",
-               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p->from),
+               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p),
                source_p->name, tkline_time/60, conf->user, conf->host);
     ilog(LOG_TYPE_KLINE, "%s added temporary %d min. K-Line for [%s@%s] [%s]",
          get_oper_name(source_p), tkline_time/60,
@@ -227,8 +114,8 @@ m_kline_add_kline(struct Client *source_p, struct MaskItem *conf,
                          get_oper_name(source_p),
                          conf->user, conf->host, conf->reason);
     sendto_one(source_p, ":%s NOTICE %s :Added K-Line [%s@%s]",
-               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p->from),
-                 source_p->name, conf->user, conf->host);
+               MyConnect(source_p) ? me.name : ID_or_name(&me, source_p),
+               source_p->name, conf->user, conf->host);
     ilog(LOG_TYPE_KLINE, "%s added K-Line for [%s@%s] [%s]",
          get_oper_name(source_p), conf->user, conf->host, conf->reason);
   }
@@ -236,14 +123,51 @@ m_kline_add_kline(struct Client *source_p, struct MaskItem *conf,
   conf->setat = CurrentTime;
   SetConfDatabase(conf);
 
-  add_conf_by_address(CONF_KLINE, conf);
-  rehashed_klines = 1;
+  check_kline(add_conf_by_address(CONF_KLINE, conf));
+}
+
+/* static int remove_tkline_match(const char *host, const char *user)
+ * Input: A hostname, a username to unkline.
+ * Output: returns YES on success, NO if no tkline removed.
+ * Side effects: Any matching tklines are removed.
+ */
+static int
+remove_kline_match(const char *host, const char *user)
+{
+  struct irc_ssaddr iphost, *piphost;
+  struct MaskItem *conf;
+  int t = 0;
+  int aftype = 0;
+
+  if ((t = parse_netmask(host, &iphost, NULL)) != HM_HOST)
+  {
+#ifdef IPV6
+    if (t == HM_IPV6)
+      aftype = AF_INET6;
+    else
+#endif
+      aftype = AF_INET;
+    piphost = &iphost;
+  }
+  else
+    piphost = NULL;
+
+  if ((conf = find_conf_by_address(host, piphost, CONF_KLINE, aftype, user, NULL, 0)))
+  {
+    if (IsConfDatabase(conf))
+    {
+      delete_one_address_conf(host, conf);
+      return 1;
+    }
+  }
+
+  return 0;
 }
 
 /* already_placed_kline()
- * inputs	- user to complain to, username & host to check for
- * outputs	- returns 1 on existing K-line, 0 if doesn't exist
- * side effects	- notifies source_p if the K-line already exists
+ * inputs       - user to complain to, username & host to check for
+ * outputs      - returns 1 on existing K-line, 0 if doesn't exist
+ * side effects - notifies source_p if the K-line already exists
  */
 /*
  * Note: This currently works if the new K-line is a special case of an
@@ -289,6 +213,142 @@ already_placed_kline(struct Client *source_p, const char *luser, const char *lho
   return 0;
 }
 
+/* mo_kline()
+ *
+ * inputs	- pointer to server
+ *		- pointer to client
+ *		- parameter count
+ *		- parameter list
+ * output	-
+ * side effects - k line is added
+ */
+static int
+mo_kline(struct Client *client_p, struct Client *source_p,
+         int parc, char *parv[])
+{
+  char buffer[IRCD_BUFSIZE];
+  char *reason = NULL;
+  char *user = NULL;
+  char *host = NULL;
+  const char *current_date;
+  char *target_server = NULL;
+  struct MaskItem *conf;
+  time_t tkline_time = 0;
+  time_t cur_time;
+
+  if (!HasOFlag(source_p, OPER_FLAG_K))
+  {
+    sendto_one(source_p, form_str(ERR_NOPRIVS), me.name,
+               source_p->name, "kline");
+    return 0;
+  }
+
+  if (parse_aline("KLINE", source_p, parc, parv, AWILD, &user, &host,
+                  &tkline_time, &target_server, &reason) < 0)
+    return 0;
+
+  if (target_server != NULL)
+  {
+    sendto_match_servs(source_p, target_server, CAP_KLN, "KLINE %s %lu %s %s :%s",
+                       target_server, (unsigned long)tkline_time,
+                       user, host, reason);
+
+    /* Allow ON to apply local kline as well if it matches */
+    if (match(target_server, me.name))
+      return 0;
+  }
+  else
+    cluster_a_line(source_p, "KLINE", CAP_KLN, SHARED_KLINE,
+                   "%d %s %s :%s", tkline_time, user, host, reason);
+
+  if (already_placed_kline(source_p, user, host, 1))
+    return 0;
+
+  cur_time = CurrentTime;
+  current_date = smalldate(cur_time);
+  conf = conf_make(CONF_KLINE);
+
+  conf->host = xstrdup(host);
+  conf->user = xstrdup(user);
+
+  if (tkline_time != 0)
+    snprintf(buffer, sizeof(buffer), "Temporary K-line %d min. - %s (%s)",
+             (int)(tkline_time/60), reason, current_date);
+  else
+    snprintf(buffer, sizeof(buffer), "%s (%s)", reason, current_date);
+
+  conf->reason = xstrdup(buffer);
+  m_kline_add_kline(source_p, conf, tkline_time);
+  return 0;
+}
+
+/* me_kline - handle remote kline. no propagation */
+static int
+me_kline(struct Client *client_p, struct Client *source_p,
+         int parc, char *parv[])
+{
+  char buffer[IRCD_BUFSIZE];
+  struct MaskItem *conf = NULL;
+  int tkline_time = 0;
+  const char *current_date;
+  time_t cur_time;
+  char *kuser, *khost, *kreason;
+
+  if (parc != 6 || EmptyString(parv[5]))
+    return 0;
+
+  if (match(parv[1], me.name))
+    return 0;
+
+  tkline_time = valid_tkline(parv[2], TK_SECONDS);
+  kuser = parv[3];
+  khost = parv[4];
+  kreason = parv[5];
+
+  cur_time = CurrentTime;
+  current_date = smalldate(cur_time);
+
+  if (HasFlag(source_p, FLAGS_SERVICE) ||
+      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+                              source_p->username, source_p->host,
+                              SHARED_KLINE))
+  {
+    if (!IsClient(source_p) ||
+        already_placed_kline(source_p, kuser, khost, 1))
+      return 0;
+
+    conf = conf_make(CONF_KLINE);
+    conf->host = xstrdup(khost);
+    conf->user = xstrdup(kuser);
+
+    if (tkline_time != 0)
+      snprintf(buffer, sizeof(buffer), "Temporary K-line %d min. - %s (%s)",
+               (int)(tkline_time/60), kreason, current_date);
+    else
+      snprintf(buffer, sizeof(buffer), "%s (%s)", kreason, current_date);
+
+    conf->reason = xstrdup(buffer);
+    m_kline_add_kline(source_p, conf, tkline_time);
+  }
+
+  return 0;
+}
+
+static int
+ms_kline(struct Client *client_p, struct Client *source_p,
+         int parc, char *parv[])
+{
+  if (parc != 6 || EmptyString(parv[5]))
+    return 0;
+
+  /* parv[0]  parv[1]        parv[2]      parv[3]  parv[4]  parv[5] */
+  /* oper     target_server  tkline_time  user     host     reason */
+  sendto_match_servs(source_p, parv[1], CAP_KLN, "KLINE %s %s %s %s :%s",
+                     parv[1], parv[2], parv[3], parv[4], parv[5]);
+
+  return me_kline(client_p, source_p, parc, parv);
+}
+
 /*
 ** mo_unkline
 ** Added Aug 31, 1997 
@@ -299,8 +359,8 @@ already_placed_kline(struct Client *source_p, const char *luser, const char *lho
 *
 *
 */
-static void
-mo_unkline(struct Client *client_p,struct Client *source_p,
+static int
+mo_unkline(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
   char *target_server = NULL;
@@ -308,21 +368,21 @@ mo_unkline(struct Client *client_p,struct Client *source_p,
 
   if (!HasOFlag(source_p, OPER_FLAG_UNKLINE))
   {
-    sendto_one(source_p, form_str(ERR_NOPRIVS),
-               me.name, source_p->name, "unkline");
-    return;
+    sendto_one(source_p, form_str(ERR_NOPRIVS), me.name,
+               source_p->name, "unkline");
+    return 0;
   }
 
   if (EmptyString(parv[1]))
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "UNKLINE");
-    return;
+    return 0;
   }
 
   if (parse_aline("UNKLINE", source_p, parc, parv, 0, &user,
                   &host, NULL, &target_server, NULL) < 0)
-    return;
+    return 0;
 
   if (target_server != NULL)
   {
@@ -332,7 +392,7 @@ mo_unkline(struct Client *client_p,struct Client *source_p,
 
     /* Allow ON to apply local unkline as well if it matches */
     if (match(target_server, me.name))
-      return;
+      return 0;
   }
   else
     cluster_a_line(source_p, "UNKLINE", CAP_UNKLN, SHARED_UNKLINE,
@@ -340,8 +400,7 @@ mo_unkline(struct Client *client_p,struct Client *source_p,
 
   if (remove_kline_match(host, user))
   {
-    sendto_one(source_p,
-               ":%s NOTICE %s :K-Line for [%s@%s] is removed",
+    sendto_one(source_p, ":%s NOTICE %s :K-Line for [%s@%s] is removed",
                me.name, source_p->name, user, host);
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                          "%s has removed the K-Line for: [%s@%s]",
@@ -352,6 +411,7 @@ mo_unkline(struct Client *client_p,struct Client *source_p,
   else
     sendto_one(source_p, ":%s NOTICE %s :No K-Line for [%s@%s] found", 
 	       me.name, source_p->name, user, host);
+  return 0;
 }
 
 /* me_unkline()
@@ -364,30 +424,29 @@ mo_unkline(struct Client *client_p,struct Client *source_p,
  * side effects	- if server is authorized, kline is removed
  *                does not propagate message
  */
-static void
+static int
 me_unkline(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
   const char *kuser, *khost;
 
   if (parc != 4)
-    return;
+    return 0;
 
   kuser = parv[2];
   khost = parv[3];
 
   if (!IsClient(source_p) || match(parv[1], me.name))
-    return;
+    return 0;
 
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_ULINE,
-				   source_p->servptr->name,
-				   source_p->username, source_p->host,
-				   SHARED_UNKLINE))
+  if (HasFlag(source_p, FLAGS_SERVICE) ||
+      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+                              source_p->username, source_p->host,
+                              SHARED_UNKLINE))
   {
     if (remove_kline_match(khost, kuser))
     {
-      sendto_one(source_p,
-                 ":%s NOTICE %s :K-Line for [%s@%s] is removed",
+      sendto_one(source_p, ":%s NOTICE %s :K-Line for [%s@%s] is removed",
                  me.name, source_p->name, kuser, khost);
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                            "%s has removed the K-Line for: [%s@%s]",
@@ -399,69 +458,35 @@ me_unkline(struct Client *client_p, struct Client *source_p,
       sendto_one(source_p, ":%s NOTICE %s :No K-Line for [%s@%s] found",
                  me.name, source_p->name, kuser, khost);
   }
+
+  return 0;
 }
 
 /* ms_unkline - propagates and handles a remote unkline message */
-static void
+static int
 ms_unkline(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
   if (parc != 4)
-    return;
+    return 0;
 
   sendto_match_servs(source_p, parv[1], CAP_UNKLN,
                      "UNKLINE %s %s %s",
                      parv[1], parv[2], parv[3]);
 
-  me_unkline(client_p, source_p, parc, parv);
+  return me_unkline(client_p, source_p, parc, parv);
 }
 
-/* static int remove_tkline_match(const char *host, const char *user)
- * Input: A hostname, a username to unkline.
- * Output: returns YES on success, NO if no tkline removed.
- * Side effects: Any matching tklines are removed.
- */
-static int
-remove_kline_match(const char *host, const char *user)
+static struct Message kline_msgtab =
 {
-  struct irc_ssaddr iphost, *piphost;
-  struct MaskItem *conf;
-  int t = 0;
-  int aftype = 0;
-
-  if ((t = parse_netmask(host, &iphost, NULL)) != HM_HOST)
-  {
-#ifdef IPV6
-    if (t == HM_IPV6)
-      aftype = AF_INET6;
-    else
-#endif
-      aftype = AF_INET;
-    piphost = &iphost;
-  }
-  else
-    piphost = NULL;
-
-  if ((conf = find_conf_by_address(host, piphost, CONF_KLINE, aftype, user, NULL, 0)))
-  {
-    if (IsConfDatabase(conf))
-    {
-      delete_one_address_conf(host, conf);
-      return 1;
-    }
-  }
-
-  return 0;
-}
-
-static struct Message kline_msgtab = {
   "KLINE", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-   {m_unregistered, m_not_oper, ms_kline, me_kline, mo_kline, m_ignore}
+  { m_unregistered, m_not_oper, ms_kline, me_kline, mo_kline, m_ignore }
 };
 
-static struct Message unkline_msgtab = {
+static struct Message unkline_msgtab =
+{
   "UNKLINE", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-   {m_unregistered, m_not_oper, ms_unkline, me_unkline, mo_unkline, m_ignore}
+  { m_unregistered, m_not_oper, ms_unkline, me_unkline, mo_unkline, m_ignore }
 };
 
 static void
@@ -482,10 +507,11 @@ module_exit(void)
   delete_capability("KLN");
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2339 $",
+  .version = "$Revision: 3080 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
