@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_list.c: List channel given or all channels.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_list.c 2225 2013-06-12 18:11:29Z michael $
+ */
+
+/*! \file m_list.c
+ * \brief Includes required functions for processing the LIST command.
+ * \version $Id: m_list.c 2905 2014-01-22 20:44:34Z michael $
  */
 
 #include "stdinc.h"
@@ -46,7 +48,7 @@ do_list(struct Client *source_p, int parc, char *parv[])
   struct ListTask *lt = NULL;
   int no_masked_channels = 1;
 
-  if (source_p->localClient->list_task != NULL)
+  if (source_p->localClient->list_task)
   {
     free_list_task(source_p->localClient->list_task, source_p);
     sendto_one(source_p, form_str(RPL_LISTEND), me.name, source_p->name);
@@ -65,21 +67,23 @@ do_list(struct Client *source_p, int parc, char *parv[])
     dlink_list *list = NULL;
     int i = 0, errors = 0;
 
-    for (opt = strtoken(&save, parv[1], ","); opt != NULL;
-         opt = strtoken(&save, NULL, ","))
+    for (opt = strtoken(&save, parv[1], ","); opt;
+         opt = strtoken(&save,    NULL, ","))
     {
       switch (*opt)
       {
-        case '<': if ((i = atoi(opt + 1)) > 0)
-                    lt->users_max = (unsigned int) i - 1;
-                  else
-                    errors = 1;
-                  break;
-        case '>': if ((i = atoi(opt + 1)) >= 0)
-                    lt->users_min = (unsigned int) i + 1;
-                  else
-                    errors = 1;
-                  break;
+        case '<':
+          if ((i = atoi(opt + 1)) > 0)
+            lt->users_max = (unsigned int)i - 1;
+          else
+            errors = 1;
+          break;
+        case '>':
+          if ((i = atoi(opt + 1)) >= 0)
+            lt->users_min = (unsigned int)i + 1;
+          else
+            errors = 1;
+          break;
         case '-': break;
         case 'C':
         case 'c':
@@ -87,13 +91,13 @@ do_list(struct Client *source_p, int parc, char *parv[])
           {
             case '<':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->created_max = (unsigned int) (CurrentTime - 60 * i);
+                lt->created_max = (unsigned int)(CurrentTime - 60 * i);
               else
                 errors = 1;
               break;
             case '>':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->created_min = (unsigned int) (CurrentTime - 60 * i);
+                lt->created_min = (unsigned int)(CurrentTime - 60 * i);
               else
                 errors = 1;
               break;
@@ -109,13 +113,13 @@ do_list(struct Client *source_p, int parc, char *parv[])
           {
             case '<':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->topicts_min = (unsigned int) (CurrentTime - 60 * i);
+                lt->topicts_min = (unsigned int)(CurrentTime - 60 * i);
               else
                 errors = 1;
               break;
             case '>':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->topicts_max = (unsigned int) (CurrentTime - 60 * i);
+                lt->topicts_max = (unsigned int)(CurrentTime - 60 * i);
               else
                 errors = 1;
               break;
@@ -141,12 +145,9 @@ do_list(struct Client *source_p, int parc, char *parv[])
           }
           else if (!IsChanPrefix(*opt))
             errors = 1;
-          if (!errors)
-          {
-            char *s = xstrdup(opt);
 
-            dlinkAdd(s, make_dlink_node(), list);
-          }
+          if (!errors)
+            dlinkAdd(xstrdup(opt), make_dlink_node(), list);
       }
     }
 
@@ -172,14 +173,16 @@ do_list(struct Client *source_p, int parc, char *parv[])
 **      parv[0] = sender prefix
 **      parv[1] = channel
 */
-static void
+static int
 m_list(struct Client *client_p, struct Client *source_p,
         int parc, char *parv[])
 {
   do_list(source_p, parc, parv);
+  return 0;
 }
 
-static struct Message list_msgtab = {
+static struct Message list_msgtab =
+{
   "LIST", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_list, m_ignore, m_ignore, m_list, m_ignore }
 };
@@ -200,10 +203,11 @@ module_exit(void)
   delete_isupport("SAFELIST");
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2225 $",
+  .version = "$Revision: 2905 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
