@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_locops.c: Sends a message to all operators on the local server.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_locops.c 2639 2013-12-10 18:14:27Z michael $
+ */
+
+/*! \file m_locops.c
+ * \brief Includes required functions for processing the LOCOPS command.
+ * \version $Id: m_locops.c 3191 2014-03-23 18:58:18Z michael $
  */
 
 #include "stdinc.h"
@@ -40,7 +42,7 @@
  *      parv[0] = sender prefix
  *      parv[1] = message text
  */
-static void
+static int
 mo_locops(struct Client *client_p, struct Client *source_p,
           int parc, char *parv[])
 {
@@ -50,43 +52,44 @@ mo_locops(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOPRIVS),
                me.name, source_p->name, "locops");
-    return;
+    return 0;
   }
 
   if (EmptyString(message))
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
                me.name, source_p->name, "LOCOPS");
-    return;
+    return 0;
   }
 
   sendto_realops_flags(UMODE_LOCOPS, L_ALL, SEND_LOCOPS, "from: %s: %s",
                        source_p->name, message);
   cluster_a_line(source_p, "LOCOPS", 0, SHARED_LOCOPS, message);
+  return 0;
 }
 
-static void
+static int
 ms_locops(struct Client *client_p, struct Client *source_p,
           int parc, char *parv[])
 {
   if (parc != 3 || EmptyString(parv[2]))
-    return;
+    return 0;
 
-  sendto_server(client_p, CAP_TS6|CAP_CLUSTER, NOCAPS, ":%s LOCOPS %s :%s",
-                ID(source_p), parv[1], parv[2]);
-  sendto_server(client_p, CAP_CLUSTER, CAP_TS6, ":%s LOCOPS %s :%s",
-                source_p->name, parv[1], parv[2]);
+  sendto_match_servs(source_p, parv[1], CAP_CLUSTER, "LOCOPS %s :%s",
+                     parv[1], parv[2]);
 
-  if (!IsClient(source_p) || match(parv[1], me.name))
-    return;
+  if (match(parv[1], me.name))
+    return 0;
 
   if (find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
                               "*", "*", SHARED_LOCOPS))
     sendto_realops_flags(UMODE_LOCOPS, L_ALL, SEND_LOCOPS, "from: %s: %s",
                          source_p->name, parv[2]);
+  return 0;
 }
 
-static struct Message locops_msgtab = {
+static struct Message locops_msgtab =
+{
   "LOCOPS", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_not_oper, ms_locops, m_ignore, mo_locops, m_ignore }
 };
@@ -103,10 +106,11 @@ module_exit(void)
   mod_del_cmd(&locops_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2639 $",
+  .version = "$Revision: 3191 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
