@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_lusers.c: Sends user statistics.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,16 +17,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_lusers.c 2342 2013-07-03 13:59:41Z michael $
+ */
+
+/*! \file m_lusers.c
+ * \brief Includes required functions for processing the LUSERS command.
+ * \version $Id: m_lusers.c 2821 2014-01-15 23:12:35Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "ircd.h"
 #include "numeric.h"
-#include "s_serv.h"    /* hunt_server */
-#include "s_user.h"    /* show_lusers */
+#include "s_serv.h"
+#include "s_user.h"
 #include "send.h"
 #include "conf.h"
 #include "parse.h"
@@ -44,7 +46,7 @@
  *
  * 2003 hacked parv[1] back in, by request of efnet admins/opers -Dianora
  */
-static void
+static int
 m_lusers(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
@@ -54,7 +56,7 @@ m_lusers(struct Client *client_p, struct Client *source_p,
   {
     /* safe enough to give this on a local connect only */
     sendto_one(source_p, form_str(RPL_LOAD2HI), me.name, source_p->name);
-    return;
+    return 0;
   }
 
   last_used = CurrentTime;
@@ -62,9 +64,10 @@ m_lusers(struct Client *client_p, struct Client *source_p,
   if (parc > 2 && !ConfigServerHide.disable_remote_commands)
     if (hunt_server(client_p, source_p, ":%s LUSERS %s :%s", 2,
                     parc, parv) != HUNTED_ISME)
-      return;
+      return 0;
 
   show_lusers(source_p);
+  return 0;
 }
 
 /* ms_lusers - LUSERS message handler for servers and opers
@@ -72,21 +75,23 @@ m_lusers(struct Client *client_p, struct Client *source_p,
  * parv[1] = host/server mask.
  * parv[2] = server to query
  */
-static void
+static int
 ms_lusers(struct Client *client_p, struct Client *source_p,
           int parc, char *parv[])
 {
   if (parc > 2)
     if (hunt_server(client_p, source_p, ":%s LUSERS %s :%s", 2,
                     parc, parv) != HUNTED_ISME)
-        return;
+        return 0;
 
   show_lusers(source_p);
+  return 0;
 }
 
-static struct Message lusers_msgtab = {
+static struct Message lusers_msgtab =
+{
   "LUSERS", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  {m_unregistered, m_lusers, ms_lusers, m_ignore, ms_lusers, m_ignore}
+  { m_unregistered, m_lusers, ms_lusers, m_ignore, ms_lusers, m_ignore }
 };
 
 static void
@@ -101,10 +106,11 @@ module_exit(void)
   mod_del_cmd(&lusers_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2342 $",
+  .version = "$Revision: 2821 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
