@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_pass.c: Used to send a password for a server or client{} block.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,16 +17,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_pass.c 1834 2013-04-19 19:50:27Z michael $
+ */
+
+/*! \file m_pass.c
+ * \brief Includes required functions for processing the PASS command.
+ * \version $Id: m_pass.c 2821 2014-01-15 23:12:35Z michael $
  */
 
 #include "stdinc.h"
-#include "client.h"      /* client struct */
-#include "irc_string.h" 
-#include "send.h"        /* sendto_one */
-#include "numeric.h"     /* ERR_xxx */
-#include "ircd.h"        /* me */
+#include "client.h"
+#include "irc_string.h"
+#include "send.h"
+#include "numeric.h"
+#include "ircd.h"
 #include "parse.h"
 #include "modules.h"
 #include "s_serv.h"
@@ -45,7 +47,7 @@
  *      parv[1] = password
  *      parv[2] = optional extra version information
  */
-static void
+static int
 mr_pass(struct Client *client_p, struct Client *source_p,
         int parc, char *parv[])
 {
@@ -55,7 +57,7 @@ mr_pass(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS), me.name,
                source_p->name[0] ? source_p->name : "*", "PASS");
-    return;
+    return 0;
   }
 
   MyFree(source_p->localClient->passwd);
@@ -63,18 +65,19 @@ mr_pass(struct Client *client_p, struct Client *source_p,
 
   if (parc > 2)
   {
-    /* It looks to me as if orabidoo wanted to have more
+    /*
+     * It looks to me as if orabidoo wanted to have more
      * than one set of option strings possible here...
      * i.e. ":AABBTS" as long as TS was the last two chars
      * however, as we are now using CAPAB, I think we can
-     * safely assume if there is a ":TS" then its a TS server
+     * safely assume if there is a ":TS" then it's a TS server
      * -Dianora
      */
     if (!irccmp(parv[2], "TS") && source_p->tsinfo == 0)
       source_p->tsinfo = TS_DOESTS;
   }
 
-  /* only do this stuff if we are doing ts6 */
+  /* Only do this stuff if we are doing ts6 */
   if (parc > 4)
   {
     if (atoi(parv[3]) >= 6 && valid_sid(parv[4]))
@@ -83,9 +86,12 @@ mr_pass(struct Client *client_p, struct Client *source_p,
       SetCapable(source_p, CAP_TS6);
     }
   }
+
+  return 0;
 }
 
-static struct Message pass_msgtab = {
+static struct Message pass_msgtab =
+{
   "PASS", 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
   { mr_pass, m_registered, m_ignore, m_ignore, m_registered, mr_pass }
 };
@@ -102,10 +108,11 @@ module_exit(void)
   mod_del_cmd(&pass_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 1834 $",
+  .version = "$Revision: 2821 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
