@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_restart.c: Exits and re-runs ircd.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_restart.c 1834 2013-04-19 19:50:27Z michael $
+ */
+
+/*! \file m_restart.c
+ * \brief Includes required functions for processing the RESTART command.
+ * \version $Id: m_restart.c 2821 2014-01-15 23:12:35Z michael $
  */
 
 #include "stdinc.h"
@@ -38,39 +40,41 @@
  * mo_restart
  *
  */
-static void
+static int
 mo_restart(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
-  char buf[IRCD_BUFSIZE]; 
+  char buf[IRCD_BUFSIZE];
 
   if (!HasOFlag(source_p, OPER_FLAG_RESTART))
   {
-    sendto_one(source_p, form_str(ERR_NOPRIVS),
-               me.name, source_p->name, "restart");
-    return;
+    sendto_one(source_p, form_str(ERR_NOPRIVS), me.name,
+               source_p->name, "restart");
+    return 0;
   }
 
   if (EmptyString(parv[1]))
   {
     sendto_one(source_p, ":%s NOTICE %s :Need server name /restart %s",
                me.name, source_p->name, me.name);
-    return;
+    return 0;
   }
 
   if (irccmp(parv[1], me.name))
   {
     sendto_one(source_p, ":%s NOTICE %s :Mismatch on /restart %s",
                me.name, source_p->name, me.name);
-    return;
+    return 0;
   }
 
   snprintf(buf, sizeof(buf), "received RESTART command from %s",
            get_oper_name(source_p));
   server_die(buf, 1);
+  return 0;
 }
 
-static struct Message restart_msgtab = {
+static struct Message restart_msgtab =
+{
   "RESTART", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_restart, m_ignore }
 };
@@ -87,10 +91,11 @@ module_exit(void)
   mod_del_cmd(&restart_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 1834 $",
+  .version = "$Revision: 2821 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
