@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 1999 by the Bahamut Development Team.
- *  Copyright (C) 2011 by the Hybrid Development Team.
+ *  Copyright (c) 2005-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,8 +20,8 @@
  */
 
 /*! \file m_services.c
- * \brief Provides service aliases
- * \version $Id: m_services.c 2205 2013-06-05 18:41:44Z michael $
+ * \brief Includes required functions for processing the CS/NS/MS/OS/BS services command.
+ * \version $Id: m_services.c 3108 2014-03-06 19:23:59Z michael $
  */
 
 #include "stdinc.h"
@@ -45,7 +44,7 @@
  * Configureable aliases will get implemented.
  */
 
-static void
+static int
 m_nickserv(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -58,21 +57,22 @@ m_nickserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG NickServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
              me.name, source_p->name, "NickServ");
+  return 0;
 }
 
-static void
+static int
 m_chanserv(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -85,21 +85,22 @@ m_chanserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG ChanServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
              me.name, source_p->name, "ChanServ");
+  return 0;
 }
 
-static void
+static int
 m_memoserv(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -112,21 +113,22 @@ m_memoserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG MemoServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
              me.name, source_p->name, "MemoServ");
+  return 0;
 }
 
-static void
+static int
 m_operserv(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -139,21 +141,22 @@ m_operserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG OperServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
              me.name, source_p->name, "OperServ");
+  return 0;
 }
 
-static void
+static int
 m_statserv(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -166,21 +169,22 @@ m_statserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG StatServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
              me.name, source_p->name, "StatServ");
+  return 0;
 }
 
-static void
+static int
 m_hostserv(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
@@ -193,21 +197,22 @@ m_hostserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG HostServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
-             me.name, source_p->name, "HelpServ");
+             me.name, source_p->name, "HostServ");
+  return 0;
 }
 
-static void
+static int
 m_botserv(struct Client *client_p, struct Client *source_p,
           int parc, char *parv[])
 {
@@ -220,89 +225,104 @@ m_botserv(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NOTEXTTOSEND),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((target_p = hash_find_server(ConfigFileEntry.service_name)))
   {
     sendto_one(target_p, ":%s PRIVMSG BotServ@%s :%s",
                source_p->name, ConfigFileEntry.service_name, parv[1]);
-    return;
+    return 0;
   }
 
   sendto_one(source_p, form_str(ERR_SERVICESDOWN),
              me.name, source_p->name, "BotServ");
+  return 0;
 }
 
 
-static struct Message ms_msgtab = {
+static struct Message ms_msgtab =
+{
   "MS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_memoserv, m_ignore, m_ignore, m_memoserv, m_ignore}
+  { m_unregistered, m_memoserv, m_ignore, m_ignore, m_memoserv, m_ignore }
 };
 
-static struct Message ns_msgtab = {
+static struct Message ns_msgtab =
+{
   "NS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_nickserv, m_ignore, m_ignore, m_nickserv, m_ignore}
+  { m_unregistered, m_nickserv, m_ignore, m_ignore, m_nickserv, m_ignore }
 };
 
-static struct Message os_msgtab = {
+static struct Message os_msgtab =
+{
   "OS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_operserv, m_ignore, m_ignore, m_operserv, m_ignore}
+  { m_unregistered, m_operserv, m_ignore, m_ignore, m_operserv, m_ignore }
 };
 
-static struct Message bs_msgtab = {
+static struct Message bs_msgtab =
+{
   "BS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_botserv, m_ignore, m_ignore, m_botserv, m_ignore}
+  { m_unregistered, m_botserv, m_ignore, m_ignore, m_botserv, m_ignore }
 };
 
-static struct Message cs_msgtab = {
+static struct Message cs_msgtab =
+{
   "CS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_chanserv, m_ignore, m_ignore, m_chanserv, m_ignore}
+  { m_unregistered, m_chanserv, m_ignore, m_ignore, m_chanserv, m_ignore }
 };
 
-static struct Message ss_msgtab = {
+static struct Message ss_msgtab =
+{
   "SS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_statserv, m_ignore, m_ignore, m_statserv, m_ignore}
+  { m_unregistered, m_statserv, m_ignore, m_ignore, m_statserv, m_ignore }
 };
 
-static struct Message hs_msgtab = {
+static struct Message hs_msgtab =
+{
   "HS", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_hostserv, m_ignore, m_ignore, m_hostserv, m_ignore}
+  { m_unregistered, m_hostserv, m_ignore, m_ignore, m_hostserv, m_ignore }
 };
 
-static struct Message botserv_msgtab = {
+static struct Message botserv_msgtab =
+{
   "BOTSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_botserv, m_ignore, m_ignore, m_botserv, m_ignore}
+  { m_unregistered, m_botserv, m_ignore, m_ignore, m_botserv, m_ignore }
 };
 
-static struct Message chanserv_msgtab = {
+static struct Message chanserv_msgtab =
+{
   "CHANSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_chanserv, m_ignore, m_ignore, m_chanserv, m_ignore}
+  { m_unregistered, m_chanserv, m_ignore, m_ignore, m_chanserv, m_ignore }
 };
 
-static struct Message memoserv_msgtab = {
+static struct Message memoserv_msgtab =
+{
   "MEMOSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_memoserv, m_ignore, m_ignore, m_memoserv, m_ignore}
+  { m_unregistered, m_memoserv, m_ignore, m_ignore, m_memoserv, m_ignore }
 };
 
-static struct Message nickserv_msgtab = {
+static struct Message nickserv_msgtab =
+{
   "NICKSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_nickserv, m_ignore, m_ignore, m_nickserv, m_ignore}
+  { m_unregistered, m_nickserv, m_ignore, m_ignore, m_nickserv, m_ignore }
 };
 
-static struct Message operserv_msgtab = {
+static struct Message operserv_msgtab =
+{
   "OPERSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_operserv, m_ignore, m_ignore, m_operserv, m_ignore}
+  { m_unregistered, m_operserv, m_ignore, m_ignore, m_operserv, m_ignore }
 };
 
-static struct Message statserv_msgtab = {
+static struct Message statserv_msgtab =
+{
   "STATSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_statserv, m_ignore, m_ignore, m_statserv, m_ignore}
+  { m_unregistered, m_statserv, m_ignore, m_ignore, m_statserv, m_ignore }
 };
 
-static struct Message hostserv_msgtab = {
+static struct Message hostserv_msgtab =
+{
   "HOSTSERV", 0, 0, 0, 1, MFLG_SLOW, 0,
-  {m_unregistered, m_hostserv, m_ignore, m_ignore, m_hostserv, m_ignore}
+  { m_unregistered, m_hostserv, m_ignore, m_ignore, m_hostserv, m_ignore }
 };
 
 
@@ -344,10 +364,11 @@ module_exit(void)
   mod_del_cmd(&hs_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2205 $",
+  .version = "$Revision: 3108 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
