@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  m_whois.c: Shows who a user was.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_whowas.c 2747 2014-01-05 19:19:06Z michael $
+ */
+
+/*! \file m_whowas.c
+ * \brief Includes required functions for processing the WHOWAS command.
+ * \version $Id: m_whowas.c 2987 2014-02-18 09:39:28Z michael $
  */
 
 #include "stdinc.h"
@@ -31,6 +33,7 @@
 #include "ircd.h"
 #include "ircd_defs.h"
 #include "numeric.h"
+#include "s_misc.h"
 #include "s_serv.h"
 #include "s_user.h"
 #include "send.h"
@@ -47,11 +50,6 @@ whowas_do(struct Client *client_p, struct Client *source_p,
   int max = -1;
   const dlink_node *ptr = NULL;
 
-  if (parc > 3)
-    if (hunt_server(client_p, source_p, ":%s WHOWAS %s %s :%s", 3,
-                    parc, parv) != HUNTED_ISME)
-      return;
-
   if (parc > 2 && !EmptyString(parv[2]))
     if ((max = atoi(parv[2])) > 20 && !MyConnect(source_p))
       max = 20;
@@ -95,7 +93,7 @@ whowas_do(struct Client *client_p, struct Client *source_p,
 **      parv[0] = sender prefix
 **      parv[1] = nickname queried
 */
-static void
+static int
 m_whowas(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
@@ -105,22 +103,28 @@ m_whowas(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NONICKNAMEGIVEN),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   if ((last_used + ConfigFileEntry.pace_wait) > CurrentTime)
   {
     sendto_one(source_p,form_str(RPL_LOAD2HI),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
   last_used = CurrentTime;
 
+  if (parc > 3 && !ConfigServerHide.disable_remote_commands)
+    if (hunt_server(client_p, source_p, ":%s WHOWAS %s %s :%s", 3,
+                    parc, parv) != HUNTED_ISME)
+      return 0;
+
   whowas_do(client_p, source_p, parc, parv);
+  return 0;
 }
 
-static void
+static int
 mo_whowas(struct Client *client_p, struct Client *source_p,
           int parc, char *parv[])
 {
@@ -128,13 +132,20 @@ mo_whowas(struct Client *client_p, struct Client *source_p,
   {
     sendto_one(source_p, form_str(ERR_NONICKNAMEGIVEN),
                me.name, source_p->name);
-    return;
+    return 0;
   }
 
+  if (parc > 3)
+    if (hunt_server(client_p, source_p, ":%s WHOWAS %s %s :%s", 3,
+                    parc, parv) != HUNTED_ISME)
+      return 0;
+
   whowas_do(client_p, source_p, parc, parv);
+  return 0;
 }
 
-static struct Message whowas_msgtab = {
+static struct Message whowas_msgtab =
+{
   "WHOWAS", 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
   { m_unregistered, m_whowas, mo_whowas, m_ignore, mo_whowas, m_ignore }
 };
@@ -151,10 +162,11 @@ module_exit(void)
   mod_del_cmd(&whowas_msgtab);
 }
 
-struct module module_entry = {
+struct module module_entry =
+{
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 2747 $",
+  .version = "$Revision: 2987 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
