@@ -1,7 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 2568 2013-11-17 20:24:04Z michael $
+ * \version $Id: channel.c 3046 2014-02-25 21:39:04Z michael $
  */
 
 #include "stdinc.h"
@@ -35,8 +35,7 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
-#include "s_serv.h"             /* captab */
-#include "s_user.h"
+#include "s_serv.h"
 #include "send.h"
 #include "event.h"
 #include "memory.h"
@@ -44,7 +43,6 @@
 #include "s_misc.h"
 #include "resv.h"
 
-struct config_channel_entry ConfigChannel;
 dlink_list global_channel_list = { NULL, NULL, 0 };
 mp_pool_t *ban_pool;    /*! \todo ban_pool shouldn't be a global var */
 
@@ -63,7 +61,6 @@ channel_init(void)
 {
   add_capability("EX", CAP_EX, 1);
   add_capability("IE", CAP_IE, 1);
-  add_capability("CHW", CAP_CHW, 1);
 
   channel_pool = mp_pool_new(sizeof(struct Channel), MP_CHUNK_SIZE_CHANNEL);
   ban_pool = mp_pool_new(sizeof(struct Ban), MP_CHUNK_SIZE_BAN);
@@ -437,6 +434,7 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
   int tlen = 0;
   int is_member = IsMember(source_p, chptr);
   int multi_prefix = HasCap(source_p, CAP_MULTI_PREFIX) != 0;
+  int uhnames = HasCap(source_p, CAP_UHNAMES) != 0;
 
   if (PubChannel(chptr) || is_member)
   {
@@ -452,7 +450,11 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
       if (HasUMode(ms->client_p, UMODE_INVISIBLE) && !is_member)
         continue;
 
-      tlen = strlen(ms->client_p->name) + 1;  /* nick + space */
+      if (!uhnames)
+        tlen = strlen(ms->client_p->name) + 1;  /* nick + space */
+      else
+        tlen = strlen(ms->client_p->name) + strlen(ms->client_p->username) +
+               strlen(ms->client_p->host) + 3;
 
       if (!multi_prefix)
       {
@@ -476,8 +478,13 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
         t = start;
       }
 
-      t += sprintf(t, "%s%s ", get_member_status(ms, multi_prefix),
-                   ms->client_p->name);
+      if (!uhnames)
+        t += sprintf(t, "%s%s ", get_member_status(ms, multi_prefix),
+                     ms->client_p->name);
+      else
+        t += sprintf(t, "%s%s!%s@%s ", get_member_status(ms, multi_prefix),
+                     ms->client_p->name, ms->client_p->username,
+                     ms->client_p->host);
     }
 
     if (tlen != 0)
@@ -488,8 +495,8 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
   }
 
   if (show_eon)
-    sendto_one(source_p, form_str(RPL_ENDOFNAMES),
-               me.name, source_p->name, chptr->chname);
+    sendto_one(source_p, form_str(RPL_ENDOFNAMES), me.name,
+               source_p->name, chptr->chname);
 }
 
 /*! \brief adds client to invite list
