@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  client.c: Controls clients.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: client.c 2740 2014-01-04 20:04:39Z michael $
+ */
+
+/*! \file client.c
+ * \brief Controls clients.
+ * \version $Id: client.c 3193 2014-03-23 19:49:55Z michael $
  */
 
 #include "stdinc.h"
@@ -76,7 +78,6 @@ static dlink_node *eac_next;  /* next aborted client to exit */
 
 static void check_pings_list(dlink_list *);
 static void check_unknowns_list(void);
-static void ban_them(struct Client *, struct MaskItem *);
 
 
 /* client_init()
@@ -358,7 +359,7 @@ check_conf_klines(void)
       if (conf->type == CONF_EXEMPT)
         continue;
 
-      ban_them(client_p, conf);
+      conf_try_ban(client_p, conf);
       continue; /* and go examine next fd/client_p */
     }
 
@@ -368,16 +369,7 @@ check_conf_klines(void)
                                        CONF_GLINE, client_p->localClient->aftype,
                                        client_p->username, NULL, 1)))
       {
-        if (IsExemptKline(client_p) ||
-            IsExemptGline(client_p))
-        {
-          sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                               "GLINE over-ruled for %s, client is %sline_exempt",
-                               get_client_name(client_p, HIDE_IP), IsExemptKline(client_p) ? "k" : "g");
-          continue;
-        }
-
-        ban_them(client_p, conf);
+        conf_try_ban(client_p, conf);
         /* and go examine next fd/client_p */
         continue;
       }
@@ -387,22 +379,14 @@ check_conf_klines(void)
                                      CONF_KLINE, client_p->localClient->aftype,
                                      client_p->username, NULL, 1)))
     {
-      if (IsExemptKline(client_p))
-      {
-        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                             "KLINE over-ruled for %s, client is kline_exempt",
-                             get_client_name(client_p, HIDE_IP));
-        continue;
-      }
-
-      ban_them(client_p, conf);
+      conf_try_ban(client_p, conf);
       continue;
     }
 
     if ((conf = find_matching_name_conf(CONF_XLINE,  client_p->info,
                                         NULL, NULL, 0)))
     {
-      ban_them(client_p, conf);
+      conf_try_ban(client_p, conf);
       continue;
     }
   }
@@ -424,15 +408,15 @@ check_conf_klines(void)
 }
 
 /*
- * ban_them
+ * conf_try_ban
  *
  * inputs	- pointer to client to ban
  * 		- pointer to MaskItem
  * output	- NONE
  * side effects	- given client_p is banned
  */
-static void
-ban_them(struct Client *client_p, struct MaskItem *conf)
+void
+conf_try_ban(struct Client *client_p, struct MaskItem *conf)
 {
   const char *user_reason = NULL;  /* What is sent to user */
   const char *type_string = NULL;
@@ -444,12 +428,29 @@ ban_them(struct Client *client_p, struct MaskItem *conf)
   switch (conf->type)
   {
     case CONF_KLINE:
+      if (IsExemptKline(client_p))
+      {
+        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+                             "KLINE over-ruled for %s, client is kline_exempt",
+                             get_client_name(client_p, HIDE_IP));
+        return;
+      }
+
       type_string = kline_string;
       break;
     case CONF_DLINE:
       type_string = dline_string;
       break;
     case CONF_GLINE:
+      if (IsExemptKline(client_p) ||
+          IsExemptGline(client_p))
+      {
+        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+                             "GLINE over-ruled for %s, client is %sline_exempt",
+                             get_client_name(client_p, HIDE_IP), IsExemptKline(client_p) ? "k" : "g");
+        return;
+      }
+
       type_string = gline_string;
       break;
     case CONF_XLINE:
@@ -507,7 +508,7 @@ update_client_exit_stats(struct Client *client_p)
  * side effects - find person by (nick)name
  */
 struct Client *
-find_person(const struct Client *client_p, const char *name)
+find_person(const struct Client *const client_p, const char *name)
 {
   struct Client *target_p = NULL;
 
@@ -525,17 +526,13 @@ find_person(const struct Client *client_p, const char *name)
 /*
  * find_chasing - find the client structure for a nick name (name)
  *      using history mechanism if necessary. If the client is not found,
- *      an error message (NO SUCH NICK) is generated. If the client was found
- *      through the history, chasing will be 1 and otherwise 0.
+ *      an error message (NO SUCH NICK) is generated.
  */
 struct Client *
-find_chasing(struct Client *source_p, const char *name, int *const chasing)
+find_chasing(struct Client *source_p, const char *name)
 {
   struct Client *who = find_person(source_p->from, name);
 
-  if (chasing)
-    *chasing = 0;
-
   if (who)
     return who;
 
@@ -551,9 +548,6 @@ find_chasing(struct Client *source_p, const char *name, int *const chasing)
     return NULL;
   }
 
-  if (chasing)
-    *chasing = 1;
-
   return who;
 }
 
