@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  conf.c: Configuration file functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: conf.c 2735 2014-01-03 19:37:07Z michael $
+ */
+
+/*! \file conf.c
+ * \brief Configuration file functions.
+ * \version $Id: conf.c 3264 2014-04-03 19:29:14Z michael $
  */
 
 #include "stdinc.h"
@@ -55,7 +57,13 @@
 #include "conf_class.h"
 #include "motd.h"
 
+
+struct config_channel_entry ConfigChannel;
 struct config_server_hide ConfigServerHide;
+struct config_file_entry ConfigFileEntry;
+struct logging_entry ConfigLoggingEntry = { .use_logging = 1 };
+struct server_info ServerInfo;
+struct admin_info AdminInfo;
 
 /* general conf items link list root, other than k lines etc. */
 dlink_list service_items = { NULL, NULL, 0 };
@@ -238,9 +246,9 @@ int
 check_client(struct Client *source_p)
 {
   int i;
- 
+
   if ((i = verify_access(source_p)))
-    ilog(LOG_TYPE_IRCD, "Access denied: %s[%s]", 
+    ilog(LOG_TYPE_IRCD, "Access denied: %s[%s]",
          source_p->name, source_p->sockhost);
 
   switch (i)
@@ -264,7 +272,7 @@ check_client(struct Client *source_p)
       ilog(LOG_TYPE_IRCD, "Too many connections from %s.",
            get_client_name(source_p, SHOW_IP));
       ++ServerStats.is_ref;
-      exit_client(source_p, &me, 
+      exit_client(source_p, &me,
                   "No more connections allowed in your connection class");
       break;
 
@@ -362,7 +370,7 @@ verify_access(struct Client *client_p)
       if (IsConfGline(conf))
         sendto_one(client_p, ":%s NOTICE %s :*** G-lined", me.name,
                    client_p->name);
-      sendto_one(client_p, ":%s NOTICE %s :*** Banned: %s", 
+      sendto_one(client_p, ":%s NOTICE %s :*** Banned: %s",
                  me.name, client_p->name, conf->reason);
       return BANNED_CLIENT;
     }
@@ -579,8 +587,8 @@ hash_ip(struct irc_ssaddr *addr)
     uint32_t *ip = (uint32_t *)&v6->sin6_addr.s6_addr;
 
     hash  = ip[0] ^ ip[3];
-    hash ^= hash >> 16;  
-    hash ^= hash >> 8;   
+    hash ^= hash >> 16;
+    hash ^= hash >> 8;
     hash  = hash & (IP_HASH_SIZE - 1);
     return hash;
   }
@@ -591,7 +599,7 @@ hash_ip(struct irc_ssaddr *addr)
 
 /* count_ip_hash()
  *
- * inputs        - pointer to counter of number of ips hashed 
+ * inputs        - pointer to counter of number of ips hashed
  *               - pointer to memory used for ip hash
  * output        - returned via pointers input
  * side effects  - NONE
@@ -779,7 +787,7 @@ find_conf_name(dlink_list *list, const char *name, enum maskitem_type type)
   DLINK_FOREACH(ptr, list->head)
   {
     conf = ptr->data;
-    
+
     if (conf->type == type)
     {
       if (conf->name && (irccmp(conf->name, name) == 0 ||
@@ -897,7 +905,7 @@ find_matching_name_conf(enum maskitem_type type, const char *name, const char *u
         return conf;
     }
     break;
-  
+
   default:
     break;
   }
@@ -934,7 +942,7 @@ find_exact_name_conf(enum maskitem_type type, const struct Client *who, const ch
 
       if (EmptyString(conf->name))
         continue;
-    
+
       if (irccmp(conf->name, name) == 0)
       {
         if ((user == NULL && (host == NULL)))
@@ -1000,7 +1008,7 @@ find_exact_name_conf(enum maskitem_type type, const struct Client *who, const ch
 
       if (EmptyString(conf->name))
         continue;
-    
+
       if (name == NULL)
       {
         if (EmptyString(conf->host))
@@ -1032,7 +1040,7 @@ rehash(int sig)
 {
   if (sig != 0)
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "Got signal SIGHUP, reloading ircd.conf file");
+                         "Got signal SIGHUP, reloading configuration file(s)");
 
   restart_resolver();
 
@@ -1121,7 +1129,6 @@ set_default_conf(void)
   ConfigServerHide.hide_server_ips = 0;
   ConfigServerHide.disable_remote_commands = 0;
 
-  
   ConfigFileEntry.service_name = xstrdup(SERVICE_NAME_DEFAULT);
   ConfigFileEntry.max_watch = WATCHSIZE_DEFAULT;
   ConfigFileEntry.cycle_on_host_change = 1;
@@ -1193,7 +1200,7 @@ validate_conf(void)
   ConfigFileEntry.max_watch = IRCD_MAX(ConfigFileEntry.max_watch, WATCHSIZE_MIN);
 }
 
-/* read_conf() 
+/* read_conf()
  *
  * inputs       - file descriptor pointing to config file to use
  * output       - None
@@ -1297,7 +1304,7 @@ void
 cleanup_tklines(void *notused)
 {
   hostmask_expire_temporary();
-  expire_tklines(&xconf_items); 
+  expire_tklines(&xconf_items);
   expire_tklines(&nresv_items);
   expire_tklines(&cresv_items);
 }
@@ -1364,7 +1371,7 @@ static const struct oper_privs
   { OPER_FLAG_SQUIT,          'R' },
   { OPER_FLAG_SQUIT_REMOTE,   'S' },
   { OPER_FLAG_UNKLINE,        'U' },
-  { OPER_FLAG_X,              'X' },
+  { OPER_FLAG_XLINE,          'X' },
   { 0, '\0' }
 };
 
@@ -1397,7 +1404,7 @@ oper_privs_as_string(const unsigned int port)
 const char *
 get_oper_name(const struct Client *client_p)
 {
-  dlink_node *cnode = NULL;
+  const dlink_node *cnode = NULL;
   /* +5 for !,@,{,} and null */
   static char buffer[NICKLEN + USERLEN + HOSTLEN + HOSTLEN + 5];
 
@@ -1405,7 +1412,7 @@ get_oper_name(const struct Client *client_p)
   {
     if ((cnode = client_p->localClient->confs.head))
     {
-      struct MaskItem *conf = cnode->data;
+      const struct MaskItem *conf = cnode->data;
 
       if (IsConfOperator(conf))
       {
@@ -1415,7 +1422,7 @@ get_oper_name(const struct Client *client_p)
       }
     }
 
-    /* Probably should assert here for now. If there is an oper out there 
+    /* Probably should assert here for now. If there is an oper out there
      * with no oper{} conf attached, it would be good for us to know...
      */
     assert(0); /* Oper without oper conf! */
@@ -1446,7 +1453,7 @@ read_conf_files(int cold)
      FIXME: The full path is in conffilenamebuf first time since we
              dont know anything else
 
-     - Gozem 2002-07-21 
+     - Gozem 2002-07-21
   */
   strlcpy(conffilebuf, filename, sizeof(conffilebuf));
 
@@ -1520,7 +1527,7 @@ clear_out_old_conf(void)
   /* We only need to free anything allocated by yyparse() here.
    * Resetting structs, etc, is taken care of by set_default_conf().
    */
-  
+
   for (; *iterator != NULL; iterator++)
   {
     DLINK_FOREACH_SAFE(ptr, next_ptr, (*iterator)->head)
@@ -1607,12 +1614,12 @@ clear_out_old_conf(void)
  *
  * inputs       - pointer to config item
  * output       - NONE
- * side effects - Add a class pointer to a conf 
+ * side effects - Add a class pointer to a conf
  */
 void
 conf_add_class_to_conf(struct MaskItem *conf, const char *class_name)
 {
-  if (class_name == NULL) 
+  if (class_name == NULL)
   {
     conf->class = class_default;
 
@@ -1679,7 +1686,7 @@ conf_error_report(const char *msg)
 
 /*
  * valid_tkline()
- * 
+ *
  * inputs       - pointer to ascii string to check
  *              - whether the specified time is in seconds or minutes
  * output       - -1 not enough parameters
@@ -1704,19 +1711,19 @@ valid_tkline(const char *data, const int minutes)
   }
 
   /*
-   * In the degenerate case where oper does a /quote kline 0 user@host :reason 
+   * In the degenerate case where oper does a /quote kline 0 user@host :reason
    * i.e. they specifically use 0, I am going to return 1 instead
    * as a return value of non-zero is used to flag it as a temporary kline
    */
   if (result == 0)
     result = 1;
 
-  /* 
+  /*
    * If the incoming time is in seconds convert it to minutes for the purpose
    * of this calculation
    */
   if (!minutes)
-    result = result / 60; 
+    result = result / 60;
 
   if (result > MAX_TDKLINE_TIME)
     result = MAX_TDKLINE_TIME;
@@ -1826,7 +1833,7 @@ valid_wild_card(struct Client *source_p, int warn, int count, ...)
  *		- parse_flags bit map of things to test
  *		- pointer to user or string to parse into
  *              - pointer to host or NULL to parse into if non NULL
- *              - pointer to optional tkline time or NULL 
+ *              - pointer to optional tkline time or NULL
  *              - pointer to target_server to parse into if non NULL
  *              - pointer to reason to parse into
  *
@@ -1894,7 +1901,7 @@ parse_aline(const char *cmd, struct Client *source_p,
     *up_p = user;
     *h_p = host;
   }
- 
+
   parc--;
   parv++;
 
@@ -2016,15 +2023,15 @@ find_user_host(struct Client *source_p, char *user_host_or_nick,
       luser[1] = '\0';
       strlcpy(lhost, user_host_or_nick, HOSTLEN*4 + 1);
     }
-    
+
     return 1;
   }
   else
   {
     /* Try to find user@host mask from nick */
     /* Okay to use source_p as the first param, because source_p == client_p */
-    if ((target_p = 
-        find_chasing(source_p, user_host_or_nick, NULL)) == NULL)
+    if ((target_p =
+        find_chasing(source_p, user_host_or_nick)) == NULL)
       return 0;
 
     if (IsExemptKline(target_p))
@@ -2093,7 +2100,7 @@ match_conf_password(const char *password, const struct MaskItem *conf)
   else
     encr = password;
 
-  return !strcmp(encr, conf->passwd);
+  return encr && !strcmp(encr, conf->passwd);
 }
 
 /*
