@@ -1,8 +1,8 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (C) 1996-2009 by Andrew Church <achurch@achurch.org>
- *  Copyright (C) 2012 by the Hybrid Development Team.
+ *  Copyright (c) 2012-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,9 +22,10 @@
 
 /*! \file conf_db.c
  * \brief Includes file utilities for database handling
- * \version $Id: conf_db.c 2173 2013-06-03 19:40:02Z michael $
+ * \version $Id: conf_db.c 3068 2014-02-27 19:09:21Z michael $
  */
 
+
 #include "stdinc.h"
 #include "conf_db.h"
 #include "memory.h"
@@ -103,7 +104,7 @@ open_db_read(const char *filename)
     int errno_save = errno;
 
     if (errno != ENOENT)
-      ilog(LOG_TYPE_IRCD, "Can't read database file %s", f->filename);
+      ilog(LOG_TYPE_IRCD, "Cannot read database file %s", f->filename);
 
     MyFree(f);
     errno = errno_save;
@@ -155,11 +156,11 @@ open_db_write(const char *filename, uint32_t version)
 
     if (!walloped++)
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Can't create temporary database file %s",
+                           "Cannot create temporary database file %s",
                            f->tempname);
 
     errno = errno_save;
-    ilog(LOG_TYPE_IRCD, "Can't create temporary database file %s",
+    ilog(LOG_TYPE_IRCD, "Cannot create temporary database file %s",
         f->tempname);
 
     if (f->fp)
