@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  hostmask.c: Code to efficiently find IP & hostmask based configs.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2005 by the past and present ircd coders, and others.
+ *  Copyright (c) 2001-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: hostmask.c 2332 2013-06-23 13:52:31Z michael $
+ */
+
+/*! \file hostmask.c
+ * \brief Code to efficiently find IP & hostmask based configs.
+ * \version $Id: hostmask.c 3006 2014-02-19 10:40:26Z michael $
  */
 
 #include "stdinc.h"
@@ -51,7 +53,7 @@
  * Side effects: None
  * Comments: Called from parse_netmask
  */
-/* Fixed so ::/0 (any IPv6 address) is valid 
+/* Fixed so ::/0 (any IPv6 address) is valid
    Also a bug in DigitParse above.
    -Gozem 2002-07-19 gozem@linux.nu
 */
@@ -71,6 +73,7 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)addr;
 
   for (p = text; (c = *p); p++)
+  {
     if (IsXDigit(c))
     {
       if (nyble == 0)
@@ -119,6 +122,7 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
     }
     else
       return HM_HOST;
+  }
 
   d[dp] = d[dp] >> 4 * nyble;
 
@@ -180,6 +184,7 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   digits[n++] = text;
 
   for (p = text; (c = *p); p++)
+  {
     if (c >= '0' && c <= '9')   /* empty */
       ;
     else if (c == '.')
@@ -211,6 +216,7 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
     }
     else
       return HM_HOST;
+  }
 
   if (n < 4 && bits == 0)
     bits = n * 8;
@@ -247,12 +253,12 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 int
 parse_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 {
+  if (strchr(text, '.'))
+    return try_parse_v4_netmask(text, addr, b);
 #ifdef IPV6
   if (strchr(text, ':'))
     return try_parse_v6_netmask(text, addr, b);
 #endif
-  if (strchr(text, '.'))
-    return try_parse_v4_netmask(text, addr, b);
   return HM_HOST;
 }
 
@@ -357,11 +363,11 @@ init_host_hash(void)
  * Side effects: None
  */
 static uint32_t
-hash_ipv4(struct irc_ssaddr *addr, int bits)
+hash_ipv4(const struct irc_ssaddr *addr, int bits)
 {
   if (bits != 0)
   {
-    struct sockaddr_in *v4 = (struct sockaddr_in *)addr;
+    const struct sockaddr_in *v4 = (const struct sockaddr_in *)addr;
     uint32_t av = ntohl(v4->sin_addr.s_addr) & ~((1 << (32 - bits)) - 1);
 
     return (av ^ (av >> 12) ^ (av >> 24)) & (ATABLE_SIZE - 1);
@@ -377,10 +383,10 @@ hash_ipv4(struct irc_ssaddr *addr, int bits)
  */
 #ifdef IPV6
 static uint32_t
-hash_ipv6(struct irc_ssaddr *addr, int bits)
+hash_ipv6(const struct irc_ssaddr *addr, int bits)
 {
   uint32_t v = 0, n;
-  struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)addr;
+  const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)addr;
 
   for (n = 0; n < 16; n++)
   {
@@ -458,11 +464,6 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
   int b;
   int (*cmpfunc)(const char *, const char *) = do_match ? match : irccmp;
 
-  if (username == NULL)
-    username = "";
-  if (password == NULL)
-    password = "";
-
   if (addr)
   {
     /* Check for IPV6 matches... */
@@ -473,16 +474,16 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
       {
         DLINK_FOREACH(ptr, atable[hash_ipv6(addr, b)].head)
         {
-          arec = ptr->data; 
+          arec = ptr->data;
 
-          if (arec->type == (type & ~0x1) &&
+          if ((arec->type == type) &&
               arec->precedence > hprecv &&
               arec->masktype == HM_IPV6 &&
               match_ipv6(addr, &arec->Mask.ipa.addr,
                          arec->Mask.ipa.bits) &&
-              (type & 0x1 || !cmpfunc(arec->username, username)) &&
-	      (IsNeedPassword(arec->conf) || arec->conf->passwd == NULL ||
-	       match_conf_password(password, arec->conf)))
+              (!username || !cmpfunc(arec->username, username)) &&
+              (IsNeedPassword(arec->conf) || arec->conf->passwd == NULL ||
+               match_conf_password(password, arec->conf)))
           {
             hprecv = arec->precedence;
             hprec = arec->conf;
@@ -500,14 +501,14 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
         {
           arec = ptr->data;
 
-          if (arec->type == (type & ~0x1) &&
+          if ((arec->type == type) &&
               arec->precedence > hprecv &&
               arec->masktype == HM_IPV4 &&
               match_ipv4(addr, &arec->Mask.ipa.addr,
                          arec->Mask.ipa.bits) &&
-              (type & 0x1 || !cmpfunc(arec->username, username)) &&
-	      (IsNeedPassword(arec->conf) || arec->conf->passwd == NULL ||
-	       match_conf_password(password, arec->conf)))
+              (!username || !cmpfunc(arec->username, username)) &&
+              (IsNeedPassword(arec->conf) || arec->conf->passwd == NULL ||
+               match_conf_password(password, arec->conf)))
           {
             hprecv = arec->precedence;
             hprec = arec->conf;
@@ -526,11 +527,11 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
         DLINK_FOREACH(ptr, atable[hash_text(p)].head)
         {
           arec = ptr->data;
-          if ((arec->type == (type & ~0x1)) &&
+          if ((arec->type == type) &&
             arec->precedence > hprecv &&
             (arec->masktype == HM_HOST) &&
             !cmpfunc(arec->Mask.hostname, name) &&
-            (type & 0x1 || !cmpfunc(arec->username, username)) &&
+            (!username || !cmpfunc(arec->username, username)) &&
             (IsNeedPassword(arec->conf) || arec->conf->passwd == NULL ||
              match_conf_password(password, arec->conf)))
         {
@@ -548,11 +549,11 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
     {
       arec = ptr->data;
 
-      if (arec->type == (type & ~0x1) &&
+      if (arec->type == type &&
           arec->precedence > hprecv &&
           arec->masktype == HM_HOST &&
           !cmpfunc(arec->Mask.hostname, name) &&
-          (type & 0x1 || !cmpfunc(arec->username, username)) &&
+          (!username || !cmpfunc(arec->username, username)) &&
           (IsNeedPassword(arec->conf) || arec->conf->passwd == NULL ||
            match_conf_password(password, arec->conf)))
       {
@@ -617,38 +618,31 @@ find_dline_conf(struct irc_ssaddr *addr, int aftype)
 {
   struct MaskItem *eline;
 
-  eline = find_conf_by_address(NULL, addr, CONF_EXEMPT | 1, aftype,
-                               NULL, NULL, 1);
+  eline = find_conf_by_address(NULL, addr, CONF_EXEMPT, aftype, NULL, NULL, 1);
   if (eline != NULL)
     return eline;
 
-  return find_conf_by_address(NULL, addr, CONF_DLINE | 1, aftype, NULL, NULL, 1);
+  return find_conf_by_address(NULL, addr, CONF_DLINE, aftype, NULL, NULL, 1);
 }
 
 /* void add_conf_by_address(int, struct MaskItem *aconf)
- * Input: 
+ * Input:
  * Output: None
  * Side-effects: Adds this entry to the hash table.
  */
-void
+struct AddressRec *
 add_conf_by_address(const unsigned int type, struct MaskItem *conf)
 {
-  const char *address;
-  const char *username;
+  const char *hostname = conf->host;
+  const char *username = conf->user;
   static unsigned int prec_value = 0xFFFFFFFF;
   int bits = 0;
-  struct AddressRec *arec;
+  struct AddressRec *arec = NULL;
 
-  address = conf->host;
-  username = conf->user;
-
-  assert(type);
-
-  if (EmptyString(address))
-    address = "/NOMATCH!/";
+  assert(type && !EmptyString(hostname));
 
   arec = MyMalloc(sizeof(struct AddressRec));
-  arec->masktype = parse_netmask(address, &arec->Mask.ipa.addr, &bits);
+  arec->masktype = parse_netmask(hostname, &arec->Mask.ipa.addr, &bits);
   arec->Mask.ipa.bits = bits;
   arec->username = username;
   arec->conf = conf;
@@ -670,10 +664,12 @@ add_conf_by_address(const unsigned int type, struct MaskItem *conf)
       break;
 #endif
     default: /* HM_HOST */
-      arec->Mask.hostname = address;
-      dlinkAdd(arec, &arec->node, &atable[get_mask_hash(address)]);
+      arec->Mask.hostname = hostname;
+      dlinkAdd(arec, &arec->node, &atable[get_mask_hash(hostname)]);
       break;
   }
+
+  return arec;
 }
 
 /* void delete_one_address(const char*, struct MaskItem*)
@@ -731,14 +727,14 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
  * Output: None
  * Side effects: Clears out all address records in the hash table,
  *               frees them, and frees the MaskItems if nothing references
- *               them, otherwise sets them as illegal.   
+ *               them, otherwise sets them as illegal.
  */
 void
 clear_out_address_conf(void)
 {
   unsigned int i = 0;
   dlink_node *ptr = NULL, *ptr_next = NULL;
- 
+
   for (i = 0; i < ATABLE_SIZE; ++i)
   {
     DLINK_FOREACH_SAFE(ptr, ptr_next, atable[i].head)
@@ -782,7 +778,7 @@ hostmask_send_expiration(struct AddressRec *arec)
       break;
     default: break;
   }
-  
+
   sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                        "Temporary %c-line for [%s@%s] expired", ban_type,
                        (arec->conf->user) ? arec->conf->user : "*",
