@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  irc_string.c: IRC string functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: irc_string.c 1920 2013-04-30 14:51:30Z michael $
+ */
+
+/*! \file irc_string.c
+ * \brief IRC string functions.
+ * \version $Id: irc_string.c 2971 2014-01-31 11:23:59Z michael $
  */
 
 #include "config.h"
@@ -28,42 +30,24 @@
 
 
 int
-has_wildcards(const char *s)
+has_wildcards(const char *str)
 {
-  char c;
+  const unsigned char *p = (const unsigned char *)str;
 
-  while ((c = *s++))
-    if (IsMWildChar(c))
+  for (; *p; ++p)
+  {
+    if (*p == '\\')
+    {
+      if (*++p == '\0')
+        return 0;
+    }
+    else if (IsMWildChar(*p))
       return 1;
+  }
 
   return 0;
 }
 
-/*
- * myctime - This is like standard ctime()-function, but it zaps away
- *   the newline from the end of that string. Also, it takes
- *   the time value as parameter, instead of pointer to it.
- *   Note that it is necessary to copy the string to alternate
- *   buffer (who knows how ctime() implements it, maybe it statically
- *   has newline there and never 'refreshes' it -- zapping that
- *   might break things in other places...)
- *
- *
- * Thu Nov 24 18:22:48 1986 
- */
-const char *
-myctime(time_t value)
-{
-  static char buf[32];
-  char *p;
-
-  strlcpy(buf, ctime(&value), sizeof(buf));
-
-  if ((p = strchr(buf, '\n')) != NULL)
-    *p = '\0';
-  return buf;
-}
-
 /*
  * strip_tabs(dst, src, length)
  *
@@ -91,7 +75,6 @@ strip_tabs(char *dest, const char *src, size_t len)
  *
  */
 #ifndef HAVE_STRTOK_R
-
 char *
 strtoken(char** save, char* str, const char* fs)
 {
@@ -143,7 +126,7 @@ libio_basename(const char *path)
 
 /*
  * strlcat and strlcpy were ripped from openssh 2.5.1p2
- * They had the following Copyright info: 
+ * They had the following Copyright info:
  *
  *
  * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
@@ -154,9 +137,9 @@ libio_basename(const char *path)
  * are met:
  * 1. Redistributions of source code must retain the above copyright
  *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright    
- *    notice, this list of conditions and the following disclaimer in the  
- *    documentation and/or other materials provided with the distribution. 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  * 3. The name of the author may not be used to endorse or promote products
  *    derived from this software without specific prior written permission.
  *
@@ -171,7 +154,7 @@ libio_basename(const char *path)
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
- 
+
 #ifndef HAVE_STRLCAT
 size_t
 strlcat(char *dst, const char *src, size_t siz)
