@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  ircd.c: Starts up and runs the ircd.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: ircd.c 2690 2013-12-17 18:55:43Z michael $
+ */
+
+/*! \file ircd.c
+ * \brief Starts up and runs the ircd.
+ * \version $Id: ircd.c 3265 2014-04-05 19:09:02Z michael $
  */
 
 #include "stdinc.h"
@@ -65,18 +67,11 @@
 #ifdef HAVE_LIBGEOIP
 GeoIP *geoip_ctx;
 #endif
+
 /* /quote set variables */
 struct SetOptions GlobalSetOptions;
-
-/* configuration set from ircd.conf */
-struct config_file_entry ConfigFileEntry; 
-/* server info set from ircd.conf */
-struct server_info ServerInfo;
-/* admin info set from ircd.conf */
-struct admin_info AdminInfo = { NULL, NULL, NULL };
-struct Counter Count = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
-struct ServerState_t server_state = { 0 };
-struct logging_entry ConfigLoggingEntry = { .use_logging = 1 };
+struct Counter Count;
+struct ServerState_t server_state;
 struct ServerStatistics ServerStats;
 struct timeval SystemTime;
 struct Client me;             /* That's me */
@@ -146,25 +141,25 @@ make_daemon(void)
 static int printVersion = 0;
 
 static struct lgetopt myopts[] = {
-  {"configfile", &ConfigFileEntry.configfile, 
+  {"configfile", &ConfigFileEntry.configfile,
    STRING, "File to use for ircd.conf"},
   {"glinefile",  &ConfigFileEntry.glinefile,
    STRING, "File to use for gline database"},
-  {"klinefile",  &ConfigFileEntry.klinefile, 
+  {"klinefile",  &ConfigFileEntry.klinefile,
    STRING, "File to use for kline database"},
   {"dlinefile",  &ConfigFileEntry.dlinefile,
    STRING, "File to use for dline database"},
-  {"xlinefile",  &ConfigFileEntry.xlinefile, 
+  {"xlinefile",  &ConfigFileEntry.xlinefile,
    STRING, "File to use for xline database"},
   {"resvfile",  &ConfigFileEntry.resvfile,
    STRING, "File to use for resv database"},
-  {"logfile",    &logFileName, 
+  {"logfile",    &logFileName,
    STRING, "File to use for ircd.log"},
   {"pidfile",    &pidFileName,
    STRING, "File to use for process ID"},
-  {"foreground", &server_state.foreground, 
+  {"foreground", &server_state.foreground,
    YESNO, "Run in foreground (don't detach)"},
-  {"version",    &printVersion, 
+  {"version",    &printVersion,
    YESNO, "Print version and exit"},
   {"help", NULL, USAGE, "Print this text"},
   {NULL, NULL, STRING, NULL},
@@ -173,10 +168,7 @@ static struct lgetopt myopts[] = {
 void
 set_time(void)
 {
-  static char to_send[IRCD_BUFSIZE];
-  struct timeval newtime;
-  newtime.tv_sec  = 0;
-  newtime.tv_usec = 0;
+  struct timeval newtime = { .tv_sec = 0, .tv_usec = 0 };
 
   if (gettimeofday(&newtime, NULL) == -1)
   {
@@ -190,10 +182,12 @@ set_time(void)
 
   if (newtime.tv_sec < CurrentTime)
   {
-    snprintf(to_send, sizeof(to_send),
-             "System clock is running backwards - (%lu < %lu)",
-             (unsigned long)newtime.tv_sec, (unsigned long)CurrentTime);
-    report_error(L_ALL, to_send, me.name, 0);
+    ilog(LOG_TYPE_IRCD, "System clock is running backwards - (%lu < %lu)",
+         (unsigned long)newtime.tv_sec, (unsigned long)CurrentTime);
+    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
+                         "System clock is running backwards - (%lu < %lu)",
+                         (unsigned long)newtime.tv_sec,
+                         (unsigned long)CurrentTime);
     set_back_events(CurrentTime - newtime.tv_sec);
   }
 
@@ -208,7 +202,7 @@ io_loop(void)
   {
     /*
      * Maybe we want a flags word?
-     * ie. if (REHASHED_KLINES(global_flags)) 
+     * ie. if (REHASHED_KLINES(global_flags))
      * SET_REHASHED_KLINES(global_flags)
      * CLEAR_REHASHED_KLINES(global_flags)
      *
@@ -240,7 +234,6 @@ io_loop(void)
     comm_select();
     exit_aborted_clients();
     free_exited_clients();
-    send_queued_all();
 
     /* Check to see whether we have to rehash the configuration .. */
     if (dorehash)
@@ -252,7 +245,7 @@ io_loop(void)
     {
       motd_recache();
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Got signal SIGUSR1, reloading motd files");
+                           "Got signal SIGUSR1, reloading motd file(s)");
       doremotd = 0;
     }
   }
@@ -262,7 +255,7 @@ io_loop(void)
  *
  * inputs       - none
  * output       - none
- * side effects - This sets all global set options needed 
+ * side effects - This sets all global set options needed
  */
 static void
 initialize_global_set_options(void)
@@ -308,8 +301,8 @@ initialize_server_capabs(void)
   add_capability("EOB", CAP_EOB, 1);
   add_capability("TS6", CAP_TS6, 0);
   add_capability("CLUSTER", CAP_CLUSTER, 1);
-//  add_capability("FAKEHOST", CAP_FAKEHOST, 1);
   add_capability("SVS", CAP_SVS, 1);
+  add_capability("CHW", CAP_CHW, 1);
 #ifdef HALFOPS
   add_capability("HOPS", CAP_HOPS, 1);
 #endif
@@ -429,6 +422,8 @@ static void
 ssl_init(void)
 {
 #ifdef HAVE_LIBCRYPTO
+  const unsigned char session_id[] = "ircd-hybrid";
+
   SSL_load_error_strings();
   SSLeay_add_ssl_algorithms();
 
@@ -445,6 +440,7 @@ ssl_init(void)
   SSL_CTX_set_options(ServerInfo.server_ctx, SSL_OP_TLS_ROLLBACK_BUG|SSL_OP_ALL);
   SSL_CTX_set_verify(ServerInfo.server_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
                      always_accept_verify_cb);
+  SSL_CTX_set_session_id_context(ServerInfo.server_ctx, session_id, sizeof(session_id) - 1);
 
   if ((ServerInfo.client_ctx = SSL_CTX_new(SSLv23_client_method())) == NULL)
   {
@@ -597,7 +593,7 @@ main(int argc, char *argv[])
 
   hash_add_id(&me);
   hash_add_client(&me);
-  
+
   /* add ourselves to global_serv_list */
   dlinkAdd(&me, make_dlink_node(), &global_serv_list);
 
