@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  ircd_signal.c: responsible for ircd's signal handling
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,31 +17,32 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: ircd_signal.c 1309 2012-03-25 11:24:18Z michael $
+ */
+
+/*! \file ircd_signal.c
+ * \brief responsible for ircd's signal handling.
+ * \version $Id: ircd_signal.c 3064 2014-02-27 18:59:18Z michael $
  */
 
 #include "stdinc.h"
-#include "list.h"
 #include "ircd_signal.h"
-#include "ircd.h"         /* dorehash */
-#include "restart.h"      /* server_die */
-#include "memory.h"
-#include "s_bsd.h"
+#include "ircd.h"
+#include "restart.h"
+
 
 /*
  * sigterm_handler - exit the server
  */
-static void 
-sigterm_handler(int sig)  
+static void
+sigterm_handler(int sig)
 {
   server_die("received signal SIGTERM", 0);
 }
 
-/* 
+/*
  * sighup_handler - reread the server configuration
  */
-static void 
+static void
 sighup_handler(int sig)
 {
   dorehash = 1;
@@ -58,7 +58,7 @@ sigusr1_handler(int sig)
 }
 
 /*
- * 
+ *
  * inputs	- nothing
  * output	- nothing
  * side effects - Reaps zombies periodically
@@ -67,23 +67,26 @@ sigusr1_handler(int sig)
 static void
 sigchld_handler(int sig)
 {
-  int status;
-  waitpid(-1, &status, WNOHANG);
+  int status, errno_save = errno;
+
+  while (waitpid(-1, &status, WNOHANG) > 0)
+    ;
+  errno = errno_save;
 }
 
 /*
  * sigint_handler - restart the server
  */
-static void 
+static void
 sigint_handler(int sig)
 {
-  server_die("SIGINT received", !server_state.foreground);
+  server_die("received signal SIGINT", !server_state.foreground);
 }
 
 /*
  * setup_signals - initialize signal handlers for server
  */
-void 
+void
 setup_signals(void)
 {
   struct sigaction act;
@@ -92,44 +95,49 @@ setup_signals(void)
   act.sa_handler = SIG_IGN;
 
   sigemptyset(&act.sa_mask);
-  sigaddset(&act.sa_mask, SIGPIPE);
-  sigaddset(&act.sa_mask, SIGALRM);
-  sigaction(SIGALRM, &act, 0);
+#ifdef SIGXFSZ
+  sigaddset(&act.sa_mask, SIGXFSZ);
+#endif
+#ifdef SIGWINCH
+  sigaddset(&act.sa_mask, SIGWINCH);
+#endif
 #ifdef SIGTRAP
   sigaddset(&act.sa_mask, SIGTRAP);
 #endif
+  sigaddset(&act.sa_mask, SIGPIPE);
+  sigaddset(&act.sa_mask, SIGALRM);
+  sigaddset(&act.sa_mask, SIGHUP);
+  sigaddset(&act.sa_mask, SIGINT);
+  sigaddset(&act.sa_mask, SIGTERM);
+  sigaddset(&act.sa_mask, SIGUSR1);
+  sigaddset(&act.sa_mask, SIGCHLD);
+
 #ifdef SIGXFSZ
-  sigaddset(&act.sa_mask, SIGXFSZ);
   sigaction(SIGXFSZ, &act, 0);
 #endif
-
 #ifdef SIGWINCH
-  sigaddset(&act.sa_mask, SIGWINCH);
   sigaction(SIGWINCH, &act, 0);
 #endif
-  sigaction(SIGPIPE, &act, 0);
 #ifdef SIGTRAP
   sigaction(SIGTRAP, &act, 0);
 #endif
+  sigaction(SIGPIPE, &act, 0);
+  sigaction(SIGALRM, &act, 0);
 
   act.sa_handler = sighup_handler;
-  sigemptyset(&act.sa_mask);
-  sigaddset(&act.sa_mask, SIGHUP);
   sigaction(SIGHUP, &act, 0);
 
   act.sa_handler = sigint_handler;
-  sigaddset(&act.sa_mask, SIGINT);
   sigaction(SIGINT, &act, 0);
 
   act.sa_handler = sigterm_handler;
-  sigaddset(&act.sa_mask, SIGTERM);
   sigaction(SIGTERM, &act, 0);
 
   act.sa_handler = sigusr1_handler;
-  sigaddset(&act.sa_mask, SIGUSR1);
   sigaction(SIGUSR1, &act, 0);
 
   act.sa_handler = sigchld_handler;
-  sigaddset(&act.sa_mask, SIGCHLD);
   sigaction(SIGCHLD, &act, 0);
+
+  sigprocmask(SIG_UNBLOCK, &act.sa_mask, NULL);
 }
