@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  modules.c: A module loader.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 2000-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: modules.c 2526 2013-11-02 17:07:55Z michael $
+ */
+
+/*! \file modules.c
+ * \brief A module loader.
+ * \version $Id: modules.c 3032 2014-02-25 11:51:04Z michael $
  */
 
 #include "ltdl.h"
@@ -39,10 +41,9 @@
 #include "memory.h"
 
 
-dlink_list modules_list = { NULL, NULL, 0 };
-
-static dlink_list mod_paths = { NULL, NULL, 0 };
-static dlink_list conf_modules = { NULL, NULL, 0 };
+static dlink_list modules_list;
+static dlink_list modules_path;
+static dlink_list modules_conf;
 
 static const char *unknown_ver = "<unknown>";
 static const char *core_module_table[] =
@@ -63,6 +64,13 @@ static const char *core_module_table[] =
   NULL
 };
 
+
+dlink_list *
+modules_get_list(void)
+{
+  return &modules_list;
+}
+
 int
 modules_valid_suffix(const char *name)
 {
@@ -192,9 +200,9 @@ modules_init(void)
 static struct module_path *
 mod_find_path(const char *path)
 {
-  dlink_node *ptr;
+  dlink_node *ptr = NULL;
 
-  DLINK_FOREACH(ptr, mod_paths.head)
+  DLINK_FOREACH(ptr, modules_path.head)
   {
     struct module_path *mpath = ptr->data;
 
@@ -222,7 +230,7 @@ mod_add_path(const char *path)
   pathst = MyMalloc(sizeof(struct module_path));
 
   strlcpy(pathst->path, path, sizeof(pathst->path));
-  dlinkAdd(pathst, &pathst->node, &mod_paths);
+  dlinkAdd(pathst, &pathst->node, &modules_path);
 }
 
 /* add_conf_module
@@ -239,7 +247,7 @@ add_conf_module(const char *name)
   pathst = MyMalloc(sizeof(struct module_path));
 
   strlcpy(pathst->path, name, sizeof(pathst->path));
-  dlinkAdd(pathst, &pathst->node, &conf_modules);
+  dlinkAdd(pathst, &pathst->node, &modules_conf);
 }
 
 /* mod_clear_paths()
@@ -253,15 +261,15 @@ mod_clear_paths(void)
 {
   dlink_node *ptr = NULL, *next_ptr = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, next_ptr, mod_paths.head)
+  DLINK_FOREACH_SAFE(ptr, next_ptr, modules_path.head)
   {
-    dlinkDelete(ptr, &mod_paths);
+    dlinkDelete(ptr, &modules_path);
     MyFree(ptr->data);
   }
 
-  DLINK_FOREACH_SAFE(ptr, next_ptr, conf_modules.head)
+  DLINK_FOREACH_SAFE(ptr, next_ptr, modules_conf.head)
   {
-    dlinkDelete(ptr, &conf_modules);
+    dlinkDelete(ptr, &modules_conf);
     MyFree(ptr->data);
   }
 }
@@ -332,7 +340,7 @@ load_conf_modules(void)
 {
   dlink_node *ptr = NULL;
 
-  DLINK_FOREACH(ptr, conf_modules.head)
+  DLINK_FOREACH(ptr, modules_conf.head)
   {
     struct module_path *mpath = ptr->data;
 
@@ -375,30 +383,30 @@ load_core_modules(int warn)
  * side effects - module is loaded if found.
  */
 int
-load_one_module(const char *path)
+load_one_module(const char *name)
 {
   dlink_node *ptr = NULL;
-  char modpath[HYB_PATH_MAX + 1];
+  char path[HYB_PATH_MAX + 1];
   struct stat statbuf;
 
-  DLINK_FOREACH(ptr, mod_paths.head)
+  DLINK_FOREACH(ptr, modules_path.head)
   {
     const struct module_path *mpath = ptr->data;
 
-    snprintf(modpath, sizeof(modpath), "%s/%s", mpath->path, path);
+    snprintf(path, sizeof(path), "%s/%s", mpath->path, name);
 
-    if (!modules_valid_suffix(path))
+    if (!modules_valid_suffix(name))
       continue;
 
-    if (strstr(modpath, "../") == NULL &&
-        strstr(modpath, "/..") == NULL)
-      if (!stat(modpath, &statbuf))
+    if (strstr(path, "../") == NULL &&
+        strstr(path, "/..") == NULL)
+      if (!stat(path, &statbuf))
         if (S_ISREG(statbuf.st_mode))  /* Regular files only please */
-          return load_a_module(modpath, 1);
+          return load_a_module(path, 1);
   }
 
   sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                       "Cannot locate module %s", path);
-  ilog(LOG_TYPE_IRCD, "Cannot locate module %s", path);
+                       "Cannot locate module %s", name);
+  ilog(LOG_TYPE_IRCD, "Cannot locate module %s", name);
   return -1;
 }
