@@ -1,8 +1,8 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2000 Kevin L. Mitchell <klmitch@mit.edu>
- *  Copyright (C) 2013 by the Hybrid Development Team.
+ *  Copyright (c) 2000 Kevin L. Mitchell <klmitch@mit.edu>
+ *  Copyright (c) 2013-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file motd.c
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.c 2409 2013-07-19 15:43:53Z michael $
+ * \version $Id: motd.c 2917 2014-01-25 21:09:56Z michael $
  */
 
 #include "stdinc.h"
@@ -224,7 +224,7 @@ motd_destroy(struct Motd *motd)
  * \return Pointer to first matching MOTD for the client.
  */
 static struct Motd *
-motd_lookup(struct Client *client_p)
+motd_lookup(const struct Client *client_p)
 {
   dlink_node *ptr = NULL;
   const struct ClassItem *class = NULL;
@@ -280,8 +280,8 @@ static void
 motd_forward(struct Client *source_p, const struct MotdCache *cache)
 {
   unsigned int i = 0;
-  const char *from = ID_or_name(&me, source_p->from);
-  const char *to = ID_or_name(source_p, source_p->from);
+  const char *from = ID_or_name(&me, source_p);
+  const char *to = ID_or_name(source_p, source_p);
 
   assert(source_p);
 
