@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  numeric.c: Numeric handling functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,15 +17,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: numeric.c 2726 2013-12-29 13:27:10Z michael $
+ */
+
+/*! \file numeric.c
+ * \brief Declarations of numeric replies.
+ * \version $Id: numeric.c 3070 2014-02-27 19:12:11Z michael $
  */
 
 #include "stdinc.h"
 #include "numeric.h"
 
 
-static const char *const replies[] = {
+static const char *const replies[] =
+{
 /* 000 */ NULL,
 /* 001 RPL_WELCOME */ ":%s 001 %s :Welcome to the %s Internet Relay Chat Network %s",
 /* 002 RPL_YOURHOST */ ":%s 002 %s :Your host is %s, running version %s",
@@ -46,7 +49,7 @@ static const char *const replies[] = {
 /* 012 */ NULL,
 /* 013 */ NULL,
 /* 014 */ NULL,
-/* 015 RPL_MAP */ ":%s 015 %s :%s%s%s [%u clients] (%u%%)",
+/* 015 RPL_MAP */ ":%s 015 %s :%s%s",
 /* 016 RPL_MAPMORE */ ":%s 016 %s :%s%s --> *more*",
 /* 017 RPL_MAPEND */ ":%s 017 %s :End of /MAP",
 /* 018 */ NULL,
@@ -274,7 +277,7 @@ static const char *const replies[] = {
 /* 240 */ NULL,
 /* 241 RPL_STATSLLINE */ ":%s 241 %s %c %s * %s %d %s",
 /* 242 RPL_STATSUPTIME */ ":%s 242 %s :Server Up %d days, %d:%02d:%02d",
-/* 243 RPL_STATSOLINE */ ":%s 243 %s %c %u %s@%s * %s %s %s",
+/* 243 RPL_STATSOLINE */ ":%s 243 %s %c %s@%s * %s %s %s",
 /* 244 RPL_STATSHLINE */ ":%s 244 %s %c %s * %s %d %s",
 /* 245 RPL_STATSTLINE */ ":%s 245 %s T %s %s",
 /* 246 RPL_STATSSERVICE */ ":%s 246 %s %c %s * %s %d %d",
@@ -514,7 +517,7 @@ static const char *const replies[] = {
 /* 480 ERR_SSLONLYCHAN */ ":%s 480 %s %s :Cannot join channel (+S)",
 /* 481 ERR_NOPRIVILEGES */ ":%s 481 %s :Permission Denied - You're not an IRC operator",
 /* 482 ERR_CHANOPRIVSNEEDED */ ":%s 482 %s %s :You're not channel operator",
-/* 483 ERR_CANTKILLSERVER */ ":%s 483 %s :You can't kill a server!",
+/* 483 ERR_CANTKILLSERVER */ ":%s 483 %s :You cannot kill a server!",
 /* 484 ERR_RESTRICTED */ ":%s 484 %s :You are restricted",
 /* 485 ERR_CHANBANREASON */ ":%s 485 %s %s :Cannot join channel (%s)",
 /* 486 ERR_NONONREG */ ":%s 486 %s %s :You must identify to a registered nick to private message that person",
@@ -533,7 +536,7 @@ static const char *const replies[] = {
 /* 499 */ NULL,
 /* 500 */ NULL,
 /* 501 ERR_UMODEUNKNOWNFLAG */ ":%s 501 %s :Unknown MODE flag",
-/* 502 ERR_USERSDONTMATCH */ ":%s 502 %s :Can't change mode for other users",
+/* 502 ERR_USERSDONTMATCH */ ":%s 502 %s :Cannot change mode for other users",
 /* 503 ERR_GHOSTEDCLIENT */ ":%s 503 %s :Message could not be delivered to %s",
 /* 504 ERR_USERNOTONSERV */ ":%s 504 %s %s :User is not on this server",
 /* 505 */ NULL,
@@ -1041,7 +1044,7 @@ static const char *const replies[] = {
  * side effects - NONE
  */
 const char *
-form_str(unsigned int numeric)
+form_str(enum irc_numerics numeric)
 {
   assert(numeric < ERR_LAST_ERR_MSG);
 
