@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  parse.c: The message parser.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: parse.c 2787 2014-01-06 22:34:10Z michael $
+ */
+
+/*! \file parse.c
+ * \brief The message parser.
+ * \version $Id: parse.c 3106 2014-03-06 10:35:33Z michael $
  */
 
 #include "stdinc.h"
@@ -37,6 +39,7 @@
 #include "s_user.h"
 #include "s_serv.h"
 
+
 /*
  * (based on orabidoo's parser code)
  *
@@ -51,7 +54,7 @@
  * 't' points -> [MessageTree *] 'r' -> [MessageTree *] -> 'i'
  *   -> [MessageTree *] -> [MessageTree *] -> 'e' and matches
  *
- *				 'i' -> [MessageTree *] -> 'e' and matches
+ *                               'i' -> [MessageTree *] -> 'e' and matches
  *
  * BUGS (Limitations!)
  *
@@ -97,10 +100,6 @@ struct MessageTree
 
 static struct MessageTree msg_tree;
 
-/*
- * NOTE: parse() should not be called recursively by other functions!
- */
-static char *sender;
 static char *para[MAXPARA + 2]; /* <prefix> + <params> + NULL */
 
 static int cancel_clients(struct Client *, struct Client *, char *);
@@ -140,7 +139,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
      * Copy the prefix to 'sender' assuming it terminates
      * with SPACE (or NULL, which is an error, though).
      */
-    sender = ++ch;
+    char *sender = ++ch;
 
     if ((s = strchr(ch, ' ')) != NULL)
     {
@@ -210,7 +209,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
 
     if ((msg_ptr = find_command(ch)) == NULL)
     {
-      /* 
+      /*
        * Note: Give error message *only* to recognized
        * persons. It's a nightmare situation to have
        * two programs sending "Unknown command"'s or
@@ -716,12 +715,12 @@ handle_numeric(char numeric[], struct Client *client_p, struct Client *source_p,
         !HasUMode(target_p, UMODE_OPER))
       sendto_one(target_p, ":%s %s %s %s", me.name, numeric, target_p->name, parv[2]);
     else
-      sendto_one(target_p, ":%s %s %s %s", ID_or_name(source_p, target_p->from),
-                 numeric, ID_or_name(target_p, target_p->from), parv[2]);
+      sendto_one(target_p, ":%s %s %s %s", ID_or_name(source_p, target_p),
+                 numeric, ID_or_name(target_p, target_p), parv[2]);
   }
   else
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s %s %s %s",
-                         source_p->name, numeric, chptr->chname, parv[2]);
+    sendto_channel_butone(client_p, source_p, chptr, 0, "%s %s %s",
+                          numeric, chptr->chname, parv[2]);
 }
 
 /* m_not_oper()
@@ -729,33 +728,36 @@ handle_numeric(char numeric[], struct Client *client_p, struct Client *source_p,
  * output	-
  * side effects	- just returns a nastyogram to given user
  */
-void
+int
 m_not_oper(struct Client *client_p, struct Client *source_p,
            int parc, char *parv[])
 {
   sendto_one(source_p, form_str(ERR_NOPRIVILEGES),
              me.name, source_p->name);
+  return 0;
 }
 
-void
+int
 m_unregistered(struct Client *client_p, struct Client *source_p,
                int parc, char *parv[])
 {
   sendto_one(source_p, form_str(ERR_NOTREGISTERED), me.name,
              source_p->name[0] ? source_p->name : "*");
+  return 0;
 }
 
-void
+int
 m_registered(struct Client *client_p, struct Client *source_p,
              int parc, char *parv[])
 {
   sendto_one(source_p, form_str(ERR_ALREADYREGISTRED),
              me.name, source_p->name);
+  return 0;
 }
 
-void
+int
 m_ignore(struct Client *client_p, struct Client *source_p,
          int parc, char *parv[])
 {
-  return;
+  return 0;
 }
