@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  restart.c: Functions to allow the ircd to restart.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: restart.c 1631 2012-11-01 22:04:01Z michael $
+ */
+
+/*! \file restart.c
+ * \brief Functions to allow the ircd to restart.
+ * \version $Id: restart.c 2917 2014-01-25 21:09:56Z michael $
  */
 
 #include "stdinc.h"
@@ -30,7 +32,7 @@
 #include "irc_string.h"
 #include "send.h"
 #include "log.h"
-#include "client.h" /* for UMODE_ALL */
+#include "client.h"
 #include "memory.h"
 #include "conf_db.h"
 
