@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  s_gline.c: GLine global ban functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: s_gline.c 1996 2013-05-11 17:34:41Z michael $
+ */
+
+/*! \file s_gline.c
+ * \brief GLine global ban functions.
+ * \version $Id: s_gline.c 2917 2014-01-25 21:09:56Z michael $
  */
 
 #include "stdinc.h"
@@ -44,7 +46,6 @@ struct MaskItem *
 find_is_glined(const char *host, const char *user)
 {
   struct irc_ssaddr iphost, *piphost = NULL;
-  struct MaskItem *conf = NULL;
   int t = 0;
   int aftype = 0;
 
@@ -61,8 +62,7 @@ find_is_glined(const char *host, const char *user)
   else
     piphost = NULL;
 
-  conf = find_conf_by_address(host, piphost, CONF_GLINE, aftype, user, NULL, 0);
-  return conf;
+  return find_conf_by_address(host, piphost, CONF_GLINE, aftype, user, NULL, 0);
 }
 
 /* expire_pending_glines()
