@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  s_user.c: User related functions.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: s_user.c 2690 2013-12-17 18:55:43Z michael $
+ */
+
+/*! \file s_user.c
+ * \brief User related functions.
+ * \version $Id: s_user.c 3225 2014-03-28 17:27:16Z michael $
  */
 
 #include "stdinc.h"
@@ -469,15 +471,13 @@ register_local_user(struct Client *source_p)
  *              - username to register as
  *              - host name to register as
  *              - server name
- *              - realname (gecos)
  * output	- NONE
  * side effects	- This function is called when a remote client
  *		  is introduced by a server.
  */
 void
-register_remote_user(struct Client *source_p,
-                     const char *username, const char *host, const char *server,
-                     const char *realname)
+register_remote_user(struct Client *source_p, const char *username,
+                     const char *host, const char *server)
 {
   struct Client *target_p = NULL;
 
@@ -785,7 +785,7 @@ report_and_set_user_flags(struct Client *source_p, const struct MaskItem *conf)
     SetExemptLimits(source_p);
     sendto_one(source_p,
                ":%s NOTICE %s :*** You are exempt from user limits. Congrats.",
-               me.name,source_p->name);
+               me.name, source_p->name);
   }
 
   if (IsConfCanFlood(conf))
@@ -1193,7 +1193,7 @@ check_xline(struct Client *source_p)
     if (conf->reason != NULL)
       reason = conf->reason;
     else
-      reason = "No Reason";
+      reason = CONF_NOREASON;
 
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "X-line Rejecting [%s] [%s], user %s [%s]",
