@@ -1,8 +1,7 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
- *  send.c: Functions for sending messages.
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (C) 2002 by the past and present ircd coders, and others.
+ *  Copyright (c) 1997-2014 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: send.c 2653 2013-12-11 17:45:22Z michael $
+ */
+
+/*! \file send.c
+ * \brief Functions for sending messages.
+ * \version $Id: send.c 3310 2014-04-15 11:41:24Z michael $
  */
 
 #include "stdinc.h"
@@ -113,9 +115,7 @@ send_message(struct Client *to, char *buf, int len)
   ++to->localClient->send.messages;
   ++me.localClient->send.messages;
 
-  if (dbuf_length(&to->localClient->buf_sendq) >
-      (IsServer(to) ? (unsigned int) 1024 : (unsigned int) 4096))
-    send_queued_write(to);
+  send_queued_write(to);
 }
 
 /* send_message_remote()
@@ -127,12 +127,15 @@ send_message(struct Client *to, char *buf, int len)
  * output	- none
  * side effects	- Despite the function name, this only sends to directly
  *		  connected clients.
- * 
+ *
  */
 static void
 send_message_remote(struct Client *to, struct Client *from,
                     char *buf, int len)
 {
+  if (to->from)
+    to = to->from;
+
   if (!MyConnect(to))
   {
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
@@ -162,7 +165,7 @@ send_message_remote(struct Client *to, struct Client *from,
 
     sendto_server(NULL, CAP_TS6, NOCAPS,
                   ":%s KILL %s :%s (%s[%s@%s] Ghosted %s)",
-                  me.id, to->name, me.name, to->name,
+                  me.id, ID(to), me.name, to->name,
                   to->username, to->host, to->from->name);
     sendto_server(NULL, NOCAPS, CAP_TS6,
                   ":%s KILL %s :%s (%s[%s@%s] Ghosted %s)",
@@ -190,16 +193,10 @@ send_message_remote(struct Client *to, struct Client *from,
 void
 sendq_unblocked(fde_t *fd, struct Client *client_p)
 {
-  ClearSendqBlocked(client_p);
-  /* let send_queued_write be executed by send_queued_all */
+  assert(fd == &client_p->localClient->fd);
 
-#ifdef HAVE_LIBCRYPTO
-  if (fd->flags.pending_read)
-  {
-    fd->flags.pending_read = 0;
-    read_packet(fd, client_p);
-  }
-#endif
+  DelFlag(client_p, FLAGS_BLOCKED);
+  send_queued_write(client_p);
 }
 
 /*
@@ -218,7 +215,7 @@ send_queued_write(struct Client *to)
    ** Once socket is marked dead, we cannot start writing to it,
    ** even if the error is removed...
    */
-  if (IsDead(to) || IsSendqBlocked(to))
+  if (IsDead(to) || HasFlag(to, FLAGS_BLOCKED))
     return;  /* no use calling send() now */
 
   /* Next, lets try to write some data */
@@ -268,8 +265,8 @@ send_queued_write(struct Client *to)
 
     if ((retlen < 0) && (ignoreErrno(errno)))
     {
+      AddFlag(to, FLAGS_BLOCKED);
       /* we have a non-fatal error, reschedule a write */
-      SetSendqBlocked(to);
       comm_setselect(&to->localClient->fd, COMM_SELECT_WRITE,
                      (PF *)sendq_unblocked, to, 0);
     }
@@ -425,7 +422,7 @@ sendto_channel_butone(struct Client *one, struct Client *from,
 }
 
 /* sendto_server()
- * 
+ *
  * inputs       - pointer to client to NOT send to
  *              - pointer to channel
  *              - caps or'd together which must ALL be present
@@ -436,7 +433,7 @@ sendto_channel_butone(struct Client *one, struct Client *from,
  * side effects - Send a message to all connected servers, except the
  *                client 'one' (if non-NULL), as long as the servers
  *                support ALL capabs in 'caps', and NO capabs in 'nocaps'.
- *            
+ *
  * This function was written in an attempt to merge together the other
  * billion sendto_*serv*() functions, which sprung up with capabs,
  * lazylinks, uids, etc.
@@ -484,7 +481,7 @@ sendto_server(struct Client *one,
  *		- pattern to send
  * output	- NONE
  * side effects	- Sends a message to all people on local server who are
- * 		  in same channel with user. 
+ * 		  in same channel with user.
  *		  used by m_nick.c and exit_one_client.
  */
 void
@@ -618,60 +615,6 @@ sendto_channel_local_butone(struct Client *one, unsigned int type, unsigned int
   }
 }
 
-
-/* sendto_channel_remote()
- *
- * inputs	- Client not to send towards
- *		- Client from whom message is from
- *		- member status mask, e.g. CHFL_CHANOP | CHFL_VOICE
- *              - pointer to channel to send to
- *              - var args pattern
- * output	- NONE
- * side effects - Send a message to all members of a channel that are
- *		  remote to this server.
- */
-void
-sendto_channel_remote(struct Client *one, struct Client *from, unsigned int type,
-                      const unsigned int caps, const unsigned int nocaps,
-                      struct Channel *chptr, const char *pattern, ...)
-{
-  va_list args;
-  char buffer[IRCD_BUFSIZE];
-  int len = 0;
-  dlink_node *ptr = NULL;
-
-  va_start(args, pattern);
-  len = send_format(buffer, sizeof(buffer), pattern, args);
-  va_end(args);
-
-  ++current_serial;
-
-  DLINK_FOREACH(ptr, chptr->members.head)
-  {
-    struct Membership *ms = ptr->data;
-    struct Client *target_p = ms->client_p;
-
-    if (type != 0 && (ms->flags & type) == 0)
-      continue;
-
-    if (MyConnect(target_p))
-      continue;
-
-    target_p = target_p->from;
-
-    if (target_p == one->from ||
-        ((target_p->from->localClient->caps & caps) != caps) ||
-        ((target_p->from->localClient->caps & nocaps) != 0))
-      continue;
-
-    if (target_p->from->localClient->serial != current_serial)
-    {
-      send_message(target_p, buffer, len);
-      target_p->from->localClient->serial = current_serial;
-    }
-  }
-}
-
 /*
  ** match_it() and sendto_match_butone() ARE only used
  ** to send a msg to all ppl on servers/hosts that match a specified mask
@@ -690,7 +633,7 @@ sendto_channel_remote(struct Client *one, struct Client *from, unsigned int type
  * side effects	- NONE
  */
 static int
-match_it(const struct Client *one, const char *mask, int what)
+match_it(const struct Client *one, const char *mask, unsigned int what)
 {
   if (what == MATCH_HOST)
     return !match(mask, one->host);
@@ -786,10 +729,21 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
 {
   va_list args;
   dlink_node *ptr = NULL;
-  char buffer[IRCD_BUFSIZE];
+  char buff_suid[IRCD_BUFSIZE];
+  char buff_name[IRCD_BUFSIZE];
+  int len_suid = 0;
+  int len_name = 0;
 
   va_start(args, pattern);
-  vsnprintf(buffer, sizeof(buffer), pattern, args);
+  len_suid  = snprintf(buff_suid, sizeof(buff_suid), ":%s ", ID(source_p));
+  len_suid += send_format(&buff_suid[len_suid], sizeof(buff_suid) - len_suid,
+                          pattern, args);
+  va_end(args);
+
+  va_start(args, pattern);
+  len_name = snprintf(buff_name, sizeof(buff_name), ":%s ", source_p->name);
+  len_name += send_format(&buff_name[len_name], sizeof(buff_name) - len_name,
+                          pattern, args);
   va_end(args);
 
   ++current_serial;
@@ -816,7 +770,10 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
       if (!IsCapable(target_p->from, cap))
         continue;
 
-      sendto_anywhere(target_p, source_p, "%s", buffer);
+      if (HasID(target_p->from))
+        send_message_remote(target_p->from, source_p, buff_suid, len_suid);
+      else
+        send_message_remote(target_p->from, source_p, buff_name, len_name);
     }
   }
 }
@@ -832,35 +789,38 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
  */
 void
 sendto_anywhere(struct Client *to, struct Client *from,
+                const char *command,
                 const char *pattern, ...)
 {
   va_list args;
   char buffer[IRCD_BUFSIZE];
-  int len;
-  struct Client *send_to = (to->from != NULL ? to->from : to);
+  int len = 0;
 
-  if (IsDead(send_to))
+  if (IsDead(to->from))
     return;
 
   if (MyClient(to))
   {
     if (IsServer(from))
-      len = snprintf(buffer, sizeof(buffer), ":%s ", from->name);
+      len = snprintf(buffer, sizeof(buffer), ":%s %s %s ",
+                     from->name, command, to->name);
     else
-      len = snprintf(buffer, sizeof(buffer), ":%s!%s@%s ",
-                     from->name, from->username, from->host);
+      len = snprintf(buffer, sizeof(buffer), ":%s!%s@%s %s %s ",
+                     from->name, from->username, from->host, command, to->name);
   }
   else
-    len = snprintf(buffer, sizeof(buffer), ":%s ", ID_or_name(from, send_to));
+    len = snprintf(buffer, sizeof(buffer), ":%s %s %s ",
+                   ID_or_name(from, to), command,
+                   ID_or_name(to, to));
 
   va_start(args, pattern);
-  len += send_format(&buffer[len], IRCD_BUFSIZE - len, pattern, args);
+  len += send_format(&buffer[len], sizeof(buffer) - len, pattern, args);
   va_end(args);
 
   if (MyClient(to))
-    send_message(send_to, buffer, len);
+    send_message(to, buffer, len);
   else
-    send_message_remote(send_to, from, buffer, len);
+    send_message_remote(to, from, buffer, len);
 }
 
 /* sendto_realops_flags()
@@ -964,7 +924,7 @@ sendto_wallops_flags(unsigned int flags, struct Client *source_p,
  *		  (at most 5 warnings every 5 seconds)
  */
 void
-ts_warn(const char *pattern, ...)
+sendto_realops_flags_ratelimited(const char *pattern, ...)
 {
   va_list args;
   char buffer[IRCD_BUFSIZE];
@@ -1019,7 +979,7 @@ kill_client(struct Client *client_p, struct Client *diedie,
     return;
 
   len = snprintf(buffer, sizeof(buffer), ":%s KILL %s :",
-                 ID_or_name(&me, client_p->from),
+                 ID_or_name(&me, client_p),
                  ID_or_name(diedie, client_p));
 
   va_start(args, pattern);
