@@ -9,7 +9,7 @@
 ** /dev/random for salt generation added by 
 ** Aaron Sethman <androsyn@ratbox.org>
 **
-** $Id: mkpasswd.c 2264 2013-06-17 19:21:30Z michael $
+** $Id: mkpasswd.c 3127 2014-03-09 20:10:43Z michael $
 */
 
 #include <stdio.h>
@@ -60,9 +60,9 @@ int
 main(int argc, char *argv[])
 {
   const char *plaintext = NULL;
+  const char *saltpara = NULL;
+  const char *salt = NULL;
   int c;
-  char *saltpara = NULL;
-  char *salt;
   int flag = 0;
   int length = 0; /* Not Set */
   int rounds = 0; /* Not set, since extended DES needs 25 and blowfish needs
@@ -129,14 +129,20 @@ main(int argc, char *argv[])
     }
   }
 
-  if (flag & FLAG_MD5)
+  if (flag & FLAG_DES)
   {
-    if (length == 0)
-      length = 8;
     if (flag & FLAG_SALT)
-      salt = make_md5_salt_para(saltpara);
+    {
+      if ((strlen(saltpara) == 2))
+        salt = saltpara;
+      else
+      {
+        printf("Invalid salt, please enter 2 alphanumeric characters\n");
+        exit(1);
+      }
+    }
     else
-      salt = make_md5_salt(length);
+      salt = make_des_salt();
   }
   else if (flag & FLAG_SHA256)
   {
@@ -189,24 +195,14 @@ main(int argc, char *argv[])
   {
     salt = saltpara;
   }
-  else /* Default to DES */
+  else /* Default to MD5 */
   {
+    if (length == 0)
+      length = 8;
     if (flag & FLAG_SALT)
-    {
-      if ((strlen(saltpara) == 2))
-      {
-        salt = saltpara;
-      }
-      else
-      {
-        printf("Invalid salt, please enter 2 alphanumeric characters\n");
-        exit(1);
-      }
-    }
+      salt = make_md5_salt_para(saltpara);
     else
-    {
-      salt = make_des_salt();
-    }
+      salt = make_md5_salt(length);
   }
 
   if (flag & FLAG_PASS)
@@ -296,7 +292,7 @@ make_sha256_salt(int length)
 
   if (length > 16)
   {
-    printf("SHA256 salt length too long\n");
+    printf("SHA-256 salt length too long\n");
     exit(0);
   }
 
@@ -337,7 +333,7 @@ make_sha512_salt(int length)
 
   if (length > 16)
   {
-    printf("SHA512 salt length too long\n");
+    printf("SHA-512 salt length too long\n");
     exit(0);
   }
 
